@@ -7,6 +7,8 @@ The only requirement from an action is for it to have a take_action method.
 import logging
 import warnings
 
+from great_expectations.data_context.types.refs import GeCloudResourceRef
+
 try:
     import pypd
 except ImportError:
@@ -21,6 +23,7 @@ from great_expectations.checkpoint.util import (
 )
 from great_expectations.data_context.store.metric_store import MetricStore
 from great_expectations.data_context.types.resource_identifiers import (
+    GeCloudIdentifier,
     ValidationResultIdentifier,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
@@ -43,8 +46,10 @@ class ValidationAction:
     def run(
         self,
         validation_result_suite,
-        validation_result_suite_identifier,
+        validation_result_suite_identifier: ValidationResultIdentifier,
         data_asset,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
         **kwargs,
     ):
         """
@@ -56,14 +61,21 @@ class ValidationAction:
         :return:
         """
         return self._run(
-            validation_result_suite,
-            validation_result_suite_identifier,
-            data_asset,
+            validation_result_suite=validation_result_suite,
+            validation_result_suite_identifier=validation_result_suite_identifier,
+            data_asset=data_asset,
+            expectation_suite_identifier=expectation_suite_identifier,
+            checkpoint_identifier=checkpoint_identifier,
             **kwargs,
         )
 
     def _run(
-        self, validation_result_suite, validation_result_suite_identifier, data_asset
+        self,
+        validation_result_suite,
+        validation_result_suite_identifier,
+        data_asset,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         return NotImplementedError
 
@@ -76,7 +88,12 @@ class NoOpAction(ValidationAction):
         super().__init__(data_context)
 
     def _run(
-        self, validation_result_suite, validation_result_suite_identifier, data_asset
+        self,
+        validation_result_suite,
+        validation_result_suite_identifier,
+        data_asset,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         print("Happily doing nothing")
 
@@ -94,7 +111,11 @@ class SlackNotificationAction(ValidationAction):
           class_name: SlackNotificationAction
           # put the actual webhook URL in the uncommitted/config_variables.yml file
           # or pass in as environment variable
+          # use slack_webhook when not using slack bot token
           slack_webhook: ${validation_notification_slack_webhook}
+          # pass slack token and slack channel when not using slack_webhook
+          slack_token: # token from slack app
+          slack_channel: # slack channel that messages should go to
           notify_on: all # possible values: "all", "failure", "success"
           notify_with: # optional list of DataDocs site names to display in Slack message. Defaults to showing all
           renderer:
@@ -110,7 +131,9 @@ class SlackNotificationAction(ValidationAction):
         self,
         data_context,
         renderer,
-        slack_webhook,
+        slack_webhook=None,
+        slack_token=None,
+        slack_channel=None,
         notify_on="all",
         notify_with=None,
     ):
@@ -140,8 +163,15 @@ class SlackNotificationAction(ValidationAction):
                 package_name=None,
                 class_name=renderer["class_name"],
             )
+        if not slack_token and slack_channel:
+            assert slack_webhook
+        if not slack_webhook:
+            assert slack_token and slack_channel
+        assert not (slack_webhook and slack_channel and slack_token)
+
         self.slack_webhook = slack_webhook
-        assert slack_webhook, "No Slack webhook found in action config."
+        self.slack_token = slack_token
+        self.slack_channel = slack_channel
         self.notify_on = notify_on
         self.notify_with = notify_with
 
@@ -151,6 +181,8 @@ class SlackNotificationAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset=None,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("SlackNotificationAction.run")
 
@@ -185,15 +217,15 @@ class SlackNotificationAction(ValidationAction):
             query = self.renderer.render(
                 validation_result_suite, data_docs_pages, self.notify_with
             )
-            # this will actually sent the POST request to the Slack webapp server
+
+            # this will actually send the POST request to the Slack webapp server
             slack_notif_result = send_slack_notification(
                 query, slack_webhook=self.slack_webhook
             )
-
-            # sending payload back as dictionary
             return {"slack_notification_result": slack_notif_result}
+
         else:
-            return {"slack_notification_result": ""}
+            return {"slack_notification_result": "none required"}
 
 
 class PagerdutyAlertAction(ValidationAction):
@@ -243,6 +275,8 @@ class PagerdutyAlertAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset=None,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("PagerdutyAlertAction.run")
 
@@ -357,6 +391,8 @@ class MicrosoftTeamsNotificationAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset=None,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("MicrosoftTeamsNotificationAction.run")
 
@@ -465,6 +501,8 @@ class OpsgenieAlertAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset=None,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("OpsgenieAlertAction.run")
 
@@ -616,6 +654,8 @@ class EmailAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset=None,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("EmailAction.run")
 
@@ -709,6 +749,8 @@ class StoreValidationResultAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("StoreValidationResultAction.run")
 
@@ -716,17 +758,35 @@ class StoreValidationResultAction(ValidationAction):
             return
 
         if not isinstance(
-            validation_result_suite_identifier, ValidationResultIdentifier
+            validation_result_suite_identifier,
+            (ValidationResultIdentifier, GeCloudIdentifier),
         ):
             raise TypeError(
-                "validation_result_id must be of type ValidationResultIdentifier, not {}".format(
+                "validation_result_id must be of type ValidationResultIdentifier or GeCloudIdentifier, not {}".format(
                     type(validation_result_suite_identifier)
                 )
             )
 
-        self.target_store.set(
-            validation_result_suite_identifier, validation_result_suite
+        contract_ge_cloud_id = None
+        if self.data_context.ge_cloud_mode and checkpoint_identifier:
+            contract_ge_cloud_id = checkpoint_identifier.ge_cloud_id
+
+        expectation_suite_ge_cloud_id = None
+        if self.data_context.ge_cloud_mode and expectation_suite_identifier:
+            expectation_suite_ge_cloud_id = str(
+                expectation_suite_identifier.ge_cloud_id
+            )
+
+        return_val = self.target_store.set(
+            validation_result_suite_identifier,
+            validation_result_suite,
+            contract_id=contract_ge_cloud_id,
+            expectation_suite_id=expectation_suite_ge_cloud_id,
         )
+        if self.data_context.ge_cloud_mode:
+            return_val: GeCloudResourceRef
+            new_ge_cloud_id = return_val.ge_cloud_id
+            validation_result_suite_identifier.ge_cloud_id = new_ge_cloud_id
 
 
 class StoreEvaluationParametersAction(ValidationAction):
@@ -768,9 +828,11 @@ class StoreEvaluationParametersAction(ValidationAction):
     def _run(
         self,
         validation_result_suite,
-        validation_result_suite_identifier,
+        validation_result_suite_identifier: ValidationResultIdentifier,
         data_asset,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("StoreEvaluationParametersAction.run")
 
@@ -778,10 +840,11 @@ class StoreEvaluationParametersAction(ValidationAction):
             return
 
         if not isinstance(
-            validation_result_suite_identifier, ValidationResultIdentifier
+            validation_result_suite_identifier,
+            (ValidationResultIdentifier, GeCloudIdentifier),
         ):
             raise TypeError(
-                "validation_result_id must be of type ValidationResultIdentifier, not {}".format(
+                "validation_result_id must be of type ValidationResultIdentifier or GeCloudIdentifier, not {}".format(
                     type(validation_result_suite_identifier)
                 )
             )
@@ -846,6 +909,8 @@ class StoreMetricsAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("StoreMetricsAction.run")
 
@@ -916,6 +981,8 @@ class UpdateDataDocsAction(ValidationAction):
         validation_result_suite_identifier,
         data_asset,
         payload=None,
+        expectation_suite_identifier=None,
+        checkpoint_identifier=None,
     ):
         logger.debug("UpdateDataDocsAction.run")
 
@@ -923,30 +990,35 @@ class UpdateDataDocsAction(ValidationAction):
             return
 
         if not isinstance(
-            validation_result_suite_identifier, ValidationResultIdentifier
+            validation_result_suite_identifier,
+            (ValidationResultIdentifier, GeCloudIdentifier),
         ):
             raise TypeError(
-                "validation_result_id must be of type ValidationResultIdentifier, not {}".format(
+                "validation_result_id must be of type ValidationResultIdentifier or GeCloudIdentifier, not {}".format(
                     type(validation_result_suite_identifier)
                 )
             )
 
+        # TODO Update for RenderedDataDocs
         # build_data_docs will return the index page for the validation results, but we want to return the url for the valiation result using the code below
         self.data_context.build_data_docs(
             site_names=self._site_names,
             resource_identifiers=[
                 validation_result_suite_identifier,
-                validation_result_suite_identifier.expectation_suite_identifier,
+                expectation_suite_identifier,
             ],
         )
 
+        data_docs_validation_results = {}
+        if self.data_context.ge_cloud_mode:
+            return data_docs_validation_results
+
         # get the URL for the validation result
         docs_site_urls_list = self.data_context.get_docs_sites_urls(
             resource_identifier=validation_result_suite_identifier,
             site_names=self._site_names,
         )
         # process payload
-        data_docs_validation_results = {}
         for sites in docs_site_urls_list:
             data_docs_validation_results[sites["site_name"]] = sites["site_url"]
 
