@@ -8,13 +8,19 @@ import click
 from great_expectations import DataContext
 from great_expectations import exceptions as ge_exceptions
 from great_expectations.cli import toolkit
+
+# noinspection PyPep8Naming
 from great_expectations.cli.mark import Mark as mark
 from great_expectations.cli.pretty_printing import cli_message, cli_message_list
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.batch import BatchRequest
+from great_expectations.core.usage_statistics.anonymizers.types.base import (
+    CLISuiteInteractiveFlagCombinations,
+)
 from great_expectations.core.usage_statistics.usage_statistics import (
     edit_expectation_suite_usage_statistics,
 )
+from great_expectations.core.usage_statistics.util import send_usage_message
 from great_expectations.render.renderer.v3.suite_edit_notebook_renderer import (
     SuiteEditNotebookRenderer,
 )
@@ -45,7 +51,7 @@ def suite(ctx):
     ctx.obj.data_context = context
 
     usage_stats_prefix = f"cli.suite.{ctx.invoked_subcommand}"
-    toolkit.send_usage_message(
+    send_usage_message(
         data_context=context,
         event=f"{usage_stats_prefix}.begin",
         success=True,
@@ -119,7 +125,9 @@ def suite_new(
     context: DataContext = ctx.obj.data_context
     usage_event_end: str = ctx.obj.usage_event_end
 
-    processed_flags: Dict[str, Optional[bool]] = _process_suite_new_flags_and_prompt(
+    processed_flags: Dict[
+        str, Optional[Union[bool, CLISuiteInteractiveFlagCombinations]]
+    ] = _process_suite_new_flags_and_prompt(
         context=context,
         usage_event_end=usage_event_end,
         interactive_flag=interactive_flag,
@@ -131,7 +139,7 @@ def suite_new(
     _suite_new_workflow(
         context=context,
         expectation_suite_name=expectation_suite,
-        interactive=processed_flags["interactive"],
+        interactive_mode=processed_flags["interactive_mode"],
         profile=processed_flags["profile"],
         no_jupyter=no_jupyter,
         usage_event=usage_event_end,
@@ -146,7 +154,7 @@ def _process_suite_new_flags_and_prompt(
     manual_flag: bool,
     profile: bool,
     batch_request: Optional[str] = None,
-) -> Dict[str, Optional[bool]]:
+) -> Dict[str, Optional[Union[bool, CLISuiteInteractiveFlagCombinations]]]:
     """
     Process various optional suite new flags and prompt if there is not enough information from the flags.
     Args:
@@ -162,89 +170,38 @@ def _process_suite_new_flags_and_prompt(
         {"interactive": True, "profile": False}
     """
 
-    error_message: Optional[str] = None
-
-    # Convert interactive / no-interactive flags to interactive
-    interactive: Optional[bool] = None
-    if interactive_flag is True and manual_flag is True:
-        error_message = """Please choose either --interactive or --manual, you may not choose both."""
-    elif interactive_flag is False and manual_flag is False:
-        interactive = None
-    elif interactive_flag is True and manual_flag is False:
-        interactive = True
-    elif interactive_flag is False and manual_flag is True:
-        interactive = False
-
-    if error_message is not None:
-        cli_message(string=f"<red>{error_message}</red>")
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event_end, success=False
-        )
-        sys.exit(1)
-
-    user_provided_any_flag_skip_prompt: bool = any(
-        ((interactive is not None), (profile is True), (batch_request is not None))
+    interactive_mode: Optional[CLISuiteInteractiveFlagCombinations]
+    interactive_mode = _suite_new_convert_flags_to_interactive_mode(
+        interactive_flag, manual_flag
     )
 
-    # Note - explicit check for boolean or None for `interactive: Optional[bool]` is necessary because None indicates
-    #  that a user did not supply either flag.
-    if user_provided_any_flag_skip_prompt:
-        # Assume batch needed if user passes --profile
-        if profile and interactive is None:
-            cli_message(
-                "<green>Entering interactive mode since you passed the --profile flag</green>"
-            )
-            interactive = True
-        elif profile and interactive is False:
-            cli_message(
-                "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --profile flag</yellow>"
-            )
-            interactive = True
-        # Assume batch needed if user passes --batch-request
-        elif (batch_request is not None) and (interactive is None):
-            cli_message(
-                "<green>Entering interactive mode since you passed the --batch-request flag</green>"
-            )
-            interactive = True
-        elif (batch_request is not None) and (interactive is False):
-            cli_message(
-                "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --batch-request flag</yellow>"
-            )
-            interactive = True
-    else:
-        suite_create_method: str = click.prompt(
-            """
-How would you like to create your Expectation Suite?
-    1. Manually, without interacting with a sample batch of data (default)
-    2. Interactively, with a sample batch of data
-    3. Automatically, using a profiler
-""",
-            type=click.Choice(["1", "2", "3"]),
-            show_choices=False,
-            default="1",
-            show_default=False,
-        )
-        # Default option
-        if suite_create_method == "":
-            interactive = False
-            profile = False
-        elif suite_create_method == "1":
-            interactive = False
-            profile = False
-        elif suite_create_method == "2":
-            interactive = True
-            profile = False
-        elif suite_create_method == "3":
-            interactive = True
-            profile = True
+    error_message: Optional[str] = None
+    if (
+        interactive_mode
+        == CLISuiteInteractiveFlagCombinations.ERROR_INTERACTIVE_TRUE_MANUAL_TRUE
+    ):
+        error_message = """Please choose either --interactive or --manual, you may not choose both."""
 
-    return {"interactive": interactive, "profile": profile}
+    _exit_early_if_error(error_message, context, usage_event_end, interactive_mode)
+
+    if _suite_new_user_provided_any_flag(interactive_mode, profile, batch_request):
+        interactive_mode = _suite_new_process_profile_and_batch_request_flags(
+            interactive_mode, profile, batch_request
+        )
+
+    else:
+        interactive_mode, profile = _suite_new_mode_from_prompt(profile)
+
+    return {
+        "interactive_mode": interactive_mode,
+        "profile": profile,
+    }
 
 
 def _suite_new_workflow(
     context: DataContext,
     expectation_suite_name: str,
-    interactive: bool,
+    interactive_mode: CLISuiteInteractiveFlagCombinations,
     profile: bool,
     no_jupyter: bool,
     usage_event: str,
@@ -260,7 +217,7 @@ def _suite_new_workflow(
             Dict[str, Union[str, int, Dict[str, Any]]]
         ] = {"limit": 1000}
 
-        if interactive:
+        if interactive_mode.value["interactive_flag"]:
             if batch_request is not None and isinstance(batch_request, str):
                 batch_request = toolkit.get_batch_request_from_json_file(
                     batch_request_json_file_path=batch_request,
@@ -284,6 +241,7 @@ def _suite_new_workflow(
         else:
             batch_request = None
 
+        # noinspection PyShadowingNames
         suite: ExpectationSuite = toolkit.get_or_create_expectation_suite(
             expectation_suite_name=expectation_suite_name,
             data_context=context,
@@ -301,8 +259,11 @@ def _suite_new_workflow(
             batch_request=batch_request,
         )
 
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event, success=True
+        send_usage_message(
+            data_context=context,
+            event=usage_event,
+            event_payload=interactive_mode.value,
+            success=True,
         )
 
         if batch_request:
@@ -316,7 +277,7 @@ def _suite_new_workflow(
             expectation_suite_name=expectation_suite_name,
             profile=profile,
             usage_event=usage_event,
-            interactive=interactive,
+            interactive_mode=interactive_mode,
             no_jupyter=no_jupyter,
             create_if_not_exist=True,
             datasource_name=datasource_name,
@@ -333,17 +294,165 @@ def _suite_new_workflow(
         SQLAlchemyError,
     ) as e:
         cli_message(string=f"<red>{e}</red>")
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event, success=False
+        send_usage_message(
+            data_context=context,
+            event=usage_event,
+            event_payload=interactive_mode.value,
+            success=False,
         )
         sys.exit(1)
     except Exception as e:
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event, success=False
+        send_usage_message(
+            data_context=context,
+            event=usage_event,
+            event_payload=interactive_mode.value,
+            success=False,
         )
         raise e
 
 
+def _suite_new_convert_flags_to_interactive_mode(
+    interactive_flag: bool, manual_flag: bool
+) -> CLISuiteInteractiveFlagCombinations:
+    if interactive_flag is True and manual_flag is True:
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.ERROR_INTERACTIVE_TRUE_MANUAL_TRUE
+        )
+    elif interactive_flag is False and manual_flag is False:
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_FALSE_MANUAL_FALSE
+        )
+    elif interactive_flag is True and manual_flag is False:
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_TRUE_MANUAL_FALSE
+        )
+    elif interactive_flag is False and manual_flag is True:
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_FALSE_MANUAL_TRUE
+        )
+    else:
+        interactive_mode = CLISuiteInteractiveFlagCombinations.UNKNOWN
+
+    return interactive_mode
+
+
+def _suite_new_process_profile_and_batch_request_flags(
+    interactive_mode: CLISuiteInteractiveFlagCombinations,
+    profile: bool,
+    batch_request: Optional[str],
+) -> CLISuiteInteractiveFlagCombinations:
+
+    # Explicit check for boolean or None for `interactive_flag` is necessary: None indicates user did not supply flag.
+    # Assume batch needed if user passes --profile
+    if profile and interactive_mode.value["interactive_flag"] is None:
+        cli_message(
+            "<green>Entering interactive mode since you passed the --profile flag</green>"
+        )
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_FALSE_PROFILE_TRUE
+        )
+    elif profile and interactive_mode.value["interactive_flag"] is True:
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_TRUE_MANUAL_FALSE_PROFILE_TRUE
+        )
+    elif profile and interactive_mode.value["interactive_flag"] is False:
+        cli_message(
+            "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --profile flag</yellow>"
+        )
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_TRUE_PROFILE_TRUE
+        )
+    # Assume batch needed if user passes --batch-request
+    elif (batch_request is not None) and (
+        interactive_mode.value["interactive_flag"] is None
+    ):
+        cli_message(
+            "<green>Entering interactive mode since you passed the --batch-request flag</green>"
+        )
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_FALSE_BATCH_REQUEST_SPECIFIED
+        )
+    elif (batch_request is not None) and (
+        interactive_mode.value["interactive_flag"] is False
+    ):
+        cli_message(
+            "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --batch-request flag</yellow>"
+        )
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_TRUE_BATCH_REQUEST_SPECIFIED
+        )
+
+    return interactive_mode
+
+
+def _exit_early_if_error(
+    error_message: Optional[str],
+    context: DataContext,
+    usage_event_end: str,
+    interactive_mode: CLISuiteInteractiveFlagCombinations,
+):
+    if error_message is not None:
+        cli_message(string=f"<red>{error_message}</red>")
+        send_usage_message(
+            data_context=context,
+            event=usage_event_end,
+            event_payload=interactive_mode.value,
+            success=False,
+        )
+        sys.exit(1)
+
+
+def _suite_new_user_provided_any_flag(
+    interactive_mode: CLISuiteInteractiveFlagCombinations,
+    profile: bool,
+    batch_request: Optional[str],
+) -> bool:
+    user_provided_any_flag_skip_prompt: bool = any(
+        (
+            (interactive_mode.value["interactive_flag"] is not None),
+            (profile is True),
+            (batch_request is not None),
+        )
+    )
+    return user_provided_any_flag_skip_prompt
+
+
+def _suite_new_mode_from_prompt(profile: bool):
+    suite_create_method: str = click.prompt(
+        """
+How would you like to create your Expectation Suite?
+    1. Manually, without interacting with a sample batch of data (default)
+    2. Interactively, with a sample batch of data
+    3. Automatically, using a profiler
+""",
+        type=click.Choice(["1", "2", "3"]),
+        show_choices=False,
+        default="1",
+        show_default=False,
+    )
+    # Default option
+    if suite_create_method == "":
+        profile = False
+        interactive_mode = CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_DEFAULT
+    elif suite_create_method == "1":
+        profile = False
+        interactive_mode = CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_FALSE
+    elif suite_create_method == "2":
+        profile = False
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_TRUE_PROFILE_FALSE
+        )
+    elif suite_create_method == "3":
+        profile = True
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_TRUE_PROFILE_TRUE
+        )
+    else:
+        interactive_mode = CLISuiteInteractiveFlagCombinations.UNKNOWN
+
+    return interactive_mode, profile
+
+
 @suite.command(name="edit")
 @click.argument("expectation_suite")
 @click.option(
@@ -412,13 +521,15 @@ def suite_edit(
     context: DataContext = ctx.obj.data_context
     usage_event_end: str = ctx.obj.usage_event_end
 
-    interactive: bool = _process_suite_edit_flags_and_prompt(
-        context=context,
-        usage_event_end=usage_event_end,
-        interactive_flag=interactive_flag,
-        manual_flag=manual_flag,
-        datasource_name=datasource_name,
-        batch_request=batch_request,
+    interactive_mode: CLISuiteInteractiveFlagCombinations = (
+        _process_suite_edit_flags_and_prompt(
+            context=context,
+            usage_event_end=usage_event_end,
+            interactive_flag=interactive_flag,
+            manual_flag=manual_flag,
+            datasource_name=datasource_name,
+            batch_request=batch_request,
+        )
     )
 
     additional_batch_request_args: Optional[
@@ -430,7 +541,7 @@ def suite_edit(
         expectation_suite_name=expectation_suite,
         profile=False,
         usage_event=usage_event_end,
-        interactive=interactive,
+        interactive_mode=interactive_mode,
         no_jupyter=no_jupyter,
         create_if_not_exist=False,
         datasource_name=datasource_name,
@@ -448,7 +559,7 @@ def _process_suite_edit_flags_and_prompt(
     manual_flag: bool,
     datasource_name: Optional[str] = None,
     batch_request: Optional[str] = None,
-) -> bool:
+) -> CLISuiteInteractiveFlagCombinations:
     """
     Process various optional suite edit flags and prompt if there is not enough information from the flags.
     Args:
@@ -465,60 +576,91 @@ def _process_suite_edit_flags_and_prompt(
 
     error_message: Optional[str] = None
 
+    interactive_mode: CLISuiteInteractiveFlagCombinations
+
     # Convert interactive / no-interactive flags to interactive
-    interactive: Optional[bool] = None
     if interactive_flag is True and manual_flag is True:
         error_message = """Please choose either --interactive or --manual, you may not choose both."""
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.ERROR_INTERACTIVE_TRUE_MANUAL_TRUE
+        )
     elif interactive_flag is False and manual_flag is False:
-        interactive = None
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_FALSE_MANUAL_FALSE
+        )
     elif interactive_flag is True and manual_flag is False:
-        interactive = True
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_TRUE_MANUAL_FALSE
+        )
     elif interactive_flag is False and manual_flag is True:
-        interactive = False
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.UNPROMPTED_INTERACTIVE_FALSE_MANUAL_TRUE
+        )
+    else:
+        interactive_mode = CLISuiteInteractiveFlagCombinations.UNKNOWN
 
     if (datasource_name is not None) and (batch_request is not None):
         error_message = """Only one of --datasource-name DATASOURCE_NAME and --batch-request <path to JSON file> \
 options can be used.
 """
+        interactive_mode = (
+            CLISuiteInteractiveFlagCombinations.ERROR_DATASOURCE_SPECIFIED_BATCH_REQUEST_SPECIFIED
+        )
 
     if error_message is not None:
         cli_message(string=f"<red>{error_message}</red>")
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event_end, success=False
+        send_usage_message(
+            data_context=context,
+            event=usage_event_end,
+            event_payload=interactive_mode.value,
+            success=False,
         )
         sys.exit(1)
 
     user_provided_any_flag_skip_prompt: bool = any(
         (
-            (interactive is not None),
+            (interactive_mode.value["interactive_flag"] is not None),
             (datasource_name is not None),
             (batch_request is not None),
         )
     )
 
-    # Note - explicit check for boolean or None for `interactive: Optional[bool]` is necessary because None indicates
-    #  that a user did not supply either flag.
+    # Explicit check for boolean or None for `interactive_flag` is necessary: None indicates user did not supply flag.
     if user_provided_any_flag_skip_prompt:
         if datasource_name is not None:
-            if interactive is None:
+            if interactive_mode.value["interactive_flag"] is None:
                 cli_message(
                     "<green>Entering interactive mode since you passed the --datasource-name flag</green>"
                 )
-            elif interactive is False:
+                interactive_mode = (
+                    CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_FALSE_DATASOURCE_SPECIFIED
+                )
+            elif interactive_mode.value["interactive_flag"] is True:
+                interactive_mode = (
+                    CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_TRUE_MANUAL_FALSE_DATASOURCE_SPECIFIED
+                )
+            elif interactive_mode.value["interactive_flag"] is False:
                 cli_message(
                     "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --datasource-name flag</yellow>"
                 )
-            interactive = True
+                interactive_mode = (
+                    CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_TRUE_DATASOURCE_SPECIFIED
+                )
         elif batch_request is not None:
-            if interactive is None:
+            if interactive_mode.value["interactive_flag"] is None:
                 cli_message(
                     "<green>Entering interactive mode since you passed the --batch-request flag</green>"
                 )
-            elif interactive is False:
+                interactive_mode = (
+                    CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_FALSE_BATCH_REQUEST_SPECIFIED
+                )
+            elif interactive_mode.value["interactive_flag"] is False:
                 cli_message(
                     "<yellow>Warning: Ignoring the --manual flag and entering interactive mode since you passed the --batch-request flag</yellow>"
                 )
-            interactive = True
+                interactive_mode = (
+                    CLISuiteInteractiveFlagCombinations.UNPROMPTED_OVERRIDE_INTERACTIVE_FALSE_MANUAL_TRUE_BATCH_REQUEST_SPECIFIED
+                )
     else:
         suite_edit_method: str = click.prompt(
             """
@@ -533,13 +675,15 @@ How would you like to edit your Expectation Suite?
         )
         # Default option
         if suite_edit_method == "":
-            interactive = False
+            interactive_mode = (
+                CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_DEFAULT
+            )
         if suite_edit_method == "1":
-            interactive = False
+            interactive_mode = CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_FALSE
         elif suite_edit_method == "2":
-            interactive = True
+            interactive_mode = CLISuiteInteractiveFlagCombinations.PROMPTED_CHOICE_TRUE
 
-    return interactive
+    return interactive_mode
 
 
 def _suite_edit_workflow(
@@ -547,9 +691,9 @@ def _suite_edit_workflow(
     expectation_suite_name: str,
     profile: bool,
     usage_event: str,
-    interactive: bool,
+    interactive_mode: CLISuiteInteractiveFlagCombinations,
     no_jupyter: bool,
-    create_if_not_exist: Optional[bool] = False,
+    create_if_not_exist: bool = False,
     datasource_name: Optional[str] = None,
     batch_request: Optional[
         Union[str, Dict[str, Union[str, int, Dict[str, Any]]]]
@@ -557,14 +701,15 @@ def _suite_edit_workflow(
     additional_batch_request_args: Optional[
         Dict[str, Union[str, int, Dict[str, Any]]]
     ] = None,
-    suppress_usage_message: Optional[bool] = False,
-    assume_yes: Optional[bool] = False,
+    suppress_usage_message: bool = False,
+    assume_yes: bool = False,
 ):
     # suppress_usage_message flag is for the situation where _suite_edit_workflow is called by _suite_new_workflow().
     # when called by _suite_new_workflow(), the flag will be set to True, otherwise it will default to False
     if suppress_usage_message:
         usage_event = None
 
+    # noinspection PyShadowingNames
     suite: ExpectationSuite = toolkit.load_expectation_suite(
         data_context=context,
         expectation_suite_name=expectation_suite_name,
@@ -573,7 +718,7 @@ def _suite_edit_workflow(
     )
 
     try:
-        if interactive or profile:
+        if interactive_mode.value["interactive_flag"] or profile:
             batch_request_from_citation_is_up_to_date: bool = True
 
             batch_request_from_citation: Optional[
@@ -654,11 +799,13 @@ If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n"""
             )
 
         payload: dict = edit_expectation_suite_usage_statistics(
-            data_context=context, expectation_suite_name=suite.expectation_suite_name
+            data_context=context,
+            expectation_suite_name=suite.expectation_suite_name,
+            interactive_mode=interactive_mode,
         )
 
         if not suppress_usage_message:
-            toolkit.send_usage_message(
+            send_usage_message(
                 data_context=context,
                 event=usage_event,
                 event_payload=payload,
@@ -677,15 +824,21 @@ If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n"""
     ) as e:
         cli_message(string=f"<red>{e}</red>")
         if not suppress_usage_message:
-            toolkit.send_usage_message(
-                data_context=context, event=usage_event, success=False
+            send_usage_message(
+                data_context=context,
+                event=usage_event,
+                event_payload=interactive_mode.value,
+                success=False,
             )
         sys.exit(1)
 
     except Exception as e:
         if not suppress_usage_message:
-            toolkit.send_usage_message(
-                data_context=context, event=usage_event, success=False
+            send_usage_message(
+                data_context=context,
+                event=usage_event,
+                event_payload=interactive_mode.value,
+                success=False,
             )
         raise e
 
@@ -697,14 +850,17 @@ def suite_demo(ctx):
     """This command is not supported in the v3 (Batch Request) API."""
     context: DataContext = ctx.obj.data_context
     usage_event_end: str = ctx.obj.usage_event_end
-    toolkit.send_usage_message(
-        data_context=context, event=usage_event_end, success=True
+    send_usage_message(
+        data_context=context,
+        event=usage_event_end,
+        success=True,
     )
     cli_message(
         string="This command is not supported in the v3 (Batch Request) API. Please use `suite new` instead."
     )
 
 
+# noinspection PyShadowingNames
 @suite.command(name="delete")
 @click.argument("suite")
 @click.pass_context
@@ -717,8 +873,10 @@ def suite_delete(ctx, suite):
     try:
         suite_names: List[str] = context.list_expectation_suite_names()
     except Exception as e:
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event_end, success=False
+        send_usage_message(
+            data_context=context,
+            event=usage_event_end,
+            success=False,
         )
         raise e
     if not suite_names:
@@ -748,8 +906,10 @@ def suite_delete(ctx, suite):
 
     context.delete_expectation_suite(suite)
     cli_message(string=f"Deleted the expectation suite named: {suite}")
-    toolkit.send_usage_message(
-        data_context=context, event=usage_event_end, success=True
+    send_usage_message(
+        data_context=context,
+        event=usage_event_end,
+        success=True,
     )
 
 
@@ -762,8 +922,10 @@ def suite_list(ctx):
     try:
         suite_names: List[str] = context.list_expectation_suite_names()
     except Exception as e:
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event_end, success=False
+        send_usage_message(
+            data_context=context,
+            event=usage_event_end,
+            success=False,
         )
         raise e
 
@@ -772,8 +934,10 @@ def suite_list(ctx):
     ]
     if len(suite_names_styled) == 0:
         cli_message(string="No Expectation Suites found")
-        toolkit.send_usage_message(
-            data_context=context, event=usage_event_end, success=True
+        send_usage_message(
+            data_context=context,
+            event=usage_event_end,
+            success=True,
         )
         return
 
@@ -785,8 +949,10 @@ def suite_list(ctx):
     cli_message_list(
         string_list=suite_names_styled, list_intro_string=list_intro_string
     )
-    toolkit.send_usage_message(
-        data_context=context, event=usage_event_end, success=True
+    send_usage_message(
+        data_context=context,
+        event=usage_event_end,
+        success=True,
     )
 
 
