@@ -4,10 +4,10 @@ import click
 
 from great_expectations import DataContext
 from great_expectations import exceptions as ge_exceptions
-from great_expectations.cli.v012 import toolkit
 from great_expectations.cli.v012.cli_messages import SECTION_SEPARATOR
 from great_expectations.cli.v012.toolkit import load_data_context_with_error_handling
 from great_expectations.cli.v012.util import cli_message
+from great_expectations.core.usage_statistics.util import send_usage_message
 from great_expectations.data_context.types.base import CURRENT_GE_CONFIG_VERSION
 
 
@@ -29,8 +29,11 @@ def project_check_config(directory):
     cli_message("Checking your config files for validity...\n")
     is_config_ok, error_message, context = do_config_check(directory)
     if context:
-        toolkit.send_usage_message(
-            data_context=context, event="cli.project.check_config", success=True
+        send_usage_message(
+            data_context=context,
+            event="cli.project.check_config",
+            api_version="v2",
+            success=True,
         )
     if not is_config_ok:
         cli_message("Unfortunately, your config appears to be invalid:\n")
@@ -67,7 +70,7 @@ def do_config_check(target_directory):
         ge_config_version: int = context.get_config().config_version
         if int(ge_config_version) < CURRENT_GE_CONFIG_VERSION:
             upgrade_message: str = f"""The config_version of your great_expectations.yml -- {float(ge_config_version)} -- is outdated.
-Please consult the 0.13.x migration guide ttps://docs.greatexpectations.io/en/latest/guides/how_to_guides/migrating_versions.html and
+Please consult the V3 API migration guide https://docs.greatexpectations.io/en/latest/guides/how_to_guides/migrating_versions.html and
 upgrade your Great Expectations configuration to version {float(CURRENT_GE_CONFIG_VERSION)} in order to take advantage of the latest capabilities.
             """
             return (
