@@ -1,8 +1,9 @@
 import datetime
 import json
 import logging
+import uuid
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import great_expectations as ge
 from great_expectations import __version__ as ge_version
@@ -12,6 +13,7 @@ from great_expectations.core.evaluation_parameters import (
 from great_expectations.core.expectation_configuration import (
     ExpectationConfiguration,
     ExpectationConfigurationSchema,
+    expectationConfigurationSchema,
 )
 from great_expectations.core.util import (
     convert_to_json_serializable,
@@ -28,7 +30,6 @@ from great_expectations.marshmallow__shade import (
     Schema,
     ValidationError,
     fields,
-    post_load,
     pre_dump,
 )
 from great_expectations.types import SerializableDictDot
@@ -48,13 +49,18 @@ class ExpectationSuite(SerializableDictDot):
     def __init__(
         self,
         expectation_suite_name,
+        data_context=None,
         expectations=None,
         evaluation_parameters=None,
         data_asset_type=None,
         execution_engine_type=None,
         meta=None,
+        ge_cloud_id=None,
     ):
         self.expectation_suite_name = expectation_suite_name
+        self.ge_cloud_id = ge_cloud_id
+        self._data_context = data_context
+
         if expectations is None:
             expectations = []
         self.expectations = [
@@ -129,7 +135,10 @@ class ExpectationSuite(SerializableDictDot):
         if not isinstance(other, self.__class__):
             if isinstance(other, dict):
                 try:
-                    other = expectationSuiteSchema.load(other)
+                    other_dict: dict = expectationSuiteSchema.load(other)
+                    other: ExpectationSuite = ExpectationSuite(
+                        **other_dict, data_context=self._data_context
+                    )
                 except ValidationError:
                     logger.debug(
                         "Unable to evaluate equivalence of ExpectationConfiguration object with dict because "
@@ -172,6 +181,19 @@ class ExpectationSuite(SerializableDictDot):
     def __str__(self):
         return json.dumps(self.to_json_dict(), indent=2)
 
+    def __deepcopy__(self, memo: dict):
+        cls = self.__class__
+        result = cls.__new__(cls)
+
+        memo[id(self)] = result
+
+        attributes_to_copy = list(ExpectationSuiteSchema().fields.keys())
+        for key in attributes_to_copy:
+            setattr(result, key, deepcopy(getattr(self, key)))
+
+        setattr(result, "_data_context", self._data_context)
+        return result
+
     def to_json_dict(self):
         myself = expectationSuiteSchema.dump(self)
         # NOTE - JPC - 20191031: migrate to expectation-specific schemas that subclass result with properly-typed
@@ -197,10 +219,10 @@ class ExpectationSuite(SerializableDictDot):
 
     def get_citations(
         self,
-        sort: Optional[bool] = True,
-        require_batch_kwargs: Optional[bool] = False,
-        require_batch_request: Optional[bool] = False,
-        require_profiler_config: Optional[bool] = False,
+        sort: bool = True,
+        require_batch_kwargs: bool = False,
+        require_batch_request: bool = False,
+        require_profiler_config: bool = False,
     ) -> List[Dict[str, Any]]:
         citations: List[Dict[str, Any]] = self.meta.get("citations", [])
         if require_batch_kwargs:
@@ -261,15 +283,16 @@ class ExpectationSuite(SerializableDictDot):
 
     def remove_expectation(
         self,
-        expectation_configuration: ExpectationConfiguration,
+        expectation_configuration: Optional[ExpectationConfiguration] = None,
         match_type: str = "domain",
         remove_multiple_matches: bool = False,
+        ge_cloud_id: Optional[Union[str, uuid.UUID]] = None,
     ) -> List[ExpectationConfiguration]:
         """
 
         Args:
             expectation_configuration: A potentially incomplete (partial) Expectation Configuration to match against for
-                for the removal of expectations.
+                the removal of expectations.
             match_type: This determines what kwargs to use when matching. Options are 'domain' to match based
                 on the data evaluated by that expectation, 'success' to match based on all configuration parameters
                  that influence whether an expectation succeeds based on a given batch of data, and 'runtime' to match
@@ -281,8 +304,15 @@ class ExpectationSuite(SerializableDictDot):
             No match
             More than 1 match, if remove_multiple_matches = False
         """
+        if expectation_configuration is None and ge_cloud_id is None:
+            raise TypeError(
+                "Must provide either expectation_configuration or ge_cloud_id"
+            )
+
         found_expectation_indexes = self.find_expectation_indexes(
-            expectation_configuration, match_type
+            expectation_configuration=expectation_configuration,
+            match_type=match_type,
+            ge_cloud_id=ge_cloud_id,
         )
         if len(found_expectation_indexes) < 1:
             raise ValueError("No matching expectation was found.")
@@ -322,10 +352,14 @@ class ExpectationSuite(SerializableDictDot):
 
     def find_expectation_indexes(
         self,
-        expectation_configuration: ExpectationConfiguration,
+        expectation_configuration: Optional[ExpectationConfiguration] = None,
         match_type: str = "domain",
+        ge_cloud_id: str = None,
     ) -> List[int]:
         """
+        Find indexes of Expectations matching the given ExpectationConfiguration on the given match_type.
+        If a ge_cloud_id is provided, match_type is ignored and only indexes of Expectations
+        with matching ge_cloud_id are returned.
 
         Args:
             expectation_configuration: A potentially incomplete (partial) Expectation Configuration to match against to
@@ -334,6 +368,7 @@ class ExpectationSuite(SerializableDictDot):
                 on the data evaluated by that expectation, 'success' to match based on all configuration parameters
                  that influence whether an expectation succeeds based on a given batch of data, and 'runtime' to match
                  based on all configuration parameters
+            ge_cloud_id: Great Expectations Cloud id
 
         Returns: A list of indexes of matching ExpectationConfiguration
 
@@ -341,34 +376,108 @@ class ExpectationSuite(SerializableDictDot):
             InvalidExpectationConfigurationError
 
         """
-        if not isinstance(expectation_configuration, ExpectationConfiguration):
+        if expectation_configuration is None and ge_cloud_id is None:
+            raise TypeError(
+                "Must provide either expectation_configuration or ge_cloud_id"
+            )
+        if expectation_configuration and not isinstance(
+            expectation_configuration, ExpectationConfiguration
+        ):
             raise InvalidExpectationConfigurationError(
                 "Ensure that expectation configuration is valid."
             )
         match_indexes = []
         for idx, expectation in enumerate(self.expectations):
-            if expectation.isEquivalentTo(expectation_configuration, match_type):
-                match_indexes.append(idx)
+            if ge_cloud_id is not None:
+                if str(expectation.ge_cloud_id) == str(ge_cloud_id):
+                    match_indexes.append(idx)
+            else:
+                if expectation.isEquivalentTo(expectation_configuration, match_type):
+                    match_indexes.append(idx)
 
         return match_indexes
 
     def find_expectations(
         self,
-        expectation_configuration: ExpectationConfiguration,
+        expectation_configuration: Optional[ExpectationConfiguration] = None,
         match_type: str = "domain",
+        ge_cloud_id: Optional[str] = None,
     ) -> List[ExpectationConfiguration]:
+        """
+        Find Expectations matching the given ExpectationConfiguration on the given match_type.
+        If a ge_cloud_id is provided, match_type is ignored and only Expectations with matching
+        ge_cloud_id are returned.
+
+        Args:
+            expectation_configuration: A potentially incomplete (partial) Expectation Configuration to match against to
+                find the index of any matching Expectation Configurations on the suite.
+            match_type: This determines what kwargs to use when matching. Options are 'domain' to match based
+                on the data evaluated by that expectation, 'success' to match based on all configuration parameters
+                 that influence whether an expectation succeeds based on a given batch of data, and 'runtime' to match
+                 based on all configuration parameters
+            ge_cloud_id: Great Expectations Cloud id
+
+        Returns: A list of matching ExpectationConfigurations
+        """
+
+        if expectation_configuration is None and ge_cloud_id is None:
+            raise TypeError(
+                "Must provide either expectation_configuration or ge_cloud_id"
+            )
         found_expectation_indexes = self.find_expectation_indexes(
-            expectation_configuration, match_type
+            expectation_configuration, match_type, ge_cloud_id
         )
         if len(found_expectation_indexes) > 0:
-            return [
-                expectation
-                for idx, expectation in enumerate(self.expectations)
-                if idx in found_expectation_indexes
-            ]
+            return [self.expectations[idx] for idx in found_expectation_indexes]
         else:
             return []
 
+    def replace_expectation(
+        self,
+        new_expectation_configuration: Union[ExpectationConfiguration, dict],
+        existing_expectation_configuration: Optional[ExpectationConfiguration] = None,
+        match_type: str = "domain",
+        ge_cloud_id: Optional[str] = None,
+    ):
+        """
+        Find Expectations matching the given ExpectationConfiguration on the given match_type.
+        If a ge_cloud_id is provided, match_type is ignored and only Expectations with matching
+        ge_cloud_id are returned.
+
+        Args:
+            expectation_configuration: A potentially incomplete (partial) Expectation Configuration to match against to
+                find the index of any matching Expectation Configurations on the suite.
+            match_type: This determines what kwargs to use when matching. Options are 'domain' to match based
+                on the data evaluated by that expectation, 'success' to match based on all configuration parameters
+                 that influence whether an expectation succeeds based on a given batch of data, and 'runtime' to match
+                 based on all configuration parameters
+            ge_cloud_id: Great Expectations Cloud id
+
+        Returns: A list of matching ExpectationConfigurations
+        """
+        if existing_expectation_configuration is None and ge_cloud_id is None:
+            raise TypeError(
+                "Must provide either existing_expectation_configuration or ge_cloud_id"
+            )
+
+        if isinstance(new_expectation_configuration, dict):
+            new_expectation_configuration = expectationConfigurationSchema.load(
+                new_expectation_configuration
+            )
+
+        found_expectation_indexes = self.find_expectation_indexes(
+            existing_expectation_configuration, match_type, ge_cloud_id
+        )
+        if len(found_expectation_indexes) > 1:
+            raise ValueError(
+                "More than one matching expectation was found. Please be more specific with your search "
+                "criteria"
+            )
+        elif len(found_expectation_indexes) == 0:
+            raise ValueError("No matching Expectation was found.")
+
+        self.expectations[found_expectation_indexes[0]] = new_expectation_configuration
+
     def patch_expectation(
         self,
         expectation_configuration: ExpectationConfiguration,
@@ -409,6 +518,85 @@ class ExpectationSuite(SerializableDictDot):
         self.expectations[found_expectation_indexes[0]].patch(op, path, value)
         return self.expectations[found_expectation_indexes[0]]
 
+    def _add_expectation(
+        self,
+        expectation_configuration: ExpectationConfiguration,
+        send_usage_event: bool,
+        match_type: str = "domain",
+        overwrite_existing: bool = True,
+    ) -> ExpectationConfiguration:
+        """
+        This is a private method for adding expectations that allows for usage_events to be suppressed when
+        Expectations are added through internal processing (ie. while building profilers, rendering or validation). It
+        takes in send_usage_event boolean.
+
+        Args:
+            expectation_configuration: The ExpectationConfiguration to add or update
+            send_usage_event: Whether to send a usage_statistics event. When called through ExpectationSuite class'
+                public add_expectation() method, this is set to `True`.
+            match_type: The criteria used to determine whether the Suite already has an ExpectationConfiguration
+                and so whether we should add or replace.
+            overwrite_existing: If the expectation already exists, this will overwrite if True and raise an error if
+                False.
+        Returns:
+            The ExpectationConfiguration to add or replace.
+        Raises:
+            More than one match
+            One match if overwrite_existing = False
+        """
+
+        found_expectation_indexes = self.find_expectation_indexes(
+            expectation_configuration, match_type
+        )
+
+        if len(found_expectation_indexes) > 1:
+            if send_usage_event:
+                self.send_usage_event(success=False)
+            raise ValueError(
+                "More than one matching expectation was found. Please be more specific with your search "
+                "criteria"
+            )
+        elif len(found_expectation_indexes) == 1:
+            # Currently, we completely replace the expectation_configuration, but we could potentially use patch_expectation
+            # to update instead. We need to consider how to handle meta in that situation.
+            # patch_expectation = jsonpatch.make_patch(self.expectations[found_expectation_index] \
+            #   .kwargs, expectation_configuration.kwargs)
+            # patch_expectation.apply(self.expectations[found_expectation_index].kwargs, in_place=True)
+            if overwrite_existing:
+                # if existing Expectation has a ge_cloud_id, add it back to the new Expectation Configuration
+                existing_expectation_ge_cloud_id = self.expectations[
+                    found_expectation_indexes[0]
+                ].ge_cloud_id
+                if existing_expectation_ge_cloud_id is not None:
+                    expectation_configuration.ge_cloud_id = (
+                        existing_expectation_ge_cloud_id
+                    )
+                self.expectations[
+                    found_expectation_indexes[0]
+                ] = expectation_configuration
+            else:
+                if send_usage_event:
+                    self.send_usage_event(success=False)
+                raise DataContextError(
+                    "A matching ExpectationConfiguration already exists. If you would like to overwrite this "
+                    "ExpectationConfiguration, set overwrite_existing=True"
+                )
+        else:
+            self.append_expectation(expectation_configuration)
+        if send_usage_event:
+            self.send_usage_event(success=True)
+        return expectation_configuration
+
+    def send_usage_event(self, success: bool):
+        usage_stats_event_name: str = "expectation_suite.add_expectation"
+        usage_stats_event_payload: dict = {}
+        if self._data_context is not None:
+            self._data_context.send_usage_message(
+                event=usage_stats_event_name,
+                event_payload=usage_stats_event_payload,
+                success=success,
+            )
+
     def add_expectation(
         self,
         expectation_configuration: ExpectationConfiguration,
@@ -416,7 +604,6 @@ class ExpectationSuite(SerializableDictDot):
         overwrite_existing: bool = True,
     ) -> ExpectationConfiguration:
         """
-
         Args:
             expectation_configuration: The ExpectationConfiguration to add or update
             match_type: The criteria used to determine whether the Suite already has an ExpectationConfiguration
@@ -429,38 +616,56 @@ class ExpectationSuite(SerializableDictDot):
             More than one match
             One match if overwrite_existing = False
         """
-        found_expectation_indexes = self.find_expectation_indexes(
-            expectation_configuration, match_type
+        return self._add_expectation(
+            expectation_configuration=expectation_configuration,
+            send_usage_event=True,
+            match_type=match_type,
+            overwrite_existing=overwrite_existing,
         )
 
-        if len(found_expectation_indexes) > 1:
-            raise ValueError(
-                "More than one matching expectation was found. Please be more specific with your search "
-                "criteria"
-            )
-        elif len(found_expectation_indexes) == 1:
-            # Currently, we completely replace the expectation_configuration, but we could potentially use patch_expectation
-            # to update instead. We need to consider how to handle meta in that situation.
-            # patch_expectation = jsonpatch.make_patch(self.expectations[found_expectation_index] \
-            #   .kwargs, expectation_configuration.kwargs)
-            # patch_expectation.apply(self.expectations[found_expectation_index].kwargs, in_place=True)
-            if overwrite_existing:
-                self.expectations[
-                    found_expectation_indexes[0]
-                ] = expectation_configuration
-            else:
-                raise DataContextError(
-                    "A matching ExpectationConfiguration already exists. If you would like to overwrite this "
-                    "ExpectationConfiguration, set overwrite_existing=True"
-                )
-        else:
-            self.append_expectation(expectation_configuration)
+    def get_grouped_and_ordered_expectations_by_column(
+        self, expectation_type_filter: Optional[str] = None
+    ) -> Tuple[Dict[str, List[ExpectationConfiguration]], List[str]]:
+        expectations_by_column = {}
+        ordered_columns = []
 
-        return expectation_configuration
+        for expectation in self.expectations:
+            if "column" in expectation.kwargs:
+                column = expectation.kwargs["column"]
+            else:
+                column = "_nocolumn"
+            if column not in expectations_by_column:
+                expectations_by_column[column] = []
+
+            if (
+                expectation_type_filter is None
+                or expectation.expectation_type == expectation_type_filter
+            ):
+                expectations_by_column[column].append(expectation)
+
+            # if possible, get the order of columns from expect_table_columns_to_match_ordered_list
+            if (
+                expectation.expectation_type
+                == "expect_table_columns_to_match_ordered_list"
+            ):
+                exp_column_list = expectation.kwargs["column_list"]
+                if exp_column_list and len(exp_column_list) > 0:
+                    ordered_columns = exp_column_list
+
+        # Group items by column
+        sorted_columns = sorted(list(expectations_by_column.keys()))
+
+        # only return ordered columns from expect_table_columns_to_match_ordered_list evr if they match set of column
+        # names from entire evr, else use alphabetic sort
+        if set(sorted_columns) == set(ordered_columns):
+            return expectations_by_column, ordered_columns
+        else:
+            return expectations_by_column, sorted_columns
 
 
 class ExpectationSuiteSchema(Schema):
     expectation_suite_name = fields.Str()
+    ge_cloud_id = fields.UUID(required=False, allow_none=True)
     expectations = fields.List(fields.Nested(ExpectationConfigurationSchema))
     evaluation_parameters = fields.Dict(allow_none=True)
     data_asset_type = fields.Str(allow_none=True)
@@ -469,31 +674,42 @@ class ExpectationSuiteSchema(Schema):
     # NOTE: 20191107 - JPC - we may want to remove clean_empty and update tests to require the other fields;
     # doing so could also allow us not to have to make a copy of data in the pre_dump method.
     def clean_empty(self, data):
-        if not hasattr(data, "evaluation_parameters"):
-            pass
-        elif len(data.evaluation_parameters) == 0:
-            del data.evaluation_parameters
+        if isinstance(data, ExpectationSuite):
+            if not hasattr(data, "evaluation_parameters"):
+                pass
+            elif len(data.evaluation_parameters) == 0:
+                del data.evaluation_parameters
 
-        if not hasattr(data, "meta"):
-            pass
-        elif data.meta is None or data.meta == []:
-            pass
-        elif len(data.meta) == 0:
-            del data.meta
+            if not hasattr(data, "meta"):
+                pass
+            elif data.meta is None or data.meta == []:
+                pass
+            elif len(data.meta) == 0:
+                del data.meta
+        elif isinstance(data, dict):
+            if not data.get("evaluation_parameters"):
+                pass
+            elif len(data.get("evaluation_parameters")) == 0:
+                data.pop("evaluation_parameters")
+
+            if not data.get("meta"):
+                pass
+            elif data.get("meta") is None or data.get("meta") == []:
+                pass
+            elif len(data.get("meta")) == 0:
+                data.pop("meta")
         return data
 
     # noinspection PyUnusedLocal
     @pre_dump
     def prepare_dump(self, data, **kwargs):
         data = deepcopy(data)
-        data.meta = convert_to_json_serializable(data.meta)
+        if isinstance(data, ExpectationSuite):
+            data.meta = convert_to_json_serializable(data.meta)
+        elif isinstance(data, dict):
+            data["meta"] = convert_to_json_serializable(data.get("meta"))
         data = self.clean_empty(data)
         return data
 
-    # noinspection PyUnusedLocal
-    @post_load
-    def make_expectation_suite(self, data, **kwargs):
-        return ExpectationSuite(**data)
-
 
 expectationSuiteSchema = ExpectationSuiteSchema()
