@@ -1,3 +1,5 @@
+from typing import Optional
+
 from great_expectations.checkpoint import Checkpoint, SimpleCheckpoint
 from great_expectations.core.usage_statistics.anonymizers.anonymizer import Anonymizer
 
@@ -9,19 +11,18 @@ class CheckpointAnonymizer(Anonymizer):
         # ordered bottom up in terms of inheritance order
         self._ge_classes = [SimpleCheckpoint, Checkpoint]
 
-    def anonymize_checkpoint_info(self, name, config):
-        anonymized_info_dict = {}
-        anonymized_info_dict["anonymized_name"] = self.anonymize(name)
-
+    def anonymize_checkpoint_info(self, name: str, config: dict) -> dict:
+        anonymized_info_dict: dict = {
+            "anonymized_name": self.anonymize(name),
+        }
         self.anonymize_object_info(
             anonymized_info_dict=anonymized_info_dict,
             ge_classes=self._ge_classes,
             object_config=config,
         )
-
         return anonymized_info_dict
 
-    def is_parent_class_recognized(self, config):
+    def is_parent_class_recognized(self, config) -> Optional[str]:
         return self._is_parent_class_recognized(
             classes_to_check=self._ge_classes,
             object_config=config,
