@@ -1,4 +1,8 @@
 from great_expectations.core.usage_statistics.anonymizers.anonymizer import Anonymizer
+from great_expectations.data_context.types.base import (
+    ExecutionEngineConfig,
+    executionEngineConfigSchema,
+)
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -23,10 +27,18 @@ class ExecutionEngineAnonymizer(Anonymizer):
         anonymized_info_dict = {}
         anonymized_info_dict["anonymized_name"] = self.anonymize(name)
 
+        # Roundtrip through schema validation to add any missing fields
+        execution_engine_config: ExecutionEngineConfig = (
+            executionEngineConfigSchema.load(config)
+        )
+        execution_engine_config_dict: dict = executionEngineConfigSchema.dump(
+            execution_engine_config
+        )
+
         self.anonymize_object_info(
             anonymized_info_dict=anonymized_info_dict,
             ge_classes=self._ge_classes,
-            object_config=config,
+            object_config=execution_engine_config_dict,
         )
 
         return anonymized_info_dict
