@@ -31,8 +31,10 @@ logger = logging.getLogger(__name__)
 
 try:
     import sqlalchemy
+    from sqlalchemy.engine.row import LegacyRow
 except ImportError:
     sqlalchemy = None
+    LegacyRow = None
     logger.debug("Unable to load SqlAlchemy or one of its subclasses.")
 
 
@@ -69,23 +71,37 @@ _SUFFIX_TO_PD_KWARG = {"gz": "gzip", "zip": "zip", "bz2": "bz2", "xz": "xz"}
 
 
 def nested_update(
-    d: Union[Iterable, dict], u: Union[Iterable, dict], dedup: bool = False
+    d: Union[Iterable, dict],
+    u: Union[Iterable, dict],
+    dedup: bool = False,
+    concat_lists: bool = True,
 ):
-    """update d with items from u, recursively and joining elements"""
+    """
+    Update d with items from u, recursively and joining elements. By default, list values are
+    concatenated without de-duplication. If concat_lists is set to False, lists in u (new dict)
+    will replace those in d (base dict).
+    """
     for k, v in u.items():
         if isinstance(v, Mapping):
             d[k] = nested_update(d.get(k, {}), v, dedup=dedup)
         elif isinstance(v, set) or (k in d and isinstance(d[k], set)):
             s1 = d.get(k, set())
             s2 = v or set()
-            d[k] = s1 | s2
+
+            if concat_lists:
+                d[k] = s1 | s2
+            else:
+                d[k] = s2
         elif isinstance(v, list) or (k in d and isinstance(d[k], list)):
             l1 = d.get(k, [])
             l2 = v or []
-            if dedup:
-                d[k] = list(set(l1 + l2))
+            if concat_lists:
+                if dedup:
+                    d[k] = list(set(l1 + l2))
+                else:
+                    d[k] = l1 + l2
             else:
-                d[k] = l1 + l2
+                d[k] = l2
         else:
             d[k] = v
     return d
@@ -159,6 +175,12 @@ def convert_to_json_serializable(data):
         # to the number of digits for which the string representation will equal the float representation
         return [convert_to_json_serializable(x) for x in data.tolist()]
 
+    if isinstance(data, np.int64):
+        return int(data)
+
+    if isinstance(data, np.float64):
+        return float(data)
+
     if isinstance(data, (datetime.datetime, datetime.date)):
         return data.isoformat()
 
@@ -186,7 +208,7 @@ def convert_to_json_serializable(data):
     try:
         if not isinstance(data, list) and pd.isna(data):
             # pd.isna is functionally vectorized, but we only want to apply this to single objects
-            # Hence, why we test for `not isinstance(list))`
+            # Hence, why we test for `not isinstance(list)`
             return None
     except TypeError:
         pass
@@ -216,6 +238,10 @@ def convert_to_json_serializable(data):
             dict(zip(data.schema.names, zip(*data.collect())))
         )
 
+    # SQLAlchemy serialization
+    if LegacyRow and isinstance(data, LegacyRow):
+        return dict(data)
+
     if isinstance(data, decimal.Decimal):
         if requires_lossy_conversion(data):
             logger.warning(
@@ -404,23 +430,70 @@ def datetime_to_int(dt: datetime.date) -> int:
     return int(dt.strftime("%Y%m%d%H%M%S"))
 
 
+# noinspection SpellCheckingInspection
 class AzureUrl:
     """
-    Parses an Azure Blob Storage URL into its separate components
+    Parses an Azure Blob Storage URL into its separate components.
+    Formats:
+        WASBS (for Spark): "wasbs://<CONTAINER>@<ACCOUNT_NAME>.blob.core.windows.net/<BLOB>"
+        HTTP(S) (for Pandas) "<ACCOUNT_NAME>.blob.core.windows.net/<CONTAINER>/<BLOB>"
+
+        Reference: WASBS -- Windows Azure Storage Blob (https://datacadamia.com/azure/wasb).
     """
 
+    AZURE_BLOB_STORAGE_PROTOCOL_DETECTION_REGEX_PATTERN: str = (
+        r"^[^@]+@.+\.blob\.core\.windows\.net\/.+$"
+    )
+
+    AZURE_BLOB_STORAGE_HTTPS_URL_REGEX_PATTERN: str = (
+        r"^(https?:\/\/)?(.+?)\.blob\.core\.windows\.net/([^/]+)/(.+)$"
+    )
+    AZURE_BLOB_STORAGE_HTTPS_URL_TEMPLATE: str = (
+        "{account_name}.blob.core.windows.net/{container}/{path}"
+    )
+
+    AZURE_BLOB_STORAGE_WASBS_URL_REGEX_PATTERN: str = (
+        r"^(wasbs?:\/\/)?([^/]+)@(.+?)\.blob\.core\.windows\.net/(.+)$"
+    )
+    AZURE_BLOB_STORAGE_WASBS_URL_TEMPLATE: str = (
+        "wasbs://{container}@{account_name}.blob.core.windows.net/{path}"
+    )
+
     def __init__(self, url: str):
         search = re.search(
-            r"^(?:https?://)?(.+?).blob.core.windows.net/([^/]+)/(.+)$", url
+            AzureUrl.AZURE_BLOB_STORAGE_PROTOCOL_DETECTION_REGEX_PATTERN, url
         )
-        self._account_name = search.group(1)
-        self._container = search.group(2)
-        self._blob = search.group(3)
+        if search is None:
+            search = re.search(AzureUrl.AZURE_BLOB_STORAGE_HTTPS_URL_REGEX_PATTERN, url)
+            assert (
+                search is not None
+            ), "The provided URL does not adhere to the format specified by the Azure SDK (<ACCOUNT_NAME>.blob.core.windows.net/<CONTAINER>/<BLOB>)"
+            self._protocol = search.group(1)
+            self._account_name = search.group(2)
+            self._container = search.group(3)
+            self._blob = search.group(4)
+        else:
+            search = re.search(AzureUrl.AZURE_BLOB_STORAGE_WASBS_URL_REGEX_PATTERN, url)
+            assert (
+                search is not None
+            ), "The provided URL does not adhere to the format specified by the Azure SDK (wasbs://<CONTAINER>@<ACCOUNT_NAME>.blob.core.windows.net/<BLOB>)"
+            self._protocol = search.group(1)
+            self._container = search.group(2)
+            self._account_name = search.group(3)
+            self._blob = search.group(4)
+
+    @property
+    def protocol(self):
+        return self._protocol
 
     @property
     def account_name(self):
         return self._account_name
 
+    @property
+    def account_url(self):
+        return f"{self.account_name}.blob.core.windows.net"
+
     @property
     def container(self):
         return self._container
@@ -430,8 +503,37 @@ class AzureUrl:
         return self._blob
 
 
+class GCSUrl:
+    """
+    Parses a Google Cloud Storage URL into its separate components
+    Format: gs://<BUCKET_OR_NAME>/<BLOB>
+    """
+
+    URL_REGEX_PATTERN: str = r"^gs://([^/]+)/(.+)$"
+
+    OBJECT_URL_TEMPLATE: str = "gs://{bucket_or_name}/{path}"
+
+    def __init__(self, url: str):
+        search = re.search(GCSUrl.URL_REGEX_PATTERN, url)
+        assert (
+            search is not None
+        ), "The provided URL does not adhere to the format specified by the GCS SDK (gs://<BUCKET_OR_NAME>/<BLOB>)"
+        self._bucket = search.group(1)
+        self._blob = search.group(2)
+
+    @property
+    def bucket(self):
+        return self._bucket
+
+    @property
+    def blob(self):
+        return self._blob
+
+
 # S3Url class courtesy: https://stackoverflow.com/questions/42641315/s3-urls-get-bucket-name-and-path
 class S3Url:
+    OBJECT_URL_TEMPLATE: str = "s3a://{bucket}/{path}"
+
     """
     >>> s = S3Url("s3://bucket/hello/world")
     >>> s.bucket
@@ -487,6 +589,38 @@ class S3Url:
         return self._parsed.geturl()
 
 
+class DBFSPath:
+    """
+    Methods for converting Databricks Filesystem (DBFS) paths
+    """
+
+    @staticmethod
+    def convert_to_protocol_version(path: str) -> str:
+        if re.search(r"^\/dbfs", path):
+            candidate = path.replace("/dbfs", "dbfs:", 1)
+            if candidate == "dbfs:":
+                # Must add trailing slash
+                return "dbfs:/"
+            else:
+                return candidate
+        elif re.search(r"^dbfs:", path):
+            if path == "dbfs:":
+                # Must add trailing slash
+                return "dbfs:/"
+            return path
+        else:
+            raise ValueError("Path should start with either /dbfs or dbfs:")
+
+    @staticmethod
+    def convert_to_file_semantics_version(path: str) -> str:
+        if re.search(r"^dbfs:", path):
+            return path.replace("dbfs:", "/dbfs", 1)
+        elif re.search("^/dbfs", path):
+            return path
+        else:
+            raise ValueError("Path should start with either /dbfs or dbfs:")
+
+
 def sniff_s3_compression(s3_url: S3Url) -> str:
     """Attempts to get read_csv compression from s3_url"""
     return _SUFFIX_TO_PD_KWARG.get(s3_url.suffix)
@@ -495,7 +629,7 @@ def sniff_s3_compression(s3_url: S3Url) -> str:
 # noinspection PyPep8Naming
 def get_or_create_spark_application(
     spark_config: Optional[Dict[str, str]] = None,
-    force_reuse_spark_context: Optional[bool] = False,
+    force_reuse_spark_context: bool = False,
 ):
     # Due to the uniqueness of SparkContext per JVM, it is impossible to change SparkSession configuration dynamically.
     # Attempts to circumvent this constraint cause "ValueError: Cannot run multiple SparkContexts at once" to be thrown.
