@@ -1,12 +1,17 @@
 import json
 import logging
 import random
+import uuid
 from typing import Dict
 
-from great_expectations.data_context.store import ConfigurationStore
+from great_expectations.data_context.store import (
+    ConfigurationStore,
+    GeCloudStoreBackend,
+)
 from great_expectations.data_context.types.base import CheckpointConfig
 from great_expectations.data_context.types.resource_identifiers import (
     ConfigurationIdentifier,
+    GeCloudIdentifier,
 )
 
 logger = logging.getLogger(__name__)
@@ -39,9 +44,14 @@ class CheckpointStore(ConfigurationStore):
         test_checkpoint_configuration: CheckpointConfig = CheckpointConfig(
             **{"name": test_checkpoint_name}
         )
-        test_key: ConfigurationIdentifier = self._key_class(
-            configuration_key=test_checkpoint_name
-        )
+        if self.ge_cloud_mode:
+            test_key: GeCloudIdentifier = self.key_class(
+                resource_type="contract", ge_cloud_id=str(uuid.uuid4())
+            )
+        else:
+            test_key: ConfigurationIdentifier = self.key_class(
+                configuration_key=test_checkpoint_name
+            )
 
         if pretty_print:
             print(f"Attempting to add a new test key {test_key} to Checkpoint store...")
