@@ -20,14 +20,28 @@ logger = logging.getLogger(__name__)
 
 
 class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
+    PAYLOAD_ATTRIBUTES_KEYS = {
+        "suite_validation_result": "result",
+        "contract": "checkpoint_config",
+        "data_context": "data_context_config",
+        "expectation_suite": "suite",
+        "rendered_data_doc": "rendered_data_doc",
+    }
+
+    ALLOWED_SET_KWARGS_BY_RESOURCE_TYPE = {
+        "expectation_suite": {"clause_id"},
+        "rendered_data_doc": {"source_type", "source_id"},
+        "suite_validation_result": {"contract_id", "expectation_suite_id"},
+    }
+
     def __init__(
         self,
         ge_cloud_credentials: Dict,
-        ge_cloud_base_url: Optional[str] = "https://app.greatexpectations.io/",
+        ge_cloud_base_url: str = "https://app.greatexpectations.io/",
         ge_cloud_resource_type: Optional[str] = None,
         ge_cloud_resource_name: Optional[str] = None,
-        suppress_store_backend_id: Optional[bool] = True,
-        manually_initialize_store_backend_id: Optional[str] = "",
+        suppress_store_backend_id: bool = True,
+        manually_initialize_store_backend_id: str = "",
         store_name: Optional[str] = None,
     ):
         super().__init__(
@@ -90,44 +104,100 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
     def _move(self):
         pass
 
-    def _set(self, key, value, **kwargs):
-        # Each resource type has corresponding attribute key to include in POST body
-        post_body_keys = {
-            "suite_validation_result": "result",
-            "checkpoint": "checkpoint_config",
-        }
-
-        resource_key = self.ge_cloud_resource_name
+    def _update(self, ge_cloud_id, value, **kwargs):
         resource_type = self.ge_cloud_resource_type
         account_id = self.ge_cloud_credentials["account_id"]
 
-        post_body_key = post_body_keys[resource_type]
+        attributes_key = self.PAYLOAD_ATTRIBUTES_KEYS[resource_type]
 
         data = {
             "data": {
                 "type": resource_type,
-                "attributes": {"account_id": account_id},
+                "id": ge_cloud_id,
+                "attributes": {
+                    attributes_key: value,
+                    "account_id": account_id,
+                },
             }
         }
 
-        data["data"]["attributes"][post_body_key] = value
+        url = urljoin(
+            self.ge_cloud_base_url,
+            f"accounts/"
+            f"{account_id}/"
+            f"{hyphen(self.ge_cloud_resource_name)}/"
+            f"{ge_cloud_id}",
+        )
+        try:
+            response = requests.patch(url, json=data, headers=self.auth_headers)
+            response_status_code = response.status_code
+
+            if response_status_code < 300:
+                return True
+            return False
+        except Exception as e:
+            logger.debug(str(e))
+            raise StoreBackendError(
+                "Unable to update object in GE Cloud Store Backend."
+            )
+
+    @property
+    def allowed_set_kwargs(self):
+        return self.ALLOWED_SET_KWARGS_BY_RESOURCE_TYPE.get(
+            self.ge_cloud_resource_type, set()
+        )
+
+    def validate_set_kwargs(self, kwargs):
+        kwarg_names = set(kwargs.keys())
+        if len(kwarg_names) == 0:
+            return True
+        if kwarg_names <= self.allowed_set_kwargs:
+            return True
+        if not (kwarg_names <= self.allowed_set_kwargs):
+            extra_kwargs = kwarg_names - self.allowed_set_kwargs
+            raise ValueError(f'Invalid kwargs: {(", ").join(extra_kwargs)}')
+
+    def _set(self, key, value, **kwargs):
+        # Each resource type has corresponding attribute key to include in POST body
+        ge_cloud_id = key[1]
+
+        # if key has ge_cloud_id, perform _update instead
+        if ge_cloud_id:
+            return self._update(ge_cloud_id=ge_cloud_id, value=value, **kwargs)
+
+        resource_type = self.ge_cloud_resource_type
+        resource_name = self.ge_cloud_resource_name
+        account_id = self.ge_cloud_credentials["account_id"]
+
+        attributes_key = self.PAYLOAD_ATTRIBUTES_KEYS[resource_type]
+
+        data = {
+            "data": {
+                "type": resource_type,
+                "attributes": {
+                    "account_id": account_id,
+                    attributes_key: value,
+                    **(kwargs if self.validate_set_kwargs(kwargs) else {}),
+                },
+            }
+        }
 
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/" f"{account_id}/" f"{hyphen(resource_key)}",
+            f"accounts/" f"{account_id}/" f"{hyphen(resource_name)}",
         )
         try:
             response = requests.post(url, json=data, headers=self.auth_headers)
             response_json = response.json()
 
             object_id = response_json["data"]["id"]
-            object_url = self.get_url_for_key((object_id,))
+            object_url = self.get_url_for_key((self.ge_cloud_resource_type, object_id))
             return GeCloudResourceRef(
-                resource_type=self.ge_cloud_resource_type,
+                resource_type=resource_type,
                 ge_cloud_id=object_id,
                 url=object_url,
             )
-        # TODO: [Robby] Show more detailed error messages
+        # TODO Show more detailed error messages
         except Exception as e:
             logger.debug(str(e))
             raise StoreBackendError("Unable to set object in GE Cloud Store Backend.")
@@ -158,17 +228,23 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
         try:
             response = requests.get(url, headers=self.auth_headers)
             response_json = response.json()
-            keys = [(resource["id"],) for resource in response_json.get("data")]
+            keys = [
+                (
+                    self.ge_cloud_resource_type,
+                    resource["id"],
+                )
+                for resource in response_json.get("data")
+            ]
             return keys
         except Exception as e:
             logger.debug(str(e))
             raise StoreBackendError("Unable to list keys in GE Cloud Store Backend.")
 
     def get_url_for_key(self, key, protocol=None):
-        ge_cloud_id = key[0]
+        ge_cloud_id = key[1]
         url = urljoin(
             self.ge_cloud_base_url,
-            f"accounts/{self.ge_cloud_credentials['account_id']}/{self.ge_cloud_resource_name}/{ge_cloud_id}",
+            f"accounts/{self.ge_cloud_credentials['account_id']}/{hyphen(self.ge_cloud_resource_name)}/{ge_cloud_id}",
         )
         return url
 
@@ -176,7 +252,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
         if not isinstance(key, tuple):
             key = key.to_tuple()
 
-        ge_cloud_id = key[0]
+        ge_cloud_id = key[1]
 
         data = {
             "data": {
@@ -192,7 +268,7 @@ class GeCloudStoreBackend(StoreBackend, metaclass=ABCMeta):
             self.ge_cloud_base_url,
             f"accounts/"
             f"{self.ge_cloud_credentials['account_id']}/"
-            f"{self.ge_cloud_resource_name}/"
+            f"{hyphen(self.ge_cloud_resource_name)}/"
             f"{ge_cloud_id}",
         )
         try:
