@@ -7,6 +7,7 @@ from great_expectations.data_context.store.ge_cloud_store_backend import (
     GeCloudStoreBackend,
 )
 from great_expectations.data_context.store.store_backend import StoreBackend
+from great_expectations.data_context.types.resource_identifiers import GeCloudIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError, DataContextError
 
@@ -72,12 +73,16 @@ class Store:
         # STORE_BACKEND_ID_KEY always validated
         if key == StoreBackend.STORE_BACKEND_ID_KEY:
             return
-        elif not isinstance(key, self._key_class):
+        elif not isinstance(key, self.key_class):
             raise TypeError(
                 "key must be an instance of %s, not %s"
-                % (self._key_class.__name__, type(key))
+                % (self.key_class.__name__, type(key))
             )
 
+    @property
+    def ge_cloud_mode(self):
+        return isinstance(self._store_backend, GeCloudStoreBackend)
+
     @property
     def store_backend(self):
         return self._store_backend
@@ -95,6 +100,12 @@ class Store:
         """
         return self._store_backend.store_backend_id
 
+    @property
+    def key_class(self):
+        if self.ge_cloud_mode:
+            return GeCloudIdentifier
+        return self._key_class
+
     @property
     def store_backend_id_warnings_suppressed(self):
         """
@@ -117,11 +128,9 @@ class Store:
     def tuple_to_key(self, tuple_):
         if tuple_ == StoreBackend.STORE_BACKEND_ID_KEY:
             return StoreBackend.STORE_BACKEND_ID_KEY[0]
-        if isinstance(self._store_backend, GeCloudStoreBackend):
-            return self._key_class.from_ge_tuple(tuple_)
         if self._use_fixed_length_key:
-            return self._key_class.from_fixed_length_tuple(tuple_)
-        return self._key_class.from_tuple(tuple_)
+            return self.key_class.from_fixed_length_tuple(tuple_)
+        return self.key_class.from_tuple(tuple_)
 
     # noinspection PyMethodMayBeStatic
     def deserialize(self, key, value):
@@ -130,7 +139,7 @@ class Store:
     def get(self, key):
         if key == StoreBackend.STORE_BACKEND_ID_KEY:
             return self._store_backend.get(key)
-        elif isinstance(self.store_backend, GeCloudStoreBackend):
+        elif self.ge_cloud_mode:
             self._validate_key(key)
             value = self._store_backend.get(self.key_to_tuple(key))
             # TODO [Robby] MER-285: Handle non-200 http errors
@@ -145,13 +154,13 @@ class Store:
         else:
             return None
 
-    def set(self, key, value):
+    def set(self, key, value, **kwargs):
         if key == StoreBackend.STORE_BACKEND_ID_KEY:
-            return self._store_backend.set(key, value)
+            return self._store_backend.set(key, value, **kwargs)
         else:
             self._validate_key(key)
             return self._store_backend.set(
-                self.key_to_tuple(key), self.serialize(key, value)
+                self.key_to_tuple(key), self.serialize(key, value), **kwargs
             )
 
     def list_keys(self):
