@@ -277,7 +277,14 @@ class MetaSparkDFDataset(Dataset):
                         eval_col_A, eval_col_B
                     ),
                 )
+            # elif ignore_row_if == "neither":
             elif ignore_row_if == "never":
+                """
+                TODO: <Alex>Note: The value of the "ignore_row_if" directive in the commented out line above is correct.
+                However, fixing the error would constitute a breaking change.  Hence, the documentation is updated now
+                (8/16/2021), while the implementation is corrected as part of the Expectations V3 API release.
+                </Alex>
+                """
                 boolean_mapped_null_values = cols_df.selectExpr(
                     "`__row`",
                     "`{0}` AS `A_{0}`".format(eval_col_A),
