@@ -1,5 +1,5 @@
 from copy import deepcopy
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Tuple
 
 from great_expectations.core.batch import (
     BatchDefinition,
@@ -268,8 +268,10 @@ class ConfiguredAssetSqlDataConnector(DataConnector):
         """Split using the values in the named column"""
         # query = f"SELECT DISTINCT(\"{self.column_name}\") FROM {self.table_name}"
 
-        return sa.select([sa.func.distinct(sa.column(column_name))]).select_from(
-            sa.text(table_name)
+        return (
+            sa.select([sa.func.distinct(sa.column(column_name))])
+            .select_from(sa.text(table_name))
+            .order_by(sa.column(column_name).asc())
         )
 
     def _split_on_converted_datetime(
