@@ -2,15 +2,22 @@ import logging
 from copy import deepcopy
 from typing import Any, List, Optional, Tuple
 
-from great_expectations.core.batch import BatchDefinition, BatchMarkers, BatchRequest
+import great_expectations.exceptions as ge_exceptions
+from great_expectations.core.batch import (
+    BatchDefinition,
+    BatchMarkers,
+    BatchRequest,
+    BatchRequestBase,
+)
 from great_expectations.core.id_dict import BatchSpec
 from great_expectations.execution_engine import ExecutionEngine
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 from great_expectations.validator.validator import Validator
 
 logger = logging.getLogger(__name__)
 
 
+# noinspection SpellCheckingInspection
 class DataConnector:
     """
     DataConnectors produce identifying information, called "batch_spec" that ExecutionEngines
@@ -37,7 +44,7 @@ class DataConnector:
         self,
         name: str,
         datasource_name: str,
-        execution_engine: Optional[ExecutionEngine] = None,
+        execution_engine: ExecutionEngine,
         batch_spec_passthrough: Optional[dict] = None,
     ):
         """
@@ -46,9 +53,14 @@ class DataConnector:
         Args:
             name (str): required name for DataConnector
             datasource_name (str): required name for datasource
-            execution_engine (ExecutionEngine): optional reference to ExecutionEngine
+            execution_engine (ExecutionEngine): reference to ExecutionEngine
             batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
         """
+        if execution_engine is None:
+            raise ge_exceptions.DataConnectorError(
+                "A non-existent/unknown ExecutionEngine instance was referenced."
+            )
+
         self._name = name
         self._datasource_name = datasource_name
         self._execution_engine = execution_engine
@@ -71,6 +83,10 @@ class DataConnector:
     def datasource_name(self) -> str:
         return self._datasource_name
 
+    @property
+    def execution_engine(self) -> ExecutionEngine:
+        return self._execution_engine
+
     @property
     def data_context_root_directory(self) -> str:
         return self._data_context_root_directory
@@ -168,6 +184,16 @@ class DataConnector:
         """
         raise NotImplementedError
 
+    def get_available_data_asset_names_and_types(self) -> List[Tuple[str, str]]:
+        """
+        Return the list of asset names and types known by this DataConnector.
+
+        Returns:
+            A list of tuples consisting of available names and types
+        """
+        # NOTE: Josh 20211001 only implemented in InferredAssetSqlDataConnector
+        raise NotImplementedError
+
     def get_batch_definition_list_from_batch_request(
         self,
         batch_request: BatchRequest,
@@ -337,8 +363,7 @@ class DataConnector:
         assert len(batch_definition_list) == 1
         batch_definition: BatchDefinition = batch_definition_list[0]
 
-        # _execution_engine might be None for some tests
-        if batch_definition is None or self._execution_engine is None:
+        if batch_definition is None:
             return {}
 
         batch_data: Any
@@ -380,7 +405,7 @@ class DataConnector:
             "n_rows": n_rows,
         }
 
-    def _validate_batch_request(self, batch_request: BatchRequest):
+    def _validate_batch_request(self, batch_request: BatchRequestBase):
         """
         Validate batch_request by checking:
             1. if configured datasource_name matches batch_request's datasource_name
