@@ -6,8 +6,9 @@ import os
 import re
 import sre_constants
 import sre_parse
+import warnings
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple
 
 from great_expectations.core.batch import BatchDefinition, BatchRequestBase
 from great_expectations.core.id_dict import IDDict
@@ -17,13 +18,19 @@ from great_expectations.datasource.data_connector.sorter import Sorter
 logger = logging.getLogger(__name__)
 
 try:
-    from azure.storage.blob import BlobPrefix, BlobServiceClient, ContainerClient
+    from azure.storage.blob import BlobPrefix
 except ImportError:
     BlobPrefix = None
-    BlobServiceClient = None
-    ContainerClient = None
     logger.debug(
-        "Unable to load azure types; install optional azure dependency for support."
+        "Unable to load azure types; install optional Azure dependency for support."
+    )
+
+try:
+    from google.cloud import storage
+except ImportError:
+    storage = None
+    logger.debug(
+        "Unable to load GCS connection object; install optional Google dependency for support"
     )
 
 try:
@@ -33,7 +40,7 @@ except ImportError:
     pyspark = None
     pyspark_sql = None
     logger.debug(
-        "Unable to load pyspark and pyspark.sql; install optional spark dependency for support."
+        "Unable to load pyspark and pyspark.sql; install optional Spark dependency for support."
     )
 
 
@@ -130,20 +137,43 @@ def convert_data_reference_string_to_batch_identifiers_using_regex(
     group_names: List[str],
 ) -> Optional[Tuple[str, IDDict]]:
     # noinspection PyUnresolvedReferences
-    matches: Optional[re.Match] = re.match(regex_pattern, data_reference)
+    pattern = re.compile(regex_pattern)
+    matches: Optional[re.Match] = pattern.match(data_reference)
     if matches is None:
         return None
-    groups: list = list(matches.groups())
-    batch_identifiers: IDDict = IDDict(dict(zip(group_names, groups)))
+
+    # Check for `(?P<name>)` named group syntax
+    match_dict = matches.groupdict()
+    if match_dict:  # Only named groups will populate this dict
+        batch_identifiers = _determine_batch_identifiers_using_named_groups(
+            match_dict, group_names
+        )
+    else:
+        groups: list = list(matches.groups())
+        batch_identifiers: IDDict = IDDict(dict(zip(group_names, groups)))
 
     # TODO: <Alex>Accommodating "data_asset_name" inside batch_identifiers (e.g., via "group_names") is problematic; we need a better mechanism.</Alex>
     # TODO: <Alex>Update: Approach -- we can differentiate "def map_data_reference_string_to_batch_definition_list_using_regex(()" methods between ConfiguredAssetFilesystemDataConnector and InferredAssetFilesystemDataConnector so that IDDict never needs to include data_asset_name. (ref: https://superconductivedata.slack.com/archives/C01C0BVPL5Q/p1603843413329400?thread_ts=1603842470.326800&cid=C01C0BVPL5Q)</Alex>
-    data_asset_name: str = DEFAULT_DATA_ASSET_NAME
-    if "data_asset_name" in batch_identifiers:
-        data_asset_name = batch_identifiers.pop("data_asset_name")
+    data_asset_name: str = batch_identifiers.pop(
+        "data_asset_name", DEFAULT_DATA_ASSET_NAME
+    )
     return data_asset_name, batch_identifiers
 
 
+def _determine_batch_identifiers_using_named_groups(
+    match_dict: dict, group_names: List[str]
+) -> IDDict:
+    batch_identifiers = IDDict()
+    for key, value in match_dict.items():
+        if key in group_names:
+            batch_identifiers[key] = value
+        else:
+            logger.warn(
+                f"The named group '{key}' must explicitly be stated in group_names to be parsed"
+            )
+    return batch_identifiers
+
+
 def map_batch_definition_to_data_reference_string_using_regex(
     batch_definition: BatchDefinition,
     regex_pattern: str,
@@ -186,7 +216,7 @@ def convert_batch_identifiers_to_data_reference_string_using_regex(
         regex_pattern=regex_pattern,
         group_names=group_names,
     )
-    converted_string = filepath_template.format(**template_arguments)
+    converted_string: str = filepath_template.format(**template_arguments)
 
     return converted_string
 
@@ -291,7 +321,7 @@ def get_filesystem_one_level_directory_glob_path_list(
 
 
 def list_azure_keys(
-    azure: BlobServiceClient,
+    azure,
     query_options: dict,
     recursive: bool = False,
 ) -> List[str]:
@@ -315,7 +345,7 @@ def list_azure_keys(
         List of keys representing Azure file paths (as filtered by the query_options dict)
     """
     container: str = query_options["container"]
-    container_client: ContainerClient = azure.get_container_client(container)
+    container_client = azure.get_container_client(container)
 
     path_list: List[str] = []
 
@@ -333,6 +363,67 @@ def list_azure_keys(
     return path_list
 
 
+def list_gcs_keys(
+    gcs,
+    query_options: dict,
+    recursive: bool = False,
+) -> List[str]:
+    """
+    Utilizes the GCS connection object to retrieve blob names based on user-provided criteria.
+
+    For InferredAssetGCSDataConnector, we take `bucket_or_name` and `prefix` and search for files using RegEx at and below the level
+    specified by those parameters. However, for ConfiguredAssetGCSDataConnector, we take `bucket_or_name` and `prefix` and
+    search for files using RegEx only at the level specified by that bucket and prefix.
+
+    This restriction for the ConfiguredAssetGCSDataConnector is needed because paths on GCS are comprised not only the leaf file name
+    but the full path that includes both the prefix and the file name. Otherwise, in the situations where multiple data assets
+    share levels of a directory tree, matching files to data assets will not be possible due to the path ambiguity.
+
+    Please note that the SDK's `list_blobs` method takes in a `delimiter` key that drastically alters the traversal of a given bucket:
+        - If a delimiter is not set (default), the traversal is recursive and the output will contain all blobs in the current directory
+          as well as those in any nested directories.
+        - If a delimiter is set, the traversal will continue until that value is seen; as the default is "/", traversal will be scoped
+          within the current directory and end before visiting nested directories.
+
+    In order to provide users with finer control of their config while also ensuring output that is in line with the `recursive` arg,
+    we deem it appropriate to manually override the value of the delimiter only in cases where it is absolutely necessary.
+
+    Args:
+        gcs (storage.Client): GCS connnection object responsible for accessing bucket
+        query_options (dict): GCS query attributes ("bucket_or_name", "prefix", "delimiter", "max_results")
+        recursive (bool): True for InferredAssetGCSDataConnector and False for ConfiguredAssetGCSDataConnector (see above)
+
+    Returns:
+        List of keys representing GCS file paths (as filtered by the `query_options` dict)
+    """
+    # Delimiter determines whether or not traversal of bucket is recursive
+    # Manually set to appropriate default if not already set by user
+    delimiter = query_options["delimiter"]
+    if delimiter is None and not recursive:
+        warnings.warn(
+            'In order to access blobs with a ConfiguredAssetGCSDataConnector, \
+            the delimiter that has been passed to gcs_options in your config cannot be empty; \
+            please note that the value is being set to the default "/" in order to work with the Google SDK.'
+        )
+        query_options["delimiter"] = "/"
+    elif delimiter is not None and recursive:
+        warnings.warn(
+            "In order to access blobs with an InferredAssetGCSDataConnector, \
+            the delimiter that has been passed to gcs_options in your config must be empty; \
+            please note that the value is being set to None in order to work with the Google SDK."
+        )
+        query_options["delimiter"] = None
+
+    keys: List[str] = []
+    for blob in gcs.list_blobs(**query_options):
+        name: str = blob.name
+        if name.endswith("/"):  # GCS includes directories in blob output
+            continue
+        keys.append(name)
+
+    return keys
+
+
 def list_s3_keys(
     s3, query_options: dict, iterator_dict: dict, recursive: bool = False
 ) -> str:
