@@ -6,6 +6,7 @@ from urllib.parse import urlparse
 
 from great_expectations.core.batch import Batch, BatchMarkers
 from great_expectations.core.util import nested_update
+from great_expectations.data_context.types.base import ConcurrencyConfig
 from great_expectations.dataset.sqlalchemy_dataset import SqlAlchemyBatchReference
 from great_expectations.datasource import LegacyDatasource
 from great_expectations.exceptions import (
@@ -14,6 +15,7 @@ from great_expectations.exceptions import (
 )
 from great_expectations.types import ClassConfig
 from great_expectations.types.configurations import classConfigSchema
+from great_expectations.util import get_sqlalchemy_url, import_make_url
 
 logger = logging.getLogger(__name__)
 
@@ -22,6 +24,8 @@ try:
     from sqlalchemy import create_engine
     from sqlalchemy.sql.elements import quoted_name
 
+    make_url = import_make_url()
+
 except ImportError:
     sqlalchemy = None
     create_engine = None
@@ -235,34 +239,43 @@ class SqlAlchemyDatasource(LegacyDatasource):
             credentials = {}
 
         try:
-            # if an engine was provided, use that
+            # If an engine was provided, use that.
             if "engine" in kwargs:
                 self.engine = kwargs.pop("engine")
 
-            # if a connection string or url was provided, use that
-            elif "connection_string" in kwargs:
-                connection_string = kwargs.pop("connection_string")
-                self.engine = create_engine(connection_string, **kwargs)
-                connection = self.engine.connect()
-                connection.close()
-            elif "url" in credentials:
-                url = credentials.pop("url")
-                self.drivername = urlparse(url).scheme
-                self.engine = create_engine(url, **kwargs)
-                connection = self.engine.connect()
-                connection.close()
-
-            # Otherwise, connect using remaining kwargs
             else:
-                (
-                    options,
-                    create_engine_kwargs,
-                    drivername,
-                ) = self._get_sqlalchemy_connection_options(**kwargs)
-                self.drivername = drivername
-                self.engine = create_engine(options, **create_engine_kwargs)
-                connection = self.engine.connect()
-                connection.close()
+                concurrency = (
+                    data_context.concurrency
+                    if data_context is not None
+                    else ConcurrencyConfig()
+                )
+                concurrency.add_sqlalchemy_create_engine_parameters(kwargs)
+
+                # If a connection string or url was provided, use that.
+                if "connection_string" in kwargs:
+                    connection_string = kwargs.pop("connection_string")
+                    self.engine = create_engine(connection_string, **kwargs)
+                    connection = self.engine.connect()
+                    connection.close()
+                elif "url" in credentials:
+                    url = credentials.pop("url")
+                    parsed_url = make_url(url)
+                    self.drivername = parsed_url.drivername
+                    self.engine = create_engine(url, **kwargs)
+                    connection = self.engine.connect()
+                    connection.close()
+
+                # Otherwise, connect using remaining kwargs.
+                else:
+                    (
+                        options,
+                        create_engine_kwargs,
+                        drivername,
+                    ) = self._get_sqlalchemy_connection_options(**kwargs)
+                    self.drivername = drivername
+                    self.engine = create_engine(options, **create_engine_kwargs)
+                    connection = self.engine.connect()
+                    connection.close()
 
             # since we switched to lazy loading of Datasources when we initialise a DataContext,
             # the dialect of SQLAlchemy Datasources cannot be obtained reliably when we send
@@ -321,7 +334,7 @@ class SqlAlchemyDatasource(LegacyDatasource):
                     drivername, credentials
                 )
             else:
-                options = sqlalchemy.engine.url.URL(drivername, **credentials)
+                options = get_sqlalchemy_url(drivername, **credentials)
         return options, create_engine_kwargs, drivername
 
     def _get_sqlalchemy_key_pair_auth_url(self, drivername, credentials):
@@ -357,9 +370,7 @@ class SqlAlchemyDatasource(LegacyDatasource):
         credentials_driver_name = credentials.pop("drivername", None)
         create_engine_kwargs = {"connect_args": {"private_key": pkb}}
         return (
-            sqlalchemy.engine.url.URL(
-                drivername or credentials_driver_name, **credentials
-            ),
+            get_sqlalchemy_url(drivername or credentials_driver_name, **credentials),
             create_engine_kwargs,
         )
 
@@ -407,12 +418,6 @@ class SqlAlchemyDatasource(LegacyDatasource):
             limit = batch_kwargs.get("limit")
             offset = batch_kwargs.get("offset")
             if limit is not None or offset is not None:
-                # AWS Athena does not support offset
-                if (
-                    offset is not None
-                    and self.engine.dialect.name.lower() == "awsathena"
-                ):
-                    raise NotImplementedError("AWS Athena does not support OFFSET.")
                 logger.info(
                     "Generating query from table batch_kwargs based on limit and offset"
                 )
