@@ -7,27 +7,29 @@ import warnings
 from functools import reduce
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union
 
+from dateutil.parser import parse
+
 from great_expectations.core.batch import BatchMarkers
 from great_expectations.core.batch_spec import (
+    AzureBatchSpec,
     BatchSpec,
     PathBatchSpec,
     RuntimeDataBatchSpec,
 )
 from great_expectations.core.id_dict import IDDict
-from great_expectations.core.util import get_or_create_spark_application
+from great_expectations.core.util import AzureUrl, get_or_create_spark_application
 from great_expectations.exceptions import exceptions as ge_exceptions
 from great_expectations.execution_engine import ExecutionEngine
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 from ..exceptions import (
-    BatchKwargsError,
     BatchSpecError,
     ExecutionEngineError,
     GreatExpectationsError,
     ValidationError,
 )
 from ..expectations.row_conditions import parse_condition_to_spark
-from ..validator.validation_graph import MetricConfiguration
 from .sparkdf_batch_data import SparkDFBatchData
 
 logger = logging.getLogger(__name__)
@@ -35,36 +37,35 @@ logger = logging.getLogger(__name__)
 try:
     import pyspark
     import pyspark.sql.functions as F
+
+    # noinspection SpellCheckingInspection
+    import pyspark.sql.types as sparktypes
     from pyspark import SparkContext
     from pyspark.sql import DataFrame, SparkSession
-    from pyspark.sql.types import (
-        BooleanType,
-        DateType,
-        FloatType,
-        IntegerType,
-        StringType,
-        StructField,
-        StructType,
-    )
+    from pyspark.sql.readwriter import DataFrameReader
 except ImportError:
     pyspark = None
     SparkContext = None
     SparkSession = None
     DataFrame = None
+    DataFrameReader = None
     F = None
-    StructType = (None,)
-    StructField = (None,)
-    IntegerType = (None,)
-    FloatType = (None,)
-    StringType = (None,)
-    DateType = (None,)
-    BooleanType = (None,)
+    # noinspection SpellCheckingInspection
+    sparktypes = None
 
     logger.debug(
         "Unable to load pyspark; install optional spark dependency for support."
     )
 
 
+# noinspection SpellCheckingInspection
+def apply_dateutil_parse(column):
+    assert len(column.columns) == 1, "Expected DataFrame with 1 column"
+    col_name = column.columns[0]
+    _udf = F.udf(parse, sparktypes.TimestampType())
+    return column.withColumn(col_name, _udf(col_name))
+
+
 class SparkDFExecutionEngine(ExecutionEngine):
     """
     This class holds an attribute `spark_df` which is a spark.sql.DataFrame.
@@ -170,12 +171,16 @@ class SparkDFExecutionEngine(ExecutionEngine):
         self._spark_config = spark_config
         self.spark = spark
 
+        azure_options: dict = kwargs.pop("azure_options", {})
+        self._azure_options = azure_options
+
         super().__init__(*args, **kwargs)
 
         self._config.update(
             {
                 "persist": self._persist,
                 "spark_config": spark_config,
+                "azure_options": azure_options,
             }
         )
 
@@ -212,6 +217,14 @@ class SparkDFExecutionEngine(ExecutionEngine):
             }
         )
 
+        """
+        As documented in Azure DataConnector implementations, Pandas and Spark execution engines utilize separate path
+        formats for accessing Azure Blob Storage service.  However, Pandas and Spark execution engines utilize identical
+        path formats for accessing all other supported cloud storage services (AWS S3 and Google Cloud Storage).
+        Moreover, these formats (encapsulated in S3BatchSpec and GCSBatchSpec) extend PathBatchSpec (common to them).
+        Therefore, at the present time, all cases with the exception of Azure Blob Storage , are handled generically.
+        """
+
         batch_data: Any
         if isinstance(batch_spec, RuntimeDataBatchSpec):
             # batch_data != None is already checked when RuntimeDataBatchSpec is instantiated
@@ -222,14 +235,26 @@ class SparkDFExecutionEngine(ExecutionEngine):
 Please check your config."""
                 )
             batch_spec.batch_data = "SparkDataFrame"
-        elif isinstance(batch_spec, PathBatchSpec):
+
+        elif isinstance(batch_spec, AzureBatchSpec):
             reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options
+            reader_options: dict = batch_spec.reader_options or {}
             path: str = batch_spec.path
+            azure_url = AzureUrl(path)
             try:
-                reader_options = self.spark.read.options(**reader_options)
+                credential = self._azure_options.get("credential")
+                storage_account_url = azure_url.account_url
+                if credential:
+                    self.spark.conf.set(
+                        "fs.wasb.impl",
+                        "org.apache.hadoop.fs.azure.NativeAzureFileSystem",
+                    )
+                    self.spark.conf.set(
+                        "fs.azure.account.key." + storage_account_url, credential
+                    )
+                reader: DataFrameReader = self.spark.read.options(**reader_options)
                 reader_fn: Callable = self._get_reader_fn(
-                    reader=reader_options,
+                    reader=reader,
                     reader_method=reader_method,
                     path=path,
                 )
@@ -240,6 +265,31 @@ Please check your config."""
                     Unable to load pyspark. Pyspark is required for SparkDFExecutionEngine.
                     """
                 )
+
+        elif isinstance(batch_spec, PathBatchSpec):
+            reader_method: str = batch_spec.reader_method
+            reader_options: dict = batch_spec.reader_options or {}
+            path: str = batch_spec.path
+            try:
+                reader: DataFrameReader = self.spark.read.options(**reader_options)
+                reader_fn: Callable = self._get_reader_fn(
+                    reader=reader,
+                    reader_method=reader_method,
+                    path=path,
+                )
+                batch_data = reader_fn(path)
+            except AttributeError:
+                raise ExecutionEngineError(
+                    """
+                    Unable to load pyspark. Pyspark is required for SparkDFExecutionEngine.
+                    """
+                )
+            # pyspark will raise an AnalysisException error if path is incorrect
+            except pyspark.sql.utils.AnalysisException:
+                raise ExecutionEngineError(
+                    f"""Unable to read in batch from the following path: {path}. Please check your configuration."""
+                )
+
         else:
             raise BatchSpecError(
                 """
@@ -264,10 +314,11 @@ Please check your config."""
             batch_data = sampling_fn(batch_data, **sampling_kwargs)
         return batch_data
 
+    # TODO: <Alex>Similar to Abe's note in PandasExecutionEngine: Any reason this shouldn't be a private method?</Alex>
     @staticmethod
     def guess_reader_method_from_path(path):
         """Based on a given filepath, decides a reader method. Currently supports tsv, csv, and parquet. If none of these
-        file extensions are used, returns BatchKwargsError stating that it is unable to determine the current path.
+        file extensions are used, returns ExecutionEngineError stating that it is unable to determine the current path.
 
         Args:
             path - A given file path
@@ -281,8 +332,8 @@ Please check your config."""
         elif path.endswith(".parquet"):
             return "parquet"
 
-        raise BatchKwargsError(
-            "Unable to determine reader method from path: %s" % path, {"path": path}
+        raise ExecutionEngineError(
+            "Unable to determine reader method from path: %s" % path
         )
 
     def _get_reader_fn(self, reader, reader_method=None, path=None):
@@ -298,9 +349,8 @@ Please check your config."""
 
         """
         if reader_method is None and path is None:
-            raise BatchKwargsError(
-                "Unable to determine spark reader function without reader_method or path.",
-                {"reader_method": reader_method},
+            raise ExecutionEngineError(
+                "Unable to determine spark reader function without reader_method or path"
             )
 
         if reader_method is None:
@@ -312,9 +362,8 @@ Please check your config."""
                 return reader.format(reader_method_op).load
             return getattr(reader, reader_method_op)
         except AttributeError:
-            raise BatchKwargsError(
+            raise ExecutionEngineError(
                 "Unable to find reader_method %s in spark." % reader_method,
-                {"reader_method": reader_method},
             )
 
     def get_domain_records(
@@ -410,16 +459,16 @@ Please check your config."""
             column_list = domain_kwargs["column_list"]
             ignore_row_if = domain_kwargs["ignore_row_if"]
             if ignore_row_if == "all_values_are_missing":
-                ignore_condition = reduce(
-                    lambda column_a, column_b: column_a.isNull() & column_b.isNull(),
-                    map(F.col, column_list),
-                )
+                conditions = [
+                    F.col(column_name).isNull() for column_name in column_list
+                ]
+                ignore_condition = reduce(lambda a, b: a & b, conditions)
                 data = data.filter(~ignore_condition)
             elif ignore_row_if == "any_value_is_missing":
-                ignore_condition = reduce(
-                    lambda column_a, column_b: column_a.isNull() | column_b.isNull(),
-                    map(F.col, column_list),
-                )
+                conditions = [
+                    F.col(column_name).isNull() for column_name in column_list
+                ]
+                ignore_condition = reduce(lambda a, b: a | b, conditions)
                 data = data.filter(~ignore_condition)
             else:
                 if ignore_row_if != "never":
@@ -438,8 +487,7 @@ Please check your config."""
         accessor_keys: Optional[Iterable[str]] = None,
     ) -> Tuple[DataFrame, dict, dict]:
         """Uses a given batch dictionary and domain kwargs (which include a row condition and a condition parser)
-        to obtain and/or query a batch. Returns in the format of a Pandas Series if only a single column is desired,
-        or otherwise a Data Frame.
+        to obtain and/or query a batch. Returns in the format of a Spark DataFrame.
 
         Args:
             domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
@@ -530,9 +578,14 @@ Please check your config."""
                     "column_list not found within domain_kwargs"
                 )
 
-            accessor_domain_kwargs["column_list"] = compute_domain_kwargs.pop(
-                "column_list"
-            )
+            column_list = compute_domain_kwargs.pop("column_list")
+
+            if len(column_list) < 2:
+                raise ge_exceptions.GreatExpectationsError(
+                    "column_list must contain at least 2 columns"
+                )
+
+            accessor_domain_kwargs["column_list"] = column_list
 
         return data, compute_domain_kwargs, accessor_domain_kwargs
 
@@ -584,7 +637,6 @@ Please check your config."""
 
                 Args:
                     metric_fn_bundle - A batch containing MetricEdgeKeys and their corresponding functions
-                    metrics (dict) - A dictionary containing metrics and corresponding parameters
 
                 Returns:
                     A dictionary of the collected metrics over their respective domains
@@ -676,7 +728,8 @@ Please check your config."""
         matching_divisor = batch_identifiers[column_name]
         res = (
             df.withColumn(
-                "div_temp", (F.col(column_name) / divisor).cast(IntegerType())
+                "div_temp",
+                (F.col(column_name) / divisor).cast(sparktypes.IntegerType()),
             )
             .filter(F.col("div_temp") == matching_divisor)
             .drop("div_temp")
@@ -688,7 +741,9 @@ Please check your config."""
         """Divide the values in the named column by `divisor`, and split on that"""
         matching_mod_value = batch_identifiers[column_name]
         res = (
-            df.withColumn("mod_temp", (F.col(column_name) % mod).cast(IntegerType()))
+            df.withColumn(
+                "mod_temp", (F.col(column_name) % mod).cast(sparktypes.IntegerType())
+            )
             .filter(F.col("mod_temp") == matching_mod_value)
             .drop("mod_temp")
         )
@@ -732,7 +787,7 @@ Please check your config."""
             hashed_value = hash_func(to_encode.encode()).hexdigest()[-1 * hash_digits :]
             return hashed_value
 
-        encrypt_udf = F.udf(_encrypt_value, StringType())
+        encrypt_udf = F.udf(_encrypt_value, sparktypes.StringType())
         res = (
             df.withColumn("encrypted_value", encrypt_udf(column_name))
             .filter(F.col("encrypted_value") == batch_identifiers["hash_value"])
@@ -760,7 +815,9 @@ Please check your config."""
     ):
         """Take the mod of named column, and only keep rows that match the given value"""
         res = (
-            df.withColumn("mod_temp", (F.col(column_name) % mod).cast(IntegerType()))
+            df.withColumn(
+                "mod_temp", (F.col(column_name) % mod).cast(sparktypes.IntegerType())
+            )
             .filter(F.col("mod_temp") == value)
             .drop("mod_temp")
         )
@@ -801,7 +858,7 @@ Please check your config."""
             ]
             return hashed_value
 
-        encrypt_udf = F.udf(_encrypt_value, StringType())
+        encrypt_udf = F.udf(_encrypt_value, sparktypes.StringType())
         res = (
             df.withColumn("encrypted_value", encrypt_udf(column_name))
             .filter(F.col("encrypted_value") == hash_value)
