@@ -98,6 +98,57 @@ class ExpectColumnMeanToBeBetween(ColumnExpectation):
         "catch_exceptions": False,
     }
 
+    kwargs_json_schema_base_properties = {
+        "result_format": {
+            "oneOf": [
+                {"type": "null"},
+                {
+                    "type": "string",
+                    "enum": ["BOOLEAN_ONLY", "BASIC", "SUMMARY", "COMPLETE"],
+                },
+                {
+                    "type": "object",
+                    "properties": {
+                        "result_format": {
+                            "type": "string",
+                            "enum": ["BOOLEAN_ONLY", "BASIC", "SUMMARY", "COMPLETE"],
+                        },
+                        "partial_unexpected_count": {"type": "number"},
+                    },
+                },
+            ],
+            "default": "BASIC",
+        },
+        "include_config": {
+            "oneOf": [{"type": "null"}, {"type": "boolean"}],
+            "default": "true",
+        },
+        "catch_exceptions": {
+            "oneOf": [{"type": "null"}, {"type": "boolean"}],
+            "default": "false",
+        },
+        "meta": {"type": "object"},
+    }
+
+    kwargs_json_schema = {
+        "type": "object",
+        "properties": {
+            **kwargs_json_schema_base_properties,
+            "column": {"type": "string"},
+            "min_value": {"oneOf": [{"type": "null"}, {"type": "number"}]},
+            "max_value": {"oneOf": [{"type": "null"}, {"type": "number"}]},
+            "strict_min": {
+                "oneOf": [{"type": "null"}, {"type": "boolean"}],
+                "default": "false",
+            },
+            "strict_max": {
+                "oneOf": [{"type": "null"}, {"type": "boolean"}],
+                "default": "false",
+            },
+        },
+        "required": ["column"],
+    }
+
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
         """
         Validates that a configuration has been set, and sets a configuration if it has yet to be set. Ensures that
@@ -112,6 +163,88 @@ class ExpectColumnMeanToBeBetween(ColumnExpectation):
         super().validate_configuration(configuration)
         self.validate_metric_value_between_configuration(configuration=configuration)
 
+    @classmethod
+    def _atomic_prescriptive_template(
+        cls,
+        configuration=None,
+        result=None,
+        language=None,
+        runtime_configuration=None,
+        **kwargs,
+    ):
+        runtime_configuration = runtime_configuration or {}
+        include_column_name = runtime_configuration.get("include_column_name", True)
+        include_column_name = (
+            include_column_name if include_column_name is not None else True
+        )
+        styling = runtime_configuration.get("styling")
+        params = substitute_none_for_missing(
+            configuration.kwargs,
+            [
+                "column",
+                "min_value",
+                "max_value",
+                "row_condition",
+                "condition_parser",
+                "strict_min",
+                "strict_max",
+            ],
+        )
+        params_with_json_schema = {
+            "column": {"schema": {"type": "string"}, "value": params.get("column")},
+            "min_value": {
+                "schema": {"type": "number"},
+                "value": params.get("min_value"),
+            },
+            "max_value": {
+                "schema": {"type": "number"},
+                "value": params.get("max_value"),
+            },
+            "row_condition": {
+                "schema": {"type": "string"},
+                "value": params.get("row_condition"),
+            },
+            "condition_parser": {
+                "schema": {"type": "string"},
+                "value": params.get("condition_parser"),
+            },
+            "strict_min": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_min"),
+            },
+            "strict_max": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_max"),
+            },
+        }
+
+        if (params["min_value"] is None) and (params["max_value"] is None):
+            template_str = "mean may have any numerical value."
+        else:
+            at_least_str, at_most_str = handle_strict_min_max(params)
+
+            if params["min_value"] is not None and params["max_value"] is not None:
+                template_str = f"mean must be {at_least_str} $min_value and {at_most_str} $max_value."
+            elif params["min_value"] is None:
+                template_str = f"mean must be {at_most_str} $max_value."
+            elif params["max_value"] is None:
+                template_str = f"mean must be {at_least_str} $min_value."
+
+        if include_column_name:
+            template_str = "$column " + template_str
+
+        if params["row_condition"] is not None:
+            (
+                conditional_template_str,
+                conditional_params,
+            ) = parse_row_condition_string_pandas_engine(
+                params["row_condition"], with_schema=True
+            )
+            template_str = conditional_template_str + ", then " + template_str
+            params_with_json_schema.update(conditional_params)
+
+        return (template_str, params_with_json_schema, styling)
+
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
     @render_evaluation_parameter_string
@@ -123,6 +256,7 @@ class ExpectColumnMeanToBeBetween(ColumnExpectation):
         runtime_configuration=None,
         **kwargs,
     ):
+
         runtime_configuration = runtime_configuration or {}
         include_column_name = runtime_configuration.get("include_column_name", True)
         include_column_name = (
