@@ -11,7 +11,7 @@ from ...render.util import (
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import ColumnMapExpectation, InvalidExpectationConfigurationError
+from ..expectation import ColumnMapExpectation
 
 
 class ExpectColumnValuesToBeBetween(ColumnMapExpectation):
@@ -103,7 +103,7 @@ class ExpectColumnValuesToBeBetween(ColumnMapExpectation):
         "max_value": None,
         "strict_min": False,
         "strict_max": False,  # tolerance=1e-9,
-        "parse_strings_as_datetimes": None,
+        "parse_strings_as_datetimes": False,
         "allow_cross_type_comparisons": None,
         "result_format": "BASIC",
         "include_config": True,
@@ -138,6 +138,105 @@ class ExpectColumnValuesToBeBetween(ColumnMapExpectation):
 
         self.validate_metric_value_between_configuration(configuration=configuration)
 
+    @classmethod
+    def _atomic_prescriptive_template(
+        cls,
+        configuration=None,
+        result=None,
+        language=None,
+        runtime_configuration=None,
+        **kwargs,
+    ):
+        runtime_configuration = runtime_configuration or {}
+        include_column_name = runtime_configuration.get("include_column_name", True)
+        include_column_name = (
+            include_column_name if include_column_name is not None else True
+        )
+        styling = runtime_configuration.get("styling")
+        params = substitute_none_for_missing(
+            configuration.kwargs,
+            [
+                "column",
+                "min_value",
+                "max_value",
+                "mostly",
+                "row_condition",
+                "condition_parser",
+                "strict_min",
+                "strict_max",
+            ],
+        )
+        params_with_json_schema = {
+            "column": {"schema": {"type": "string"}, "value": params.get("column")},
+            "min_value": {
+                "schema": {"type": "number"},
+                "value": params.get("min_value"),
+            },
+            "max_value": {
+                "schema": {"type": "number"},
+                "value": params.get("max_value"),
+            },
+            "mostly": {"schema": {"type": "number"}, "value": params.get("mostly")},
+            "mostly_pct": {
+                "schema": {"type": "number"},
+                "value": params.get("mostly_pct"),
+            },
+            "row_condition": {
+                "schema": {"type": "string"},
+                "value": params.get("row_condition"),
+            },
+            "condition_parser": {
+                "schema": {"type": "string"},
+                "value": params.get("condition_parser"),
+            },
+            "strict_min": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_min"),
+            },
+            "strict_max": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_max"),
+            },
+        }
+
+        template_str = ""
+        if (params["min_value"] is None) and (params["max_value"] is None):
+            template_str += "may have any numerical value."
+        else:
+            at_least_str, at_most_str = handle_strict_min_max(params)
+
+            mostly_str = ""
+            if params["mostly"] is not None:
+                params_with_json_schema["mostly_pct"]["value"] = num_to_str(
+                    params["mostly"] * 100, precision=15, no_scientific=True
+                )
+                # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
+                mostly_str = ", at least $mostly_pct % of the time"
+
+            if params["min_value"] is not None and params["max_value"] is not None:
+                template_str += f"values must be {at_least_str} $min_value and {at_most_str} $max_value{mostly_str}."
+
+            elif params["min_value"] is None:
+                template_str += f"values must be {at_most_str} $max_value{mostly_str}."
+
+            elif params["max_value"] is None:
+                template_str += f"values must be {at_least_str} $min_value{mostly_str}."
+
+        if include_column_name:
+            template_str = "$column " + template_str
+
+        if params["row_condition"] is not None:
+            (
+                conditional_template_str,
+                conditional_params,
+            ) = parse_row_condition_string_pandas_engine(
+                params["row_condition"], with_schema=True
+            )
+            template_str = conditional_template_str + ", then " + template_str
+            params_with_json_schema.update(conditional_params)
+
+        return (template_str, params_with_json_schema, styling)
+
     # NOTE: This method is a pretty good example of good usage of `params`.
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
