@@ -126,6 +126,78 @@ class ExpectColumnValuesToNotMatchRegex(ColumnMapExpectation):
             raise InvalidExpectationConfigurationError(str(e))
         return True
 
+    @classmethod
+    def _atomic_prescriptive_template(
+        cls,
+        configuration=None,
+        result=None,
+        language=None,
+        runtime_configuration=None,
+        **kwargs,
+    ):
+        runtime_configuration = runtime_configuration or {}
+        include_column_name = runtime_configuration.get("include_column_name", True)
+        include_column_name = (
+            include_column_name if include_column_name is not None else True
+        )
+        styling = runtime_configuration.get("styling")
+        params = substitute_none_for_missing(
+            configuration.kwargs,
+            ["column", "regex", "mostly", "row_condition", "condition_parser"],
+        )
+        params_with_json_schema = {
+            "column": {"schema": {"type": "string"}, "value": params.get("column")},
+            "regex": {"schema": {"type": "string"}, "value": params.get("regex")},
+            "mostly": {
+                "schema": {"type": "number"},
+                "value": params.get("mostly"),
+            },
+            "row_condition": {
+                "schema": {"type": "string"},
+                "value": params.get("row_condition"),
+            },
+            "condition_parser": {
+                "schema": {"type": "string"},
+                "value": params.get("condition_parser"),
+            },
+        }
+
+        if not params.get("regex"):
+            template_str = (
+                "values must not match a regular expression but none was specified."
+            )
+        else:
+            if params["mostly"] is not None:
+                params["mostly_pct"] = num_to_str(
+                    params["mostly"] * 100, precision=15, no_scientific=True
+                )
+                # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
+                if include_column_name:
+                    template_str = "$column values must not match this regular expression: $regex, at least $mostly_pct % of the time."
+                else:
+                    template_str = "values must not match this regular expression: $regex, at least $mostly_pct % of the time."
+            else:
+                if include_column_name:
+                    template_str = (
+                        "$column values must not match this regular expression: $regex."
+                    )
+                else:
+                    template_str = (
+                        "values must not match this regular expression: $regex."
+                    )
+
+        if params["row_condition"] is not None:
+            (
+                conditional_template_str,
+                conditional_params,
+            ) = parse_row_condition_string_pandas_engine(
+                params["row_condition"], with_schema=True
+            )
+            template_str = conditional_template_str + ", then " + template_str
+            params_with_json_schema.update(conditional_params)
+
+        return (template_str, params_with_json_schema, styling)
+
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
     @render_evaluation_parameter_string
