@@ -106,6 +106,55 @@ class ExpectTableColumnCountToBeBetween(TableExpectation):
         super().validate_configuration(configuration)
         self.validate_metric_value_between_configuration(configuration=configuration)
 
+    @classmethod
+    def _atomic_prescriptive_template(
+        cls,
+        configuration=None,
+        result=None,
+        language=None,
+        runtime_configuration=None,
+        **kwargs,
+    ):
+        runtime_configuration = runtime_configuration or {}
+        include_column_name = runtime_configuration.get("include_column_name", True)
+        include_column_name = (
+            include_column_name if include_column_name is not None else True
+        )
+        styling = runtime_configuration.get("styling")
+        params = substitute_none_for_missing(
+            configuration.kwargs,
+            ["min_value", "max_value", "strict_min", "strict_max"],
+        )
+        if params["min_value"] is None and params["max_value"] is None:
+            template_str = "May have any number of columns."
+        else:
+            at_least_str, at_most_str = handle_strict_min_max(params)
+            if params["min_value"] is not None and params["max_value"] is not None:
+                template_str = f"Must have {at_least_str} $min_value and {at_most_str} $max_value columns."
+            elif params["min_value"] is None:
+                template_str = f"Must have {at_most_str} $max_value columns."
+            elif params["max_value"] is None:
+                template_str = f"Must have {at_least_str} $min_value columns."
+        params_with_json_schema = {
+            "min_value": {
+                "schema": {"type": "number"},
+                "value": params.get("min_value"),
+            },
+            "max_value": {
+                "schema": {"type": "number"},
+                "value": params.get("max_value"),
+            },
+            "strict_min": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_min"),
+            },
+            "strict_max": {
+                "schema": {"type": "boolean"},
+                "value": params.get("strict_max"),
+            },
+        }
+        return (template_str, params_with_json_schema, styling)
+
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
     @render_evaluation_parameter_string
@@ -137,6 +186,7 @@ class ExpectTableColumnCountToBeBetween(TableExpectation):
                 template_str = f"Must have {at_most_str} $max_value columns."
             elif params["max_value"] is None:
                 template_str = f"Must have {at_least_str} $min_value columns."
+
         return [
             RenderedStringTemplateContent(
                 **{
