@@ -19,7 +19,7 @@ from great_expectations.expectations.metrics.column_aggregate_metric_provider im
     sa as sa,
 )
 from great_expectations.expectations.metrics.metric_provider import metric_value
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
 def unique_proportion(_metrics):
