@@ -1,6 +1,9 @@
-from typing import Any, Dict, Optional, Tuple
+import datetime
+import warnings
+from typing import Any, Dict, Optional
 
 import pandas as pd
+from dateutil.parser import parse
 
 from great_expectations.core import ExpectationConfiguration
 from great_expectations.execution_engine import (
@@ -12,35 +15,66 @@ from great_expectations.execution_engine.execution_engine import (
     MetricDomainTypes,
     MetricPartialFunctionTypes,
 )
-from great_expectations.execution_engine.sqlalchemy_execution_engine import (
-    SqlAlchemyExecutionEngine,
-)
 from great_expectations.expectations.metrics.import_manager import F, Window, sparktypes
 from great_expectations.expectations.metrics.map_metric_provider import (
     ColumnMapMetricProvider,
     column_condition_partial,
 )
-from great_expectations.expectations.metrics.metric_provider import (
-    metric_partial,
-    metric_value,
-)
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.expectations.metrics.metric_provider import metric_partial
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
 class ColumnValuesIncreasing(ColumnMapMetricProvider):
     condition_metric_name = "column_values.increasing"
-    condition_value_keys = ("strictly",)
-    default_kwarg_values = {"strictly": False}
+    condition_value_keys = (
+        "strictly",
+        "parse_strings_as_datetimes",
+    )
+    default_kwarg_values = {
+        "strictly": False,
+        "parse_strings_as_datetimes": False,
+    }
 
     @column_condition_partial(engine=PandasExecutionEngine)
-    def _pandas(cls, column, strictly=None, **kwargs):
-        series_diff = column.diff()
-        # The first element is null, so it gets a bye and is always treated as True
-        series_diff[series_diff.isnull()] = 1
+    def _pandas(
+        cls,
+        column,
+        **kwargs,
+    ):
+        parse_strings_as_datetimes: bool = (
+            kwargs.get("parse_strings_as_datetimes") or False
+        )
+        if parse_strings_as_datetimes:
+            warnings.warn(
+                """The parameter "parse_strings_as_datetimes" is no longer supported and will be deprecated in a \
+future release.  Please update code accordingly.
+""",
+                DeprecationWarning,
+            )
 
+            try:
+                temp_column = column.map(parse)
+            except TypeError:
+                temp_column = column
+        else:
+            temp_column = column
+
+        series_diff = temp_column.diff()
+        # The first element is null, so it gets a bye and is always treated as True
+        if parse_strings_as_datetimes:
+            series_diff[series_diff.isnull()] = datetime.timedelta(seconds=1)
+            series_diff = pd.to_timedelta(series_diff, unit="S")
+        else:
+            series_diff[series_diff.isnull()] = 1
+
+        strictly: bool = kwargs.get("strictly") or False
         if strictly:
+            if parse_strings_as_datetimes:
+                return series_diff.dt.total_seconds() > 0.0
             return series_diff > 0
         else:
+            if parse_strings_as_datetimes:
+                return series_diff.dt.total_seconds() >= 0.0
             return series_diff >= 0
 
     @metric_partial(
@@ -53,9 +87,20 @@ class ColumnValuesIncreasing(ColumnMapMetricProvider):
         execution_engine: SparkDFExecutionEngine,
         metric_domain_kwargs: Dict,
         metric_value_kwargs: Dict,
-        metrics: Dict[Tuple, Any],
+        metrics: Dict[str, Any],
         runtime_configuration: Dict,
     ):
+        parse_strings_as_datetimes: bool = (
+            metric_value_kwargs.get("parse_strings_as_datetimes") or False
+        )
+        if parse_strings_as_datetimes:
+            warnings.warn(
+                f"""The parameter "parse_strings_as_datetimes" is no longer supported and will be deprecated in a \
+future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._spark()", types are detected naturally.
+""",
+                DeprecationWarning,
+            )
+
         # check if column is any type that could have na (numeric types)
         column_name = metric_domain_kwargs["column"]
         table_columns = metrics["table.column_types"]
