@@ -5,6 +5,7 @@ import numpy as np
 from dateutil.parser import parse
 
 from great_expectations.execution_engine.util import check_sql_engine_dialect
+from great_expectations.util import get_sqlalchemy_inspector
 
 try:
     import psycopg2
@@ -23,20 +24,29 @@ try:
     from sqlalchemy.engine import Engine, reflection
     from sqlalchemy.engine.interfaces import Dialect
     from sqlalchemy.exc import OperationalError
-    from sqlalchemy.sql import Select
-    from sqlalchemy.sql.elements import BinaryExpression, TextClause, literal
+    from sqlalchemy.sql import Insert, Select
+    from sqlalchemy.sql.elements import (
+        BinaryExpression,
+        ColumnElement,
+        Label,
+        TextClause,
+        literal,
+    )
     from sqlalchemy.sql.operators import custom_op
 except ImportError:
     sa = None
     registry = None
-    Select = None
-    BinaryExpression = None
-    TextClause = None
-    literal = None
-    custom_op = None
     Engine = None
     reflection = None
     Dialect = None
+    Insert = None
+    Select = None
+    BinaryExpression = None
+    ColumnElement = None
+    Label = None
+    TextClause = None
+    literal = None
+    custom_op = None
     OperationalError = None
 
 try:
@@ -46,6 +56,13 @@ except ImportError:
 
 logger = logging.getLogger(__name__)
 
+try:
+    import sqlalchemy_dremio.pyodbc
+
+    registry.register("dremio", "sqlalchemy_dremio.pyodbc", "dialect")
+except ImportError:
+    sqlalchemy_dremio = None
+
 try:
     import pybigquery.sqlalchemy_bigquery
 
@@ -78,6 +95,13 @@ try:
 except ImportError:
     bigquery_types_tuple = None
     pybigquery = None
+    namedtuple = None
+
+try:
+    import teradatasqlalchemy.dialect
+    import teradatasqlalchemy.types as teradatatypes
+except ImportError:
+    teradatasqlalchemy = None
 
 
 def get_dialect_regex_expression(column, regex, dialect, positive=True):
@@ -93,6 +117,7 @@ def get_dialect_regex_expression(column, regex, dialect, positive=True):
 
     try:
         # redshift
+        # noinspection PyUnresolvedReferences
         if issubclass(dialect.dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
             if positive:
                 return BinaryExpression(column, literal(regex), custom_op("~"))
@@ -147,6 +172,29 @@ def get_dialect_regex_expression(column, regex, dialect, positive=True):
         )
         pass
 
+    try:
+        # Dremio
+        if hasattr(dialect, "DremioDialect"):
+            if positive:
+                return sa.func.REGEXP_MATCHES(column, literal(regex))
+            else:
+                return sa.not_(sa.func.REGEXP_MATCHES(column, literal(regex)))
+    except (
+        AttributeError,
+        TypeError,
+    ):  # TypeError can occur if the driver was not installed and so is None
+        pass
+
+    try:
+        # Teradata
+        if issubclass(dialect.dialect, teradatasqlalchemy.dialect.TeradataDialect):
+            if positive:
+                return sa.func.REGEXP_SIMILAR(column, literal(regex), literal("i")) == 1
+            else:
+                return sa.func.REGEXP_SIMILAR(column, literal(regex), literal("i")) == 0
+    except (AttributeError, TypeError):
+        pass
+
     return None
 
 
@@ -158,6 +206,7 @@ def _get_dialect_type_module(dialect=None):
         return sa
     try:
         # Redshift does not (yet) export types to top level; only recognize base SA types
+        # noinspection PyUnresolvedReferences
         if isinstance(dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
             return dialect.sa
     except (TypeError, AttributeError):
@@ -176,10 +225,24 @@ def _get_dialect_type_module(dialect=None):
     except (TypeError, AttributeError):
         pass
 
+    # Teradata types module
+    try:
+        if (
+            issubclass(
+                dialect,
+                teradatasqlalchemy.dialect.TeradataDialect,
+            )
+            and teradatatypes is not None
+        ):
+            return teradatatypes
+    except (TypeError, AttributeError):
+        pass
+
     return dialect
 
 
 def attempt_allowing_relative_error(dialect):
+    # noinspection PyUnresolvedReferences
     detected_redshift: bool = (
         sqlalchemy_redshift is not None
         and check_sql_engine_dialect(
@@ -220,12 +283,16 @@ def get_sqlalchemy_column_metadata(
     try:
         columns: List[Dict[str, Any]]
 
-        inspector: reflection.Inspector = reflection.Inspector.from_engine(engine)
+        inspector: reflection.Inspector = get_sqlalchemy_inspector(engine)
         try:
-            columns = inspector.get_columns(
-                table_selectable,
-                schema=schema_name,
-            )
+            # if a custom query was passed
+            if isinstance(table_selectable, TextClause):
+                columns = table_selectable.selected_columns.columns
+            else:
+                columns = inspector.get_columns(
+                    table_selectable,
+                    schema=schema_name,
+                )
         except (
             KeyError,
             AttributeError,
@@ -258,6 +325,7 @@ def column_reflection_fallback(
 ) -> List[Dict[str, str]]:
     """If we can't reflect the table, use a query to at least get column names."""
     col_info_dict_list: List[Dict[str, str]]
+    # noinspection PyUnresolvedReferences
     if dialect.name.lower() == "mssql":
         # Get column names and types from the database
         # Reference: https://dataedo.com/kb/query/sql-server/list-table-columns-in-database
@@ -294,7 +362,11 @@ ORDER BY schema_name,
             for schema_name, table_name, column_id, column_name, column_data_type, column_max_length, column_precision in col_info_tuples_list
         ]
     else:
-        query: Select = sa.select([sa.text("*")]).select_from(selectable).limit(1)
+        # if a custom query was passed
+        if isinstance(selectable, TextClause):
+            query: TextClause = selectable
+        else:
+            query: Select = sa.select([sa.text("*")]).select_from(selectable).limit(1)
         result_object = sqlalchemy_engine.execute(query)
         # noinspection PyProtectedMember
         col_names: List[str] = result_object._metadata.keys
@@ -334,10 +406,22 @@ def get_dialect_like_pattern_expression(column, dialect, like_pattern, positive=
         dialect_supported = True
 
     try:
+        # noinspection PyUnresolvedReferences
         if isinstance(dialect, sqlalchemy_redshift.dialect.RedshiftDialect):
             dialect_supported = True
     except (AttributeError, TypeError):
         pass
+    try:
+        if hasattr(dialect, "DremioDialect"):
+            dialect_supported = True
+    except (AttributeError, TypeError):
+        pass
+
+    try:
+        if issubclass(dialect.dialect, teradatasqlalchemy.dialect.TeradataDialect):
+            dialect_supported = True
+    except (AttributeError, TypeError):
+        pass
 
     if dialect_supported:
         try:
