@@ -1,6 +1,7 @@
 import datetime
 import logging
 from itertools import chain
+from typing import Optional
 
 import ipywidgets as widgets
 from IPython.display import display
@@ -1019,7 +1020,7 @@ class ExpectationExplorer:
     def generate_parse_strings_as_datetimes_widget_dict(
         self,
         expectation_state,
-        parse_strings_as_datetimes=None,
+        parse_strings_as_datetimes: bool = False,
         column=None,
         **expectation_kwargs,
     ):
