@@ -9,6 +9,7 @@ from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
 from great_expectations.render.util import num_to_str
 
+from ...core import ExpectationSuite
 from ...core.expectation_validation_result import ExpectationSuiteValidationResult
 from ...core.run_identifier import RunIdentifier
 from ...validation_operators.types.validation_operator_result import (
@@ -30,7 +31,12 @@ logger = logging.getLogger(__name__)
 
 
 class ValidationResultsPageRenderer(Renderer):
-    def __init__(self, column_section_renderer=None, run_info_at_end: bool = False):
+    def __init__(
+        self,
+        column_section_renderer=None,
+        run_info_at_end: bool = False,
+        data_context=None,
+    ):
         """
         Args:
             column_section_renderer:
@@ -57,6 +63,7 @@ class ValidationResultsPageRenderer(Renderer):
                 class_name=column_section_renderer["class_name"],
             )
         self.run_info_at_end = run_info_at_end
+        self._data_context = data_context
 
     def render_validation_operator_result(
         self, validation_operator_result: ValidationOperatorResult
@@ -90,7 +97,10 @@ class ValidationResultsPageRenderer(Renderer):
             run_name = run_id
         elif isinstance(run_id, dict):
             run_name = run_id.get("run_name") or "__none__"
-            run_time = run_id.get("run_time") or "__none__"
+            try:
+                run_time = parse(run_id.get("run_time")).strftime("%Y-%m-%dT%H:%M:%SZ")
+            except (ValueError, TypeError):
+                run_time = "__none__"
         elif isinstance(run_id, RunIdentifier):
             run_name = run_id.run_name or "__none__"
             run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
@@ -113,7 +123,20 @@ class ValidationResultsPageRenderer(Renderer):
 
         # Group EVRs by column
         columns = {}
+        try:
+            suite_meta = (
+                self._data_context.get_expectation_suite(expectation_suite_name).meta
+                if self._data_context is not None
+                else None
+            )
+        except:
+            suite_meta = None
+        meta_properties_to_render = self._get_meta_properties_notes(suite_meta)
         for evr in validation_results.results:
+            if meta_properties_to_render is not None:
+                evr.expectation_config.kwargs[
+                    "meta_properties_to_render"
+                ] = meta_properties_to_render
             if "column" in evr.expectation_config.kwargs:
                 column = evr.expectation_config.kwargs["column"]
             else:
@@ -259,6 +282,48 @@ class ValidationResultsPageRenderer(Renderer):
             }
         )
 
+    @classmethod
+    def _get_meta_properties_notes(cls, suite_meta):
+        """
+        This method is used for fetching the custom meta to be added at the suite level
+        "notes": {
+            "content": {
+                "dimension": "properties.dimension",
+                "severity": "properties.severity"
+            },
+            "format": "renderer.diagnostic.meta_properties"
+        }
+        expectation level
+        {
+            "expectation_type": "expect_column_values_to_not_be_null",
+            "kwargs": {
+                "column": "city"
+            },
+            "meta": {
+                "attributes": {
+                    "properties": {
+                        "dimension": "completeness",
+                        "severity": "P3"
+                    },
+                    "user_meta": {
+                        "notes": ""
+                    }
+                }
+            }
+        }
+        This will fetch dimension and severity values which are in the expectation meta.
+
+        """
+        if (
+            suite_meta is not None
+            and "notes" in suite_meta
+            and "format" in suite_meta["notes"]
+            and suite_meta["notes"]["format"] == "renderer.diagnostic.meta_properties"
+        ):
+            return suite_meta["notes"]["content"]
+        else:
+            return None
+
     @classmethod
     def _render_validation_header(cls, validation_results):
         success = validation_results.success
@@ -343,16 +408,21 @@ class ValidationResultsPageRenderer(Renderer):
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
-                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+                run_time = parse(run_id).strftime("%Y-%m-%dT%H:%M:%SZ")
             except (ValueError, TypeError):
                 run_time = "__none__"
             run_name = run_id
         elif isinstance(run_id, dict):
             run_name = run_id.get("run_name") or "__none__"
-            run_time = run_id.get("run_time") or "__none__"
+            try:
+                run_time = str(
+                    parse(run_id.get("run_time")).strftime("%Y-%m-%dT%H:%M:%SZ")
+                )
+            except (ValueError, TypeError):
+                run_time = "__none__"
         elif isinstance(run_id, RunIdentifier):
             run_name = run_id.run_name or "__none__"
-            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%SZ")
         # TODO: Deprecate "great_expectations.__version__"
         ge_version = validation_results.meta.get(
             "great_expectations_version"
@@ -567,9 +637,12 @@ class ExpectationSuitePageRenderer(Renderer):
             )
 
     def render(self, expectations):
-        columns, ordered_columns = self._group_and_order_expectations_by_column(
-            expectations
-        )
+        if isinstance(expectations, dict):
+            expectations = ExpectationSuite(**expectations, data_context=None)
+        (
+            columns,
+            ordered_columns,
+        ) = expectations.get_grouped_and_ordered_expectations_by_column()
         expectation_suite_name = expectations.expectation_suite_name
 
         overview_content_blocks = [
