@@ -2,15 +2,19 @@ import logging
 import os
 import traceback
 from collections import OrderedDict
+from typing import Any, List, Optional, Tuple
 
 import great_expectations.exceptions as exceptions
+from great_expectations.core import ExpectationSuite
 from great_expectations.core.util import nested_update
 from great_expectations.data_context.store.html_site_store import (
     HtmlSiteStore,
     SiteSectionIdentifier,
 )
+from great_expectations.data_context.store.json_site_store import JsonSiteStore
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
+    GeCloudIdentifier,
     ValidationResultIdentifier,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
@@ -114,12 +118,14 @@ class SiteBuilder:
         show_how_to_buttons=True,
         site_section_builders=None,
         runtime_environment=None,
+        ge_cloud_mode=False,
         **kwargs,
     ):
         self.site_name = site_name
         self.data_context = data_context
         self.store_backend = store_backend
         self.show_how_to_buttons = show_how_to_buttons
+        self.ge_cloud_mode = ge_cloud_mode
 
         usage_statistics_config = data_context.anonymous_usage_statistics
         data_context_id = None
@@ -158,9 +164,14 @@ class SiteBuilder:
         # three types of backends using the base
         # type of the configuration defined in the store_backend section
 
-        self.target_store = HtmlSiteStore(
-            store_backend=store_backend, runtime_environment=runtime_environment
-        )
+        if ge_cloud_mode:
+            self.target_store = JsonSiteStore(
+                store_backend=store_backend, runtime_environment=runtime_environment
+            )
+        else:
+            self.target_store = HtmlSiteStore(
+                store_backend=store_backend, runtime_environment=runtime_environment
+            )
 
         default_site_section_builders_config = {
             "expectations": {
@@ -221,6 +232,7 @@ class SiteBuilder:
                     "custom_views_directory": custom_views_directory,
                     "data_context_id": self.data_context_id,
                     "show_how_to_buttons": self.show_how_to_buttons,
+                    "ge_cloud_mode": self.ge_cloud_mode,
                 },
                 config_defaults={"name": site_section_name, "module_name": module_name},
             )
@@ -252,6 +264,7 @@ class SiteBuilder:
                     if section_config not in FALSEY_YAML_STRINGS
                 },
                 "site_section_builders_config": site_section_builders,
+                "ge_cloud_mode": self.ge_cloud_mode,
             },
             config_defaults={
                 "name": "site_index_builder",
@@ -287,14 +300,17 @@ class SiteBuilder:
         """
 
         # copy static assets
-        self.target_store.copy_static_assets()
-
-        for site_section, site_section_builder in self.site_section_builders.items():
+        for site_section_builder in self.site_section_builders.values():
             site_section_builder.build(resource_identifiers=resource_identifiers)
 
-        index_page_url, index_links_dict = self.site_index_builder.build(
-            build_index=build_index
-        )
+        # GE Cloud supports JSON Site Data Docs
+        # Skip static assets, indexing
+        if self.ge_cloud_mode:
+            return
+
+        self.target_store.copy_static_assets()
+
+        _, index_links_dict = self.site_index_builder.build(build_index=build_index)
         return (
             self.get_resource_url(only_if_exists=False),
             index_links_dict,
@@ -332,16 +348,18 @@ class DefaultSiteSectionBuilder:
         renderer=None,
         view=None,
         data_context_id=None,
+        ge_cloud_mode=False,
         **kwargs,
     ):
         self.name = name
+        self.data_context = data_context
         self.source_store = data_context.stores[source_store_name]
         self.target_store = target_store
         self.run_name_filter = run_name_filter
         self.validation_results_limit = validation_results_limit
         self.data_context_id = data_context_id
         self.show_how_to_buttons = show_how_to_buttons
-
+        self.ge_cloud_mode = ge_cloud_mode
         if renderer is None:
             raise exceptions.InvalidConfigError(
                 "SiteSectionBuilder requires a renderer configuration "
@@ -400,13 +418,17 @@ class DefaultSiteSectionBuilder:
             if resource_identifiers and resource_key not in resource_identifiers:
                 continue
 
-            if self.run_name_filter:
+            if self.run_name_filter and not isinstance(resource_key, GeCloudIdentifier):
                 if not resource_key_passes_run_name_filter(
                     resource_key, self.run_name_filter
                 ):
                     continue
             try:
                 resource = self.source_store.get(resource_key)
+                if isinstance(resource_key, ExpectationSuiteIdentifier):
+                    resource = ExpectationSuite(
+                        **resource, data_context=self.data_context
+                    )
             except exceptions.InvalidKeyError:
                 logger.warning(
                     f"Object with Key: {str(resource_key)} could not be retrieved. Skipping..."
@@ -416,9 +438,7 @@ class DefaultSiteSectionBuilder:
             if isinstance(resource_key, ExpectationSuiteIdentifier):
                 expectation_suite_name = resource_key.expectation_suite_name
                 logger.debug(
-                    "        Rendering expectation suite {}".format(
-                        expectation_suite_name
-                    )
+                    f"        Rendering expectation suite {expectation_suite_name}"
                 )
             elif isinstance(resource_key, ValidationResultIdentifier):
                 run_id = resource_key.run_id
@@ -429,36 +449,40 @@ class DefaultSiteSectionBuilder:
                 )
                 if self.name == "profiling":
                     logger.debug(
-                        "        Rendering profiling for batch {}".format(
-                            resource_key.batch_identifier
-                        )
+                        f"        Rendering profiling for batch {resource_key.batch_identifier}"
                     )
                 else:
 
                     logger.debug(
-                        "        Rendering validation: run name: {}, run time: {}, suite {} for batch {}".format(
-                            run_name,
-                            run_time,
-                            expectation_suite_name,
-                            resource_key.batch_identifier,
-                        )
+                        f"        Rendering validation: run name: {run_name}, run time: {run_time}, suite {expectation_suite_name} for batch {resource_key.batch_identifier}"
                     )
 
             try:
                 rendered_content = self.renderer_class.render(resource)
-                viewable_content = self.view_class.render(
-                    rendered_content,
-                    data_context_id=self.data_context_id,
-                    show_how_to_buttons=self.show_how_to_buttons,
-                )
 
-                self.target_store.set(
-                    SiteSectionIdentifier(
-                        site_section_name=self.name,
-                        resource_identifier=resource_key,
-                    ),
-                    viewable_content,
-                )
+                if self.ge_cloud_mode:
+                    self.target_store.set(
+                        GeCloudIdentifier(
+                            resource_type="rendered_data_doc",
+                        ),
+                        rendered_content,
+                        source_type=resource_key.resource_type,
+                        source_id=resource_key.ge_cloud_id,
+                    )
+                else:
+                    viewable_content = self.view_class.render(
+                        rendered_content,
+                        data_context_id=self.data_context_id,
+                        show_how_to_buttons=self.show_how_to_buttons,
+                    )
+                    # Verify type
+                    self.target_store.set(
+                        SiteSectionIdentifier(
+                            site_section_name=self.name,
+                            resource_identifier=resource_key,
+                        ),
+                        viewable_content,
+                    )
             except Exception as e:
                 exception_message = f"""\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
@@ -654,7 +678,7 @@ class DefaultSiteIndexBuilder:
         )
         see_glossary = CallToActionButton(
             "See More Kinds of Expectations",
-            "https://docs.greatexpectations.io/en/latest/reference/glossary_of_expectations.html",
+            "https://greatexpectations.io/expectations",
         )
         validation_playground = CallToActionButton(
             "How to Validate Data",
@@ -689,7 +713,9 @@ class DefaultSiteIndexBuilder:
         return results
 
     # TODO: deprecate dual batch api support
-    def build(self, skip_and_clean_missing=True, build_index: bool = True):
+    def build(
+        self, skip_and_clean_missing=True, build_index: bool = True
+    ) -> Tuple[Any, Optional[OrderedDict]]:
         """
         :param skip_and_clean_missing: if True, target html store keys without corresponding source store keys will
         be skipped and removed from the target store
@@ -709,12 +735,46 @@ class DefaultSiteIndexBuilder:
         if self.show_how_to_buttons:
             index_links_dict["cta_object"] = self.get_calls_to_action()
 
-        if (
-            # TODO why is this duplicated?
-            self.site_section_builders_config.get("expectations", "None")
-            and self.site_section_builders_config.get("expectations", "None")
-            not in FALSEY_YAML_STRINGS
-        ):
+        self._add_expectations_to_index_links(index_links_dict, skip_and_clean_missing)
+        validation_and_profiling_result_site_keys = (
+            self._build_validation_and_profiling_result_site_keys(
+                skip_and_clean_missing
+            )
+        )
+        self._add_profiling_to_index_links(
+            index_links_dict, validation_and_profiling_result_site_keys
+        )
+        self._add_validations_to_index_links(
+            index_links_dict, validation_and_profiling_result_site_keys
+        )
+
+        viewable_content = ""
+        try:
+            rendered_content = self.renderer_class.render(index_links_dict)
+            viewable_content = self.view_class.render(
+                rendered_content,
+                data_context_id=self.data_context_id,
+                show_how_to_buttons=self.show_how_to_buttons,
+            )
+        except Exception as e:
+            exception_message = f"""\
+An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
+not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
+diagnose and repair the underlying issue.  Detailed information follows:
+            """
+            exception_traceback = traceback.format_exc()
+            exception_message += (
+                f'{type(e).__name__}: "{str(e)}".  Traceback: "{exception_traceback}".'
+            )
+            logger.error(exception_message)
+
+        return self.target_store.write_index_page(viewable_content), index_links_dict
+
+    def _add_expectations_to_index_links(
+        self, index_links_dict: OrderedDict, skip_and_clean_missing: bool
+    ) -> None:
+        expectations = self.site_section_builders_config.get("expectations", "None")
+        if expectations and expectations not in FALSEY_YAML_STRINGS:
             expectation_suite_source_keys = self.data_context.stores[
                 self.site_section_builders_config["expectations"].get(
                     "source_store_name"
@@ -744,22 +804,18 @@ class DefaultSiteIndexBuilder:
                     section_name="expectations",
                 )
 
+    def _build_validation_and_profiling_result_site_keys(
+        self, skip_and_clean_missing: bool
+    ) -> List[ValidationResultIdentifier]:
         validation_and_profiling_result_site_keys = []
-        if (
-            # TODO why is this duplicated?
-            self.site_section_builders_config.get("validations", "None")
-            and self.site_section_builders_config.get("validations", "None")
-            not in FALSEY_YAML_STRINGS
-            or self.site_section_builders_config.get("profiling", "None")
-            and self.site_section_builders_config.get("profiling", "None")
-            not in FALSEY_YAML_STRINGS
+        validations = self.site_section_builders_config.get("validations", "None")
+        profiling = self.site_section_builders_config.get("profiling", "None")
+        if (validations and validations not in FALSEY_YAML_STRINGS) or (
+            profiling and profiling not in FALSEY_YAML_STRINGS
         ):
             source_store = (
                 "validations"
-                # TODO why is this duplicated?
-                if self.site_section_builders_config.get("validations", "None")
-                and self.site_section_builders_config.get("validations", "None")
-                not in FALSEY_YAML_STRINGS
+                if (validations and validations not in FALSEY_YAML_STRINGS)
                 else "profiling"
             )
             validation_and_profiling_result_source_keys = self.data_context.stores[
@@ -787,12 +843,15 @@ class DefaultSiteIndexBuilder:
                         cleaned_keys.append(validation_result_site_key)
                 validation_and_profiling_result_site_keys = cleaned_keys
 
-        if (
-            # TODO why is this duplicated?
-            self.site_section_builders_config.get("profiling", "None")
-            and self.site_section_builders_config.get("profiling", "None")
-            not in FALSEY_YAML_STRINGS
-        ):
+        return validation_and_profiling_result_site_keys
+
+    def _add_profiling_to_index_links(
+        self,
+        index_links_dict: OrderedDict,
+        validation_and_profiling_result_site_keys: List[ValidationResultIdentifier],
+    ) -> None:
+        profiling = self.site_section_builders_config.get("profiling", "None")
+        if profiling and profiling not in FALSEY_YAML_STRINGS:
             profiling_run_name_filter = self.site_section_builders_config["profiling"][
                 "run_name_filter"
             ]
@@ -829,17 +888,16 @@ class DefaultSiteIndexBuilder:
                         batch_spec=batch_spec,
                     )
                 except Exception:
-                    error_msg = "Profiling result not found: {:s} - skipping".format(
-                        str(profiling_result_key.to_tuple())
-                    )
+                    error_msg = f"Profiling result not found: {str(profiling_result_key.to_tuple()):s} - skipping"
                     logger.warning(error_msg)
 
-        if (
-            # TODO why is this duplicated?
-            self.site_section_builders_config.get("validations", "None")
-            and self.site_section_builders_config.get("validations", "None")
-            not in FALSEY_YAML_STRINGS
-        ):
+    def _add_validations_to_index_links(
+        self,
+        index_links_dict: OrderedDict,
+        validation_and_profiling_result_site_keys: List[ValidationResultIdentifier],
+    ) -> None:
+        validations = self.site_section_builders_config.get("validations", "None")
+        if validations and validations not in FALSEY_YAML_STRINGS:
             validations_run_name_filter = self.site_section_builders_config[
                 "validations"
             ]["run_name_filter"]
@@ -887,32 +945,9 @@ class DefaultSiteIndexBuilder:
                         batch_spec=batch_spec,
                     )
                 except Exception:
-                    error_msg = "Validation result not found: {:s} - skipping".format(
-                        str(validation_result_key.to_tuple())
-                    )
+                    error_msg = f"Validation result not found: {str(validation_result_key.to_tuple()):s} - skipping"
                     logger.warning(error_msg)
 
-        try:
-            rendered_content = self.renderer_class.render(index_links_dict)
-            viewable_content = self.view_class.render(
-                rendered_content,
-                data_context_id=self.data_context_id,
-                show_how_to_buttons=self.show_how_to_buttons,
-            )
-        except Exception as e:
-            exception_message = f"""\
-An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
-not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
-diagnose and repair the underlying issue.  Detailed information follows:
-            """
-            exception_traceback = traceback.format_exc()
-            exception_message += (
-                f'{type(e).__name__}: "{str(e)}".  Traceback: "{exception_traceback}".'
-            )
-            logger.error(exception_message)
-
-        return (self.target_store.write_index_page(viewable_content), index_links_dict)
-
 
 class CallToActionButton:
     def __init__(self, title, link):
