@@ -5,7 +5,7 @@ from great_expectations.core.batch import BatchRequest
 from great_expectations.execution_engine.execution_engine import MetricDomainTypes
 from great_expectations.rule_based_profiler.domain_builder import Domain, DomainBuilder
 from great_expectations.rule_based_profiler.parameter_builder import ParameterContainer
-from great_expectations.validator.validator import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
 class SimpleColumnSuffixDomainBuilder(DomainBuilder):
