@@ -56,10 +56,10 @@ class NumericMetricRangeMultiBatchParameterBuilder(ParameterBuilder):
         metric_name: str,
         metric_domain_kwargs: Optional[Union[str, dict]] = None,
         metric_value_kwargs: Optional[Union[str, dict]] = None,
-        sampling_method: Optional[str] = "bootstrap",
-        enforce_numeric_metric: Optional[Union[str, bool]] = True,
-        replace_nan_with_zero: Optional[Union[str, bool]] = True,
-        false_positive_rate: Optional[Union[str, float]] = 5.0e-2,
+        sampling_method: str = "bootstrap",
+        enforce_numeric_metric: Union[str, bool] = True,
+        replace_nan_with_zero: Union[str, bool] = True,
+        false_positive_rate: Union[str, float] = 5.0e-2,
         num_bootstrap_samples: Optional[Union[str, int]] = None,
         round_decimals: Optional[Union[str, int]] = None,
         truncate_values: Optional[
