@@ -1,3 +1,4 @@
+import json
 import logging
 from unittest import mock
 
@@ -33,6 +34,13 @@ class MockTeamsResponse:
         self.text = "test_text"
 
 
+class MockSlackResponse:
+    def __init__(self, status_code):
+        self.status_code = status_code
+        self.text = "test_text"
+        self.content = json.dumps({"ok": "True"})
+
+
 @freeze_time("09/26/2019 13:42:41")
 def test_StoreAction():
     fake_in_memory_store = ValidationsStore(
@@ -43,7 +51,7 @@ def test_StoreAction():
     stores = {"fake_in_memory_store": fake_in_memory_store}
 
     class Object:
-        pass
+        ge_cloud_mode = False
 
     data_context = Object()
     data_context.stores = stores
@@ -59,7 +67,7 @@ def test_StoreAction():
             expectation_suite_identifier=ExpectationSuiteIdentifier(
                 expectation_suite_name="default_expectations"
             ),
-            run_id="prod_20190801",
+            run_id=RunIdentifier(run_name="prod_20190801"),
             batch_identifier="1234",
         ),
         validation_result_suite=ExpectationSuiteValidationResult(
@@ -95,6 +103,7 @@ def test_StoreAction():
     )
 
 
+@mock.patch.object(Session, "post", return_value=MockSlackResponse(200))
 def test_SlackNotificationAction(
     data_context_parameterized_expectation_suite,
     validation_result_suite,
@@ -105,8 +114,11 @@ def test_SlackNotificationAction(
         "class_name": "SlackRenderer",
     }
     slack_webhook = "https://hooks.slack.com/services/test/slack/webhook"
+    slack_token = "test"
+    slack_channel = "test"
     notify_on = "all"
 
+    # test with just web_hook set; expect pass
     slack_action = SlackNotificationAction(
         data_context=data_context_parameterized_expectation_suite,
         renderer=renderer,
@@ -114,14 +126,111 @@ def test_SlackNotificationAction(
         notify_on=notify_on,
     )
 
-    # TODO: improve this test - currently it is verifying a failed call to Slack. It returns a "empty" payload
     assert (
         slack_action.run(
             validation_result_suite_identifier=validation_result_suite_id,
             validation_result_suite=validation_result_suite,
             data_asset=None,
         )
-        == {"slack_notification_result": None}
+        == {"slack_notification_result": "Slack notification succeeded."}
+    )
+
+    # Test with slack_token and slack_channel set; expect pass
+    slack_action = SlackNotificationAction(
+        data_context=data_context_parameterized_expectation_suite,
+        renderer=renderer,
+        slack_token=slack_token,
+        slack_channel=slack_channel,
+        notify_on=notify_on,
+    )
+
+    assert (
+        slack_action.run(
+            validation_result_suite_identifier=validation_result_suite_id,
+            validation_result_suite=validation_result_suite,
+            data_asset=None,
+        )
+        == {"slack_notification_result": "Slack notification succeeded."}
+    )
+
+    # Test with just slack_token set; expect fail
+    with pytest.raises(AssertionError):
+        SlackNotificationAction(
+            data_context=data_context_parameterized_expectation_suite,
+            renderer=renderer,
+            slack_token=slack_token,
+            notify_on=notify_on,
+        )
+
+    # Test with just slack_channel set; expect fail
+    with pytest.raises(AssertionError):
+        slack_action = SlackNotificationAction(
+            data_context=data_context_parameterized_expectation_suite,
+            renderer=renderer,
+            slack_channel=slack_channel,
+            notify_on=notify_on,
+        )
+
+    # Test with slack_channel, slack_token, and slack_webhook set; expect fail
+    with pytest.raises(AssertionError):
+        SlackNotificationAction(
+            data_context=data_context_parameterized_expectation_suite,
+            renderer=renderer,
+            slack_channel=slack_channel,
+            slack_token=slack_token,
+            slack_webhook=slack_webhook,
+            notify_on=notify_on,
+        )
+
+    # test notify on with failed run; expect pass
+    notify_on = "failure"
+    slack_action = SlackNotificationAction(
+        data_context=data_context_parameterized_expectation_suite,
+        renderer=renderer,
+        slack_webhook=slack_webhook,
+        notify_on=notify_on,
+    )
+
+    assert (
+        slack_action.run(
+            validation_result_suite_identifier=validation_result_suite_id,
+            validation_result_suite=ExpectationSuiteValidationResult(
+                success=False,
+                results=[],
+                statistics={
+                    "successful_expectations": [],
+                    "evaluated_expectations": [],
+                },
+            ),
+            data_asset=None,
+        )
+        == {"slack_notification_result": "Slack notification succeeded."}
+    )
+
+    # test notify on with successful run; expect pass
+    notify_on = "failure"
+    validation_result_suite.success = False
+    slack_action = SlackNotificationAction(
+        data_context=data_context_parameterized_expectation_suite,
+        renderer=renderer,
+        slack_webhook=slack_webhook,
+        notify_on=notify_on,
+    )
+
+    assert (
+        slack_action.run(
+            validation_result_suite_identifier=validation_result_suite_id,
+            validation_result_suite=ExpectationSuiteValidationResult(
+                success=True,
+                results=[],
+                statistics={
+                    "successful_expectations": [],
+                    "evaluated_expectations": [],
+                },
+            ),
+            data_asset=None,
+        )
+        == {"slack_notification_result": "none required"}
     )
 
 
