@@ -78,13 +78,6 @@ def test_cli_init_on_new_project(
     checkpoints/
     expectations/
         .ge_store_backend_id
-    notebooks/
-        pandas/
-            validation_playground.ipynb
-        spark/
-            validation_playground.ipynb
-        sql/
-            validation_playground.ipynb
     plugins/
         custom_data_docs/
             renderers/
@@ -226,12 +219,13 @@ def test_cli_init_on_existing_project_with_no_uncommitted_dirs_answering_no_then
     # Test the second invocation of init (answer N to update broken init)
     runner = CliRunner(mix_stderr=False)
     monkeypatch.chdir(os.path.dirname(context.root_directory))
-    result = runner.invoke(
-        cli,
-        ["--v3-api", "init"],
-        input="N\n",
-        catch_exceptions=False,
-    )
+    with pytest.warns(UserWarning):
+        result = runner.invoke(
+            cli,
+            ["--v3-api", "init"],
+            input="N\n",
+            catch_exceptions=False,
+        )
     stdout = result.stdout
 
     assert result.exit_code == 0
