@@ -2,6 +2,7 @@ import json
 import os
 from unittest import mock
 
+import pytest
 from click.testing import CliRunner
 
 from great_expectations import DataContext
@@ -132,6 +133,9 @@ def test_suite_demo_enter_existing_suite_name_as_arg(
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_demo_answer_suite_name_prompts_with_name_of_existing_suite(
@@ -377,6 +381,9 @@ def test_suite_new_empty_with_no_jupyter(
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_new_empty_with_csv_gz(
@@ -412,6 +419,9 @@ def test_suite_new_empty_with_csv_gz(
     assert citations[0]["batch_kwargs"]["reader_options"] == {"compression": "gzip"}
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_demo_one_datasource_without_generator_without_suite_name_argument(
@@ -492,6 +502,9 @@ def test_suite_demo_one_datasource_without_generator_without_suite_name_argument
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_demo_multiple_datasources_with_generator_without_suite_name_argument(
@@ -579,6 +592,9 @@ def test_suite_demo_multiple_datasources_with_generator_without_suite_name_argum
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_demo_multiple_datasources_with_generator_with_suite_name_argument(
@@ -804,6 +820,9 @@ def test_suite_edit_with_non_existent_datasource_shows_helpful_error_message(
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_edit_multiple_datasources_with_generator_with_no_additional_args_with_suite_without_citations(
@@ -892,6 +911,9 @@ def test_suite_edit_multiple_datasources_with_generator_with_no_additional_args_
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_edit_multiple_datasources_with_generator_with_no_additional_args_with_suite_containing_citations(
@@ -965,6 +987,9 @@ def test_suite_edit_multiple_datasources_with_generator_with_no_additional_args_
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_edit_multiple_datasources_with_generator_with_batch_kwargs_arg(
@@ -1179,6 +1204,9 @@ def test_suite_edit_on_exsiting_suite_one_datasources_with_datasource_arg_and_ba
     )
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
 def test_suite_edit_one_datasources_no_generator_with_no_additional_args_and_no_citations(
