@@ -1,16 +1,19 @@
 import jsonschema
 
 from great_expectations.core.usage_statistics.schemas import (
+    anonymized_batch_request_schema,
     anonymized_batch_schema,
+    anonymized_checkpoint_run_schema,
+    anonymized_cli_new_ds_choice_payload_schema,
+    anonymized_cli_suite_expectation_suite_payload_schema,
     anonymized_datasource_schema,
-    cli_new_ds_choice_payload_schema,
-    cli_suite_expectation_suite_payload_schema,
-    datasource_sqlalchemy_connect_payload,
+    anonymized_datasource_sqlalchemy_connect_payload_schema,
+    anonymized_init_payload_schema,
+    anonymized_legacy_profiler_build_suite_payload_schema,
+    anonymized_save_or_edit_expectation_suite_payload_schema,
+    anonymized_test_yaml_config_payload_schema,
+    anonymized_usage_statistics_record_schema,
     empty_payload_schema,
-    init_payload_schema,
-    save_or_edit_expectation_suite_payload_schema,
-    test_yaml_config_payload_schema,
-    usage_statistics_record_schema,
 )
 from tests.integration.usage_statistics.test_usage_statistics_messages import (
     valid_usage_statistics_messages,
@@ -54,11 +57,16 @@ def test_comprehensive_list_of_messages():
         "data_asset.validate",
         "data_context.__init__",
         "data_context.add_datasource",
+        "data_context.get_batch_list",
         "data_context.build_data_docs",
         "data_context.open_data_docs",
+        "data_context.run_checkpoint",
         "data_context.save_expectation_suite",
-        "datasource.sqlalchemy.connect",
         "data_context.test_yaml_config",
+        "datasource.sqlalchemy.connect",
+        "checkpoint.run",
+        "expectation_suite.add_expectation",
+        "legacy_profiler.build_suite",
     }
 
 
@@ -71,12 +79,12 @@ def test_init_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             # non-empty payload
             jsonschema.validate(
                 message["event_payload"],
-                init_payload_schema,
+                anonymized_init_payload_schema,
             )
 
 
@@ -89,7 +97,7 @@ def test_data_asset_validate_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             # non-empty payload
             jsonschema.validate(
@@ -107,7 +115,7 @@ def test_data_context_add_datasource_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             # non-empty payload
             jsonschema.validate(
@@ -116,6 +124,57 @@ def test_data_context_add_datasource_message():
             )
 
 
+def test_data_context_get_batch_list_message():
+    usage_stats_records_messages = [
+        "data_context.get_batch_list",
+    ]
+    for message_type in usage_stats_records_messages:
+        for message in valid_usage_statistics_messages[message_type]:
+            # record itself
+            jsonschema.validate(
+                message,
+                anonymized_usage_statistics_record_schema,
+            )
+            jsonschema.validate(
+                message["event_payload"],
+                anonymized_batch_request_schema,
+            )
+
+
+def test_checkpoint_run_message():
+    usage_stats_records_messages = [
+        "checkpoint.run",
+    ]
+    for message_type in usage_stats_records_messages:
+        for message in valid_usage_statistics_messages[message_type]:
+            # record itself
+            jsonschema.validate(
+                message,
+                anonymized_usage_statistics_record_schema,
+            )
+            jsonschema.validate(
+                message["event_payload"],
+                anonymized_checkpoint_run_schema,
+            )
+
+
+def test_legacy_profiler_build_suite_message():
+    usage_stats_records_messages = [
+        "legacy_profiler.build_suite",
+    ]
+    for message_type in usage_stats_records_messages:
+        for message in valid_usage_statistics_messages[message_type]:
+            # record itself
+            jsonschema.validate(
+                message,
+                anonymized_usage_statistics_record_schema,
+            )
+            jsonschema.validate(
+                message["event_payload"],
+                anonymized_legacy_profiler_build_suite_payload_schema,
+            )
+
+
 def test_data_context_save_expectation_suite_message():
     usage_stats_records_messages = [
         "data_context.save_expectation_suite",
@@ -125,11 +184,11 @@ def test_data_context_save_expectation_suite_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             jsonschema.validate(
                 message["event_payload"],
-                save_or_edit_expectation_suite_payload_schema,
+                anonymized_cli_suite_expectation_suite_payload_schema,
             )
 
 
@@ -142,16 +201,15 @@ def test_datasource_sqlalchemy_connect_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             jsonschema.validate(
                 message["event_payload"],
-                datasource_sqlalchemy_connect_payload,
+                anonymized_datasource_sqlalchemy_connect_payload_schema,
             )
 
 
 def test_cli_data_asset_validate():
-
     usage_stats_records_messages = [
         "data_asset.validate",
     ]
@@ -161,7 +219,7 @@ def test_cli_data_asset_validate():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
 
 
@@ -174,7 +232,24 @@ def test_cli_new_ds_choice_message():
             # non-empty payload
             jsonschema.validate(
                 message["event_payload"],
-                cli_new_ds_choice_payload_schema,
+                anonymized_cli_new_ds_choice_payload_schema,
+            )
+
+
+def test_cli_suite_new_message():
+    usage_stats_records_messages = [
+        "cli.suite.new",
+    ]
+    for message_type in usage_stats_records_messages:
+        for message in valid_usage_statistics_messages[message_type]:
+            # record itself
+            jsonschema.validate(
+                message,
+                anonymized_usage_statistics_record_schema,
+            )
+            jsonschema.validate(
+                message["event_payload"],
+                anonymized_cli_suite_expectation_suite_payload_schema,
             )
 
 
@@ -187,11 +262,11 @@ def test_cli_suite_edit_message():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             jsonschema.validate(
                 message["event_payload"],
-                cli_suite_expectation_suite_payload_schema,
+                anonymized_cli_suite_expectation_suite_payload_schema,
             )
 
 
@@ -204,11 +279,11 @@ def test_test_yaml_config_messages():
             # record itself
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
             jsonschema.validate(
                 message["event_payload"],
-                test_yaml_config_payload_schema,
+                anonymized_test_yaml_config_payload_schema,
             )
 
 
@@ -216,12 +291,29 @@ def test_usage_stats_empty_payload_messages():
     usage_stats_records_messages = [
         "data_context.build_data_docs",
         "data_context.open_data_docs",
+        "data_context.run_checkpoint",
     ]
     for message_type in usage_stats_records_messages:
         for message in valid_usage_statistics_messages[message_type]:
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
+            )
+            jsonschema.validate(
+                message["event_payload"],
+                empty_payload_schema,
+            )
+
+
+def test_usage_stats_expectation_suite_messages():
+    usage_stats_records_messages = [
+        "expectation_suite.add_expectation",
+    ]
+    for message_type in usage_stats_records_messages:
+        for message in valid_usage_statistics_messages[message_type]:
+            jsonschema.validate(
+                message,
+                anonymized_usage_statistics_record_schema,
             )
             jsonschema.validate(
                 message["event_payload"],
@@ -259,5 +351,5 @@ def test_usage_stats_cli_payload_messages():
         for message in valid_usage_statistics_messages[message_type]:
             jsonschema.validate(
                 message,
-                usage_statistics_record_schema,
+                anonymized_usage_statistics_record_schema,
             )
