@@ -5,6 +5,7 @@ import pandas as pd
 import pytest
 
 import great_expectations as ge
+from great_expectations import DataContext
 from great_expectations.core import ExpectationConfiguration, expectationSuiteSchema
 from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.core.expectation_validation_result import (
@@ -13,7 +14,10 @@ from great_expectations.core.expectation_validation_result import (
 from great_expectations.exceptions import InvalidExpectationConfigurationError
 
 
-def test_get_and_save_expectation_suite(tmp_path_factory):
+def test_get_and_save_expectation_suite(
+    tmp_path_factory, empty_data_context_stats_enabled
+):
+    context: DataContext = empty_data_context_stats_enabled
     directory_name = str(
         tmp_path_factory.mktemp("test_get_and_save_expectation_config")
     )
@@ -56,6 +60,7 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
+        data_context=context,
         meta={"great_expectations_version": ge.__version__},
     )
 
@@ -63,7 +68,9 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
 
     df.save_expectation_suite(directory_name + "/temp1.json")
     with open(directory_name + "/temp1.json") as infile:
-        loaded_config = expectationSuiteSchema.loads(infile.read())
+        loaded_config_dict: dict = expectationSuiteSchema.loads(infile.read())
+        loaded_config = ExpectationSuite(**loaded_config_dict, data_context=context)
+
     assert output_config == loaded_config
 
     ### Second test set ###
@@ -93,6 +100,7 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
+        data_context=context,
         meta={"great_expectations_version": ge.__version__},
     )
 
@@ -101,7 +109,9 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         directory_name + "/temp2.json", discard_failed_expectations=False
     )
     with open(directory_name + "/temp2.json") as infile:
-        loaded_suite = expectationSuiteSchema.loads(infile.read())
+        loaded_suite_dict: dict = expectationSuiteSchema.loads(infile.read())
+        loaded_suite = ExpectationSuite(**loaded_suite_dict, data_context=context)
+
     assert output_config == loaded_suite
 
     ### Third test set ###
@@ -131,6 +141,7 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         ],
         expectation_suite_name="default",
         data_asset_type="Dataset",
+        data_context=context,
         meta={"great_expectations_version": ge.__version__},
     )
     assert output_config == df.get_expectation_suite(
@@ -145,7 +156,8 @@ def test_get_and_save_expectation_suite(tmp_path_factory):
         discard_catch_exceptions_kwargs=False,
     )
     with open(directory_name + "/temp3.json") as infile:
-        loaded_suite = expectationSuiteSchema.loads(infile.read())
+        loaded_suite_dict: dict = expectationSuiteSchema.loads(infile.read())
+        loaded_suite = ExpectationSuite(**loaded_suite_dict, data_context=context)
     assert output_config == loaded_suite
 
 
@@ -172,7 +184,7 @@ def test_expectation_meta():
     # This should raise an error because meta isn't serializable.
     with pytest.raises(InvalidExpectationConfigurationError) as exc:
         df.expect_column_values_to_be_increasing(
-            "x", meta={"unserializable_content": np.complex(0, 0)}
+            "x", meta={"unserializable_content": complex(0, 0)}
         )
     assert "which cannot be serialized to json" in exc.value.message
 
