@@ -1,8 +1,11 @@
 import datetime
 import os
+from unittest import mock
 
+import boto3
 import pytest
 from freezegun import freeze_time
+from moto import mock_s3
 
 import tests.test_utils as test_utils
 from great_expectations.core import ExpectationConfiguration
@@ -12,6 +15,13 @@ from great_expectations.core.expectation_validation_result import (
 )
 from great_expectations.core.metric import ValidationMetricIdentifier
 from great_expectations.core.run_identifier import RunIdentifier
+from great_expectations.data_context.data_context import DataContext
+from great_expectations.data_context.store import (
+    EvaluationParameterStore,
+    TupleAzureBlobStoreBackend,
+    TupleGCSStoreBackend,
+    TupleS3StoreBackend,
+)
 from great_expectations.data_context.util import instantiate_class_from_config
 
 
@@ -78,7 +88,7 @@ def in_memory_param_store(request, test_backends):
 
 
 def test_evaluation_parameter_store_methods(
-    data_context_parameterized_expectation_suite,
+    data_context_parameterized_expectation_suite: DataContext,
 ):
     run_id = RunIdentifier(run_name="20191125T000000.000000Z")
     source_patient_data_results = ExpectationSuiteValidationResult(
@@ -247,3 +257,98 @@ def test_database_evaluation_parameter_store_get_bind_params(param_store):
         "urn:great_expectations:validations:asset2.warning:"
         "expect_column_values_to_match_regex.result.unexpected_percent:column=mycol": 12.3456789,
     }
+
+
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleS3StoreBackend.list_keys"
+)
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleStoreBackend.list_keys"
+)
+def test_evaluation_parameter_store_calls_proper_cloud_tuple_store_methods(
+    mock_parent_list_keys,
+    mock_s3_list_keys,
+):
+    """
+    What does this test and why?
+
+    Demonstrate that EvaluationParameterStore works as expected with TupleS3StoreBackend
+    and that the store backend adheres to the Liskov substitution principle.
+    """
+    evaluation_parameter_store = EvaluationParameterStore()
+    run_id = RunIdentifier()
+    s3_store = TupleS3StoreBackend(bucket="my_bucket")
+    evaluation_parameter_store._store_backend = s3_store
+
+    # Sanity check to ensure neither parent nor child method has been called
+    assert not mock_s3_list_keys.called
+    assert not mock_parent_list_keys.called
+
+    # `get_bind_params` calls the child method due to proper polymorphism
+    evaluation_parameter_store.get_bind_params(run_id=run_id)
+    assert mock_s3_list_keys.called
+    assert not mock_parent_list_keys.called
+
+
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleAzureBlobStoreBackend.list_keys"
+)
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleStoreBackend.list_keys"
+)
+def test_evaluation_parameter_store_calls_proper_azure_tuple_store_methods(
+    mock_parent_list_keys,
+    mock_azure_list_keys,
+):
+    """
+    What does this test and why?
+
+    Demonstrate that EvaluationParameterStore works as expected with TupleAzureBlobStoreBackend
+    and that the store backend adheres to the Liskov substitution principle.
+    """
+    evaluation_parameter_store = EvaluationParameterStore()
+    run_id = RunIdentifier()
+    azure_store = TupleAzureBlobStoreBackend(
+        container="my_container", connection_string="my_connection_string"
+    )
+    evaluation_parameter_store._store_backend = azure_store
+
+    # Sanity check to ensure neither parent nor child method has been called
+    assert not mock_azure_list_keys.called
+    assert not mock_parent_list_keys.called
+
+    # `get_bind_params` calls the child method due to proper polymorphism
+    evaluation_parameter_store.get_bind_params(run_id=run_id)
+    assert mock_azure_list_keys.called
+    assert not mock_parent_list_keys.called
+
+
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleGCSStoreBackend.list_keys"
+)
+@mock.patch(
+    "great_expectations.data_context.store.tuple_store_backend.TupleStoreBackend.list_keys"
+)
+def test_evaluation_parameter_store_calls_proper_gcs_tuple_store_methods(
+    mock_parent_list_keys,
+    mock_gcs_list_keys,
+):
+    """
+    What does this test and why?
+
+    Demonstrate that EvaluationParameterStore works as expected with TupleGCSStoreBackend
+    and that the store backend adheres to the Liskov substitution principle.
+    """
+    evaluation_parameter_store = EvaluationParameterStore()
+    run_id = RunIdentifier()
+    gcs_store = TupleGCSStoreBackend(bucket="my_bucket", project="my_project")
+    evaluation_parameter_store._store_backend = gcs_store
+
+    # Sanity check to ensure neither parent nor child method has been called
+    assert not mock_gcs_list_keys.called
+    assert not mock_parent_list_keys.called
+
+    # `get_bind_params` calls the child method due to proper polymorphism
+    evaluation_parameter_store.get_bind_params(run_id=run_id)
+    assert mock_gcs_list_keys.called
+    assert not mock_parent_list_keys.called
