@@ -1,4 +1,5 @@
 import datetime
+import json
 import os
 import uuid
 from collections import OrderedDict
@@ -10,7 +11,11 @@ import pytest
 from moto import mock_s3
 
 import tests.test_utils as test_utils
+from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.core.run_identifier import RunIdentifier
+from great_expectations.data_context import DataContext
+from great_expectations.data_context.data_context import BaseDataContext
 from great_expectations.data_context.store import (
     GeCloudStoreBackend,
     InMemoryStoreBackend,
@@ -20,15 +25,133 @@ from great_expectations.data_context.store import (
     TupleGCSStoreBackend,
     TupleS3StoreBackend,
 )
-from great_expectations.data_context.types.base import CheckpointConfig
+from great_expectations.data_context.types.base import (
+    CheckpointConfig,
+    DataContextConfig,
+)
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
     ValidationResultIdentifier,
 )
+from great_expectations.data_context.util import file_relative_path
 from great_expectations.exceptions import InvalidKeyError, StoreBackendError, StoreError
+from great_expectations.self_check.util import expectationSuiteSchema
 from great_expectations.util import gen_directory_tree_str
 
 
+@pytest.fixture()
+def basic_data_context_config_for_validation_operator():
+    return DataContextConfig(
+        config_version=2,
+        plugins_directory=None,
+        evaluation_parameter_store_name="evaluation_parameter_store",
+        expectations_store_name="expectations_store",
+        datasources={},
+        stores={
+            "expectations_store": {"class_name": "ExpectationsStore"},
+            "evaluation_parameter_store": {"class_name": "EvaluationParameterStore"},
+            "validation_result_store": {"class_name": "ValidationsStore"},
+            "metrics_store": {"class_name": "MetricStore"},
+        },
+        validations_store_name="validation_result_store",
+        data_docs_sites={},
+        validation_operators={
+            "store_val_res_and_extract_eval_params": {
+                "class_name": "ActionListValidationOperator",
+                "action_list": [
+                    {
+                        "name": "store_validation_result",
+                        "action": {
+                            "class_name": "StoreValidationResultAction",
+                            "target_store_name": "validation_result_store",
+                        },
+                    },
+                    {
+                        "name": "extract_and_store_eval_parameters",
+                        "action": {
+                            "class_name": "StoreEvaluationParametersAction",
+                            "target_store_name": "evaluation_parameter_store",
+                        },
+                    },
+                ],
+            },
+            "errors_and_warnings_validation_operator": {
+                "class_name": "WarningAndFailureExpectationSuitesValidationOperator",
+                "action_list": [
+                    {
+                        "name": "store_validation_result",
+                        "action": {
+                            "class_name": "StoreValidationResultAction",
+                            "target_store_name": "validation_result_store",
+                        },
+                    },
+                    {
+                        "name": "extract_and_store_eval_parameters",
+                        "action": {
+                            "class_name": "StoreEvaluationParametersAction",
+                            "target_store_name": "evaluation_parameter_store",
+                        },
+                    },
+                ],
+            },
+        },
+    )
+
+
+@pytest.fixture
+def validation_operators_data_context(
+    basic_data_context_config_for_validation_operator, filesystem_csv_4
+):
+    data_context = BaseDataContext(basic_data_context_config_for_validation_operator)
+
+    data_context.add_datasource(
+        "my_datasource",
+        class_name="PandasDatasource",
+        batch_kwargs_generators={
+            "subdir_reader": {
+                "class_name": "SubdirReaderBatchKwargsGenerator",
+                "base_directory": str(filesystem_csv_4),
+            }
+        },
+    )
+    data_context.create_expectation_suite("f1.foo")
+
+    df = data_context.get_batch(
+        batch_kwargs=data_context.build_batch_kwargs(
+            "my_datasource", "subdir_reader", "f1"
+        ),
+        expectation_suite_name="f1.foo",
+    )
+    df.expect_column_values_to_be_between(column="x", min_value=1, max_value=9)
+    failure_expectations = df.get_expectation_suite(discard_failed_expectations=False)
+
+    df.expect_column_values_to_not_be_null(column="y")
+    warning_expectations = df.get_expectation_suite(discard_failed_expectations=False)
+
+    data_context.save_expectation_suite(
+        failure_expectations, expectation_suite_name="f1.failure"
+    )
+    data_context.save_expectation_suite(
+        warning_expectations, expectation_suite_name="f1.warning"
+    )
+
+    return data_context
+
+
+@pytest.fixture()
+def parameterized_expectation_suite(empty_data_context_stats_enabled):
+    context: DataContext = empty_data_context_stats_enabled
+    fixture_path = file_relative_path(
+        __file__,
+        "../../test_fixtures/expectation_suites/parameterized_expression_expectation_suite_fixture.json",
+    )
+    with open(
+        fixture_path,
+    ) as suite:
+        expectation_suite_dict: dict = expectationSuiteSchema.load(json.load(suite))
+        return ExpectationSuite(**expectation_suite_dict, data_context=context)
+
+
 def test_StoreBackendValidation():
     backend = InMemoryStoreBackend()
 
@@ -468,9 +591,45 @@ def test_TupleS3StoreBackend_with_prefix():
         == f"https://s3.amazonaws.com/{bucket}/{prefix}/my_file_BBB"
     )
 
-    my_store.remove_key(("BBB",))
+    assert my_store.remove_key(("BBB",))
     with pytest.raises(InvalidKeyError):
         my_store.get(("BBB",))
+    # Check that the rest of the keys still exist in the bucket
+    assert {
+        s3_object_info["Key"]
+        for s3_object_info in boto3.client("s3").list_objects_v2(
+            Bucket=bucket, Prefix=prefix
+        )["Contents"]
+    } == {
+        "this_is_a_test_prefix/.ge_store_backend_id",
+        "this_is_a_test_prefix/my_file_AAA",
+    }
+
+    # Call remove_key on an already deleted object
+    assert not my_store.remove_key(("BBB",))
+    # Check that the rest of the keys still exist in the bucket
+    assert {
+        s3_object_info["Key"]
+        for s3_object_info in boto3.client("s3").list_objects_v2(
+            Bucket=bucket, Prefix=prefix
+        )["Contents"]
+    } == {
+        "this_is_a_test_prefix/.ge_store_backend_id",
+        "this_is_a_test_prefix/my_file_AAA",
+    }
+
+    # Call remove_key on a non-existent key
+    assert not my_store.remove_key(("NON_EXISTENT_KEY",))
+    # Check that the rest of the keys still exist in the bucket
+    assert {
+        s3_object_info["Key"]
+        for s3_object_info in boto3.client("s3").list_objects_v2(
+            Bucket=bucket, Prefix=prefix
+        )["Contents"]
+    } == {
+        "this_is_a_test_prefix/.ge_store_backend_id",
+        "this_is_a_test_prefix/my_file_AAA",
+    }
 
     # testing base_public_path
     my_new_store = TupleS3StoreBackend(
@@ -488,6 +647,89 @@ def test_TupleS3StoreBackend_with_prefix():
     )
 
 
+# NOTE: Chetan - 20211118: I am commenting out this test as it was introduced in: https://github.com/great-expectations/great_expectations/pull/3377
+# We've decided to roll back these changes for the time being since they introduce some unintendend consequences.
+#
+# This is a gentle reminder to future contributors to please re-enable this test when revisiting the matter.
+
+# @mock_s3
+# def test_tuple_s3_store_backend_expectation_suite_and_validation_operator_share_prefix(
+#     validation_operators_data_context: DataContext,
+#     parameterized_expectation_suite: ExpectationSuite,
+# ):
+#     """
+#     What does this test test and why?
+
+#     In cases where an s3 store is used with the same prefix for both validations
+#     and expectations, the list_keys() operation picks up files ending in .json
+#     from both validations and expectations stores.
+
+#     To avoid this issue, the expectation suite configuration, if available, is used
+#     to locate the specific key for the suite in place of calling list_keys().
+
+#     NOTE: It is an issue with _all stores_ when the result of list_keys() contain paths
+#     with a period (.) and are passed to ExpectationSuiteIdentifier.from_tuple() method,
+#     as happens in the DataContext.store_evaluation_parameters() method. The best fix is
+#     to choose a different delimiter for generating expectation suite identifiers (or
+#     perhaps escape the period in path names).
+
+#     For now, the fix is to avoid the call to list_keys() in
+#     DataContext.store_evaluation_parameters() if the expectation suite is known (from config).
+#     This approach should also improve performance.
+
+#     This test confirms the fix for GitHub issue #3054.
+#     """
+#     bucket = "leakybucket"
+#     prefix = "this_is_a_test_prefix"
+
+#     # create a bucket in Moto's mock AWS environment
+#     conn = boto3.resource("s3", region_name="us-east-1")
+#     conn.create_bucket(Bucket=bucket)
+
+#     # replace store backends with the mock, both with the same prefix (per issue #3054)
+#     validation_operators_data_context.validations_store._store_backend = (
+#         TupleS3StoreBackend(
+#             bucket=bucket,
+#             prefix=prefix,
+#         )
+#     )
+#     validation_operators_data_context.expectations_store._store_backend = (
+#         TupleS3StoreBackend(
+#             bucket=bucket,
+#             prefix=prefix,
+#         )
+#     )
+
+#     validation_operators_data_context.save_expectation_suite(
+#         parameterized_expectation_suite, "param_suite"
+#     )
+
+#     # ensure the suite is in the context
+#     assert validation_operators_data_context.expectations_store.has_key(
+#         ExpectationSuiteIdentifier("param_suite")
+#     )
+
+#     res = validation_operators_data_context.run_validation_operator(
+#         "store_val_res_and_extract_eval_params",
+#         assets_to_validate=[
+#             (
+#                 validation_operators_data_context.build_batch_kwargs(
+#                     "my_datasource", "subdir_reader", "f1"
+#                 ),
+#                 "param_suite",
+#             )
+#         ],
+#         evaluation_parameters={
+#             "urn:great_expectations:validations:source_patient_data.default:expect_table_row_count_to_equal.result"
+#             ".observed_value": 3
+#         },
+#     )
+
+#     assert (
+#         res["success"] is True
+#     ), "No exception thrown, validation operators ran successfully"
+
+
 @mock_s3
 def test_tuple_s3_store_backend_slash_conditions():
     bucket = "my_bucket"
@@ -733,6 +975,39 @@ def test_TupleS3StoreBackend_with_empty_prefixes():
     )
 
 
+@mock_s3
+def test_TupleS3StoreBackend_with_s3_put_options():
+
+    bucket = "leakybucket"
+    conn = boto3.client("s3", region_name="us-east-1")
+    conn.create_bucket(Bucket=bucket)
+
+    my_store = TupleS3StoreBackend(
+        bucket=bucket,
+        # Since not all out options are supported in moto, only Metadata and StorageClass is passed here.
+        s3_put_options={
+            "Metadata": {"test": "testMetadata"},
+            "StorageClass": "REDUCED_REDUNDANCY",
+        },
+    )
+
+    assert my_store.config["s3_put_options"] == {
+        "Metadata": {"test": "testMetadata"},
+        "StorageClass": "REDUCED_REDUNDANCY",
+    }
+
+    my_store.set(("AAA",), "aaa")
+
+    res = conn.get_object(Bucket=bucket, Key="AAA")
+
+    assert res["Metadata"] == {"test": "testMetadata"}
+    assert res["StorageClass"] == "REDUCED_REDUNDANCY"
+
+    assert my_store.get(("AAA",)) == "aaa"
+    assert my_store.has_key(("AAA",))
+    assert my_store.list_keys() == [(".ge_store_backend_id",), ("AAA",)]
+
+
 def test_TupleGCSStoreBackend_base_public_path():
     """
     What does this test and why?
@@ -799,7 +1074,7 @@ def test_TupleGCSStoreBackend():
     with patch("google.cloud.storage.Client", autospec=True) as mock_gcs_client:
 
         mock_client = mock_gcs_client.return_value
-        mock_bucket = mock_client.get_bucket.return_value
+        mock_bucket = mock_client.bucket.return_value
         mock_blob = mock_bucket.blob.return_value
 
         my_store = TupleGCSStoreBackend(
@@ -812,7 +1087,7 @@ def test_TupleGCSStoreBackend():
         my_store.set(("AAA",), "aaa", content_type="text/html")
 
         mock_gcs_client.assert_called_with("dummy-project")
-        mock_client.get_bucket.assert_called_with("leakybucket")
+        mock_client.bucket.assert_called_with("leakybucket")
         mock_bucket.blob.assert_called_with("this_is_a_test_prefix/my_file_AAA")
         # mock_bucket.blob.assert_any_call("this_is_a_test_prefix/.ge_store_backend_id")
         mock_blob.upload_from_string.assert_called_with(
@@ -821,7 +1096,7 @@ def test_TupleGCSStoreBackend():
 
     with patch("google.cloud.storage.Client", autospec=True) as mock_gcs_client:
         mock_client = mock_gcs_client.return_value
-        mock_bucket = mock_client.get_bucket.return_value
+        mock_bucket = mock_client.bucket.return_value
         mock_blob = mock_bucket.blob.return_value
 
         my_store_with_no_filepath_template = TupleGCSStoreBackend(
@@ -833,7 +1108,7 @@ def test_TupleGCSStoreBackend():
         )
 
         mock_gcs_client.assert_called_with("dummy-project")
-        mock_client.get_bucket.assert_called_with("leakybucket")
+        mock_client.bucket.assert_called_with("leakybucket")
         mock_bucket.blob.assert_called_with("this_is_a_test_prefix/AAA")
         # mock_bucket.blob.assert_any_call("this_is_a_test_prefix/.ge_store_backend_id")
         mock_blob.upload_from_string.assert_called_with(
@@ -843,14 +1118,14 @@ def test_TupleGCSStoreBackend():
     with patch("google.cloud.storage.Client", autospec=True) as mock_gcs_client:
 
         mock_client = mock_gcs_client.return_value
-        mock_bucket = mock_client.get_bucket.return_value
+        mock_bucket = mock_client.bucket.return_value
         mock_blob = mock_bucket.get_blob.return_value
         mock_str = mock_blob.download_as_string.return_value
 
         my_store.get(("BBB",))
 
         mock_gcs_client.assert_called_once_with("dummy-project")
-        mock_client.get_bucket.assert_called_once_with("leakybucket")
+        mock_client.bucket.assert_called_once_with("leakybucket")
         mock_bucket.get_blob.assert_called_once_with(
             "this_is_a_test_prefix/my_file_BBB"
         )
@@ -872,7 +1147,7 @@ def test_TupleGCSStoreBackend():
         from google.cloud.exceptions import NotFound
 
         try:
-            mock_client.get_bucket.assert_called_once_with("leakybucket")
+            mock_client.bucket.assert_called_once_with("leakybucket")
         except NotFound:
             pass
 
@@ -1042,7 +1317,7 @@ def test_GeCloudStoreBackend():
         "access_token": "1234",
         "account_id": "51379b8b-86d3-4fe7-84e9-e1a52f4a414c",
     }
-    ge_cloud_resource_type = "checkpoint"
+    ge_cloud_resource_type = "contract"
     my_simple_checkpoint_config: CheckpointConfig = CheckpointConfig(
         name="my_minimal_simple_checkpoint",
         class_name="SimpleCheckpoint",
@@ -1061,14 +1336,12 @@ def test_GeCloudStoreBackend():
             ge_cloud_credentials=ge_cloud_credentials,
             ge_cloud_resource_type=ge_cloud_resource_type,
         )
-        my_store_backend.set(
-            ("my_checkpoint_name",), my_simple_checkpoint_config_serialized
-        )
+        my_store_backend.set(("contract", ""), my_simple_checkpoint_config_serialized)
         mock_post.assert_called_with(
-            "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/checkpoints",
+            "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/contracts",
             json={
                 "data": {
-                    "type": "checkpoint",
+                    "type": "contract",
                     "attributes": {
                         "account_id": "51379b8b-86d3-4fe7-84e9-e1a52f4a414c",
                         "checkpoint_config": OrderedDict(
@@ -1087,6 +1360,7 @@ def test_GeCloudStoreBackend():
                                 ("validations", []),
                                 ("profilers", []),
                                 ("ge_cloud_id", None),
+                                ("expectation_suite_ge_cloud_id", None),
                             ]
                         ),
                     },
@@ -1105,9 +1379,15 @@ def test_GeCloudStoreBackend():
                 ge_cloud_credentials=ge_cloud_credentials,
                 ge_cloud_resource_type=ge_cloud_resource_type,
             )
-            my_store_backend.get(("0ccac18e-7631-4bdd-8a42-3c35cce574c6",))
+            my_store_backend.get(
+                (
+                    "contract",
+                    "0ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                )
+            )
             mock_get.assert_called_with(
-                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/checkpoints/0ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/contracts/0ccac18e-7631"
+                "-4bdd-8a42-3c35cce574c6",
                 headers={
                     "Content-Type": "application/vnd.api+json",
                     "Authorization": "Bearer 1234",
@@ -1123,7 +1403,7 @@ def test_GeCloudStoreBackend():
             )
             my_store_backend.list_keys()
             mock_get.assert_called_with(
-                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/checkpoints",
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/contracts",
                 headers={
                     "Content-Type": "application/vnd.api+json",
                     "Authorization": "Bearer 1234",
@@ -1140,12 +1420,19 @@ def test_GeCloudStoreBackend():
                 ge_cloud_credentials=ge_cloud_credentials,
                 ge_cloud_resource_type=ge_cloud_resource_type,
             )
-            my_store_backend.remove_key(("0ccac18e-7631-4bdd-8a42-3c35cce574c6",))
+            my_store_backend.remove_key(
+                (
+                    "contract",
+                    "0ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                )
+            )
             mock_patch.assert_called_with(
-                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/checkpoints/0ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/contracts/0ccac18e-7631"
+                "-4bdd"
+                "-8a42-3c35cce574c6",
                 json={
                     "data": {
-                        "type": "checkpoint",
+                        "type": "contract",
                         "id": "0ccac18e-7631-4bdd-8a42-3c35cce574c6",
                         "attributes": {"deleted": True},
                     }
@@ -1155,3 +1442,99 @@ def test_GeCloudStoreBackend():
                     "Authorization": "Bearer 1234",
                 },
             )
+
+    # test .set
+    with patch("requests.post", autospec=True) as mock_post:
+        my_store_backend = GeCloudStoreBackend(
+            ge_cloud_base_url=ge_cloud_base_url,
+            ge_cloud_credentials=ge_cloud_credentials,
+            ge_cloud_resource_type="rendered_data_doc",
+        )
+        my_store_backend.set(("rendered_data_doc", ""), OrderedDict())
+        mock_post.assert_called_with(
+            "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/rendered-data-docs",
+            json={
+                "data": {
+                    "type": "rendered_data_doc",
+                    "attributes": {
+                        "account_id": "51379b8b-86d3-4fe7-84e9-e1a52f4a414c",
+                        "rendered_data_doc": OrderedDict(),
+                    },
+                }
+            },
+            headers={
+                "Content-Type": "application/vnd.api+json",
+                "Authorization": "Bearer 1234",
+            },
+        )
+
+        # test .get
+        with patch("requests.get", autospec=True) as mock_get:
+            my_store_backend = GeCloudStoreBackend(
+                ge_cloud_base_url=ge_cloud_base_url,
+                ge_cloud_credentials=ge_cloud_credentials,
+                ge_cloud_resource_type="rendered_data_doc",
+            )
+            my_store_backend.get(
+                (
+                    "rendered_data_doc",
+                    "1ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                )
+            )
+            mock_get.assert_called_with(
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/rendered-data-docs/1ccac18e-7631"
+                "-4bdd-8a42-3c35cce574c6",
+                headers={
+                    "Content-Type": "application/vnd.api+json",
+                    "Authorization": "Bearer 1234",
+                },
+            )
+
+        # test .list_keys
+        with patch("requests.get", autospec=True) as mock_get:
+            my_store_backend = GeCloudStoreBackend(
+                ge_cloud_base_url=ge_cloud_base_url,
+                ge_cloud_credentials=ge_cloud_credentials,
+                ge_cloud_resource_type="rendered_data_doc",
+            )
+            my_store_backend.list_keys()
+            mock_get.assert_called_with(
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/rendered-data-docs",
+                headers={
+                    "Content-Type": "application/vnd.api+json",
+                    "Authorization": "Bearer 1234",
+                },
+            )
+
+        # test .remove_key
+        with patch("requests.patch", autospec=True) as mock_patch:
+            mock_response = mock_patch.return_value
+            mock_response.status_code = 200
+
+            my_store_backend = GeCloudStoreBackend(
+                ge_cloud_base_url=ge_cloud_base_url,
+                ge_cloud_credentials=ge_cloud_credentials,
+                ge_cloud_resource_type="rendered_data_doc",
+            )
+            my_store_backend.remove_key(
+                (
+                    "rendered_data_doc",
+                    "1ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                )
+            )
+            mock_patch.assert_called_with(
+                "https://app.greatexpectations.io/accounts/51379b8b-86d3-4fe7-84e9-e1a52f4a414c/rendered-data-docs/1ccac18e-7631"
+                "-4bdd"
+                "-8a42-3c35cce574c6",
+                json={
+                    "data": {
+                        "type": "rendered_data_doc",
+                        "id": "1ccac18e-7631-4bdd-8a42-3c35cce574c6",
+                        "attributes": {"deleted": True},
+                    }
+                },
+                headers={
+                    "Content-Type": "application/vnd.api+json",
+                    "Authorization": "Bearer 1234",
+                },
+            )
