@@ -5,7 +5,11 @@ import pytest
 from freezegun import freeze_time
 from moto import mock_s3
 
+import tests.test_utils as test_utils
 from great_expectations.core import ExpectationSuiteValidationResult
+from great_expectations.core.expectation_validation_result import (
+    ExpectationSuiteValidationResult,
+)
 from great_expectations.data_context.store import ValidationsStore
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
@@ -62,14 +66,13 @@ def test_ValidationsStore_with_TupleS3StoreBackend():
     )
 
     # Verify that internals are working as expected, including the default filepath
-    assert set(
-        [
-            s3_object_info["Key"]
-            for s3_object_info in boto3.client("s3").list_objects_v2(
-                Bucket=bucket, Prefix=prefix
-            )["Contents"]
-        ]
-    ) == {
+    assert {
+        s3_object_info["Key"]
+        for s3_object_info in boto3.client("s3").list_objects_v2(
+            Bucket=bucket, Prefix=prefix
+        )["Contents"]
+    } == {
+        "test/prefix/.ge_store_backend_id",
         "test/prefix/asset/quarantine/20191007T151224.1234Z_prod_100/20190926T134241.000000Z/batch_id.json",
         "test/prefix/asset/quarantine/20191007T151224.1234Z_prod_200/20190926T134241.000000Z/batch_id.json",
     }
@@ -80,6 +83,16 @@ def test_ValidationsStore_with_TupleS3StoreBackend():
         ns_2,
     }
 
+    """
+    What does this test and why?
+    A Store should be able to report it's store_backend_id
+    which is set when the StoreBackend is instantiated.
+    """
+    # Check that store_backend_id exists can be read
+    assert my_store.store_backend_id is not None
+    # Check that store_backend_id is a valid UUID
+    assert test_utils.validate_uuid4(my_store.store_backend_id)
+
 
 @freeze_time("09/26/2019 13:42:41")
 def test_ValidationsStore_with_InMemoryStoreBackend():
@@ -122,11 +135,19 @@ def test_ValidationsStore_with_InMemoryStoreBackend():
     assert my_store.get(ns_2) == ExpectationSuiteValidationResult(
         success=False, statistics={}, results=[]
     )
-
     assert set(my_store.list_keys()) == {
         ns_1,
         ns_2,
     }
+    """
+    What does this test and why?
+    A Store should be able to report it's store_backend_id
+    which is set when the StoreBackend is instantiated.
+    """
+    # Check that store_backend_id exists can be read
+    assert my_store.store_backend_id is not None
+    # Check that store_backend_id is a valid UUID
+    assert test_utils.validate_uuid4(my_store.store_backend_id)
 
 
 @freeze_time("09/26/2019 13:42:41")
@@ -186,6 +207,7 @@ def test_ValidationsStore_with_TupleFileSystemStoreBackend(tmp_path_factory):
         == """\
 test_ValidationResultStore_with_TupleFileSystemStoreBackend__dir0/
     my_store/
+        .ge_store_backend_id
         asset/
             quarantine/
                 prod-100/
@@ -197,6 +219,27 @@ test_ValidationResultStore_with_TupleFileSystemStoreBackend__dir0/
 """
     )
 
+    """
+    What does this test and why?
+    A Store should be able to report it's store_backend_id
+    which is set when the StoreBackend is instantiated.
+    """
+    # Check that store_backend_id exists can be read
+    assert my_store.store_backend_id is not None
+    # Check that store_backend_id is a valid UUID
+    assert test_utils.validate_uuid4(my_store.store_backend_id)
+
+    # Check that another store with the same configuration shares the same store_backend_id
+    my_store_duplicate = ValidationsStore(
+        store_backend={
+            "module_name": "great_expectations.data_context.store",
+            "class_name": "TupleFilesystemStoreBackend",
+            "base_directory": "my_store/",
+        },
+        runtime_environment={"root_directory": path},
+    )
+    assert my_store.store_backend_id == my_store_duplicate.store_backend_id
+
 
 def test_ValidationsStore_with_DatabaseStoreBackend(sa):
     # Use sqlite so we don't require postgres for this test.
@@ -242,3 +285,13 @@ def test_ValidationsStore_with_DatabaseStoreBackend(sa):
         ns_1,
         ns_2,
     }
+
+    """
+    What does this test and why?
+    A Store should be able to report it's store_backend_id
+    which is set when the StoreBackend is instantiated.
+    """
+    # Check that store_backend_id exists can be read
+    assert my_store.store_backend_id is not None
+    # Check that store_backend_id is a valid UUID
+    assert test_utils.validate_uuid4(my_store.store_backend_id)
