@@ -1,10 +1,13 @@
 import datetime
 import json
+from unittest import mock
 
 import pandas as pd
 import pytest
 
 import great_expectations as ge
+from great_expectations import DataContext
+from great_expectations.core import ExpectationSuite
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.profile import ColumnsExistProfiler
 from great_expectations.self_check.util import (
@@ -530,7 +533,8 @@ def test_ge_pandas_merging():
     assert df.get_expectation_suite().expectations == exp_m
 
 
-def test_ge_pandas_sampling():
+def test_ge_pandas_sampling(empty_data_context):
+    context: DataContext = empty_data_context
     df = ge.dataset.PandasDataset(
         {
             "A": [1, 2, 3, 4],
@@ -567,7 +571,7 @@ def test_ge_pandas_sampling():
     # in the sample.
     df.expect_column_values_to_be_in_set("D", ["e", "f", "g", "x"])
     samp1 = df.sample(n=2)
-    exp1 = expectationSuiteSchema.load(
+    exp1_dict: dict = expectationSuiteSchema.load(
         {
             "expectation_suite_name": "test",
             "expectations": [
@@ -606,6 +610,7 @@ def test_ge_pandas_sampling():
             ],
         }
     )
+    exp1: ExpectationSuite = ExpectationSuite(**exp1_dict, data_context=context)
     assert (
         samp1.get_expectation_suite(discard_failed_expectations=False).expectations
         == exp1.expectations
@@ -668,6 +673,10 @@ def test_ge_pandas_subsetting():
     assert sub1.get_expectation_suite().expectations == exp1
 
 
+@pytest.mark.filterwarnings(
+    "ignore:DataAsset.remove_expectations*:DeprecationWarning:great_expectations.data_asset"
+)
+@pytest.mark.filterwarnings("ignore:Removed*:UserWarning:great_expectations.data_asset")
 def test_ge_pandas_automatic_failure_removal():
     df = ge.dataset.PandasDataset(
         {
@@ -882,6 +891,30 @@ def test_ge_value_count_of_object_dtype_column_with_mixed_types():
     assert value_counts["I am a string in an otherwise float column"] == 1
 
 
+@mock.patch(
+    "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
+)
+def test_adding_expectation_to_pandas_dataset_not_send_usage_message(mock_emit):
+    """
+    What does this test and why?
+
+    When an Expectation is called using a PandasDataset, it validates the dataset using the implementation of
+    the Expectation. As part of the process, it also adds the Expectation to the active
+    ExpectationSuite. This test ensures that this in-direct way of adding an Expectation to the ExpectationSuite
+    (ie not calling add_expectations() directly) does not emit a usage_stats event.
+    """
+    df = ge.dataset.PandasDataset(
+        {
+            "A": [[1, 2], None, [4, 5], 6],
+        }
+    )
+
+    validation = df.expect_column_values_to_be_of_type("A", "list")
+    # add_expectation() will not send usage_statistics event when called from a Pandas Dataset
+    assert mock_emit.call_count == 0
+    assert mock_emit.call_args_list == []
+
+
 def test_expect_values_to_be_of_type_list():
     """
     Having lists in a Pandas column used to raise a ValueError when parsing to
