@@ -18,6 +18,7 @@ from great_expectations.core.batch import (
 )
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.datasource.data_connector import ConfiguredAssetS3DataConnector
+from great_expectations.execution_engine import PandasExecutionEngine
 
 yaml = YAML()
 
@@ -45,6 +46,7 @@ def test_basic_instantiation():
     my_data_connector = ConfiguredAssetS3DataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        execution_engine=PandasExecutionEngine(),
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
@@ -133,6 +135,9 @@ def test_instantiation_from_a_config(mock_emit, empty_data_context_stats_enabled
         assets:
             alpha:
     """,
+        runtime_environment={
+            "execution_engine": PandasExecutionEngine(),
+        },
         return_mode="report_object",
     )
 
@@ -222,6 +227,9 @@ assets:
     alpha:
 
     """,
+        runtime_environment={
+            "execution_engine": PandasExecutionEngine(),
+        },
         return_mode="report_object",
     )
 
@@ -293,8 +301,6 @@ def test_return_all_batch_definitions_unsorted():
         f"""
             class_name: ConfiguredAssetS3DataConnector
             datasource_name: test_environment
-            #execution_engine:
-            #    class_name: PandasExecutionEngine
             bucket: {bucket}
             prefix: ""
             assets:
@@ -312,12 +318,13 @@ def test_return_all_batch_definitions_unsorted():
         config=my_data_connector_yaml,
         runtime_environment={
             "name": "general_s3_data_connector",
-            "datasource_name": "test_environment",
+            "execution_engine": PandasExecutionEngine(),
         },
         config_defaults={"module_name": "great_expectations.datasource.data_connector"},
     )
 
     with pytest.raises(TypeError):
+        # noinspection PyArgumentList
         my_data_connector.get_batch_definition_list_from_batch_request()
 
     # with unnamed data_asset_name
@@ -326,7 +333,7 @@ def test_return_all_batch_definitions_unsorted():
             BatchRequest(
                 datasource_name="test_environment",
                 data_connector_name="general_s3_data_connector",
-                data_asset_name=None,
+                data_asset_name="",
             )
         )
 
@@ -336,7 +343,7 @@ def test_return_all_batch_definitions_unsorted():
             BatchRequestBase(
                 datasource_name="test_environment",
                 data_connector_name="general_s3_data_connector",
-                data_asset_name=None,
+                data_asset_name="",
             )
         )
     )
@@ -468,8 +475,6 @@ def test_return_all_batch_definitions_sorted():
         f"""
         class_name: ConfiguredAssetS3DataConnector
         datasource_name: test_environment
-        #execution_engine:
-        #    class_name: PandasExecutionEngine
         bucket: {bucket}
         prefix: ""
         assets:
@@ -499,7 +504,7 @@ def test_return_all_batch_definitions_sorted():
         config=my_data_connector_yaml,
         runtime_environment={
             "name": "general_s3_data_connector",
-            "datasource_name": "test_environment",
+            "execution_engine": PandasExecutionEngine(),
         },
         config_defaults={"module_name": "great_expectations.datasource.data_connector"},
     )
@@ -689,6 +694,7 @@ def test_alpha():
         f"""
                 module_name: great_expectations.datasource.data_connector
                 class_name: ConfiguredAssetS3DataConnector
+                datasource_name: BASE
                 bucket: {bucket}
                 prefix: test_dir_alpha
                 assets:
@@ -704,7 +710,7 @@ def test_alpha():
         config=my_data_connector_yaml,
         runtime_environment={
             "name": "general_s3_data_connector",
-            "datasource_name": "BASE",
+            "execution_engine": PandasExecutionEngine(),
         },
         config_defaults={"module_name": "great_expectations.datasource.data_connector"},
     )
@@ -783,6 +789,7 @@ def test_foxtrot():
         f"""
             module_name: great_expectations.datasource.data_connector
             class_name: ConfiguredAssetS3DataConnector
+            datasource_name: BASE
             bucket: {bucket}
             prefix: test_dir_foxtrot
             assets:
@@ -810,7 +817,7 @@ def test_foxtrot():
         config=my_data_connector_yaml,
         runtime_environment={
             "name": "general_s3_data_connector",
-            "datasource_name": "BASE",
+            "execution_engine": PandasExecutionEngine(),
         },
         config_defaults={"module_name": "great_expectations.datasource.data_connector"},
     )
@@ -897,8 +904,6 @@ def test_return_all_batch_definitions_sorted_sorter_named_that_does_not_match_gr
         f"""
         class_name: ConfiguredAssetS3DataConnector
         datasource_name: test_environment
-        #execution_engine:
-        #    class_name: PandasExecutionEngine
         bucket: bucket
         assets:
             TestFiles:
@@ -931,7 +936,7 @@ def test_return_all_batch_definitions_sorted_sorter_named_that_does_not_match_gr
                 config=my_data_connector_yaml,
                 runtime_environment={
                     "name": "general_s3_data_connector",
-                    "datasource_name": "test_environment",
+                    "execution_engine": PandasExecutionEngine(),
                 },
                 config_defaults={
                     "module_name": "great_expectations.datasource.data_connector"
@@ -971,8 +976,6 @@ def test_return_all_batch_definitions_too_many_sorters():
         f"""
         class_name: ConfiguredAssetS3DataConnector
         datasource_name: test_environment
-        #execution_engine:
-        #    class_name: PandasExecutionEngine
         bucket: {bucket}
         prefix: ""
         assets:
@@ -1002,7 +1005,7 @@ def test_return_all_batch_definitions_too_many_sorters():
                 config=my_data_connector_yaml,
                 runtime_environment={
                     "name": "general_s3_data_connector",
-                    "datasource_name": "test_environment",
+                    "execution_engine": PandasExecutionEngine(),
                 },
                 config_defaults={
                     "module_name": "great_expectations.datasource.data_connector"
@@ -1066,7 +1069,10 @@ assets:
     my_data_connector = instantiate_class_from_config(
         config,
         config_defaults={"module_name": "great_expectations.datasource.data_connector"},
-        runtime_environment={"name": "my_data_connector"},
+        runtime_environment={
+            "name": "my_data_connector",
+            "execution_engine": PandasExecutionEngine(),
+        },
     )
     # noinspection PyProtectedMember
     my_data_connector._refresh_data_references_cache()
