@@ -1,7 +1,7 @@
 import json
 import os
 import shutil
-from typing import List
+from typing import List, Union
 
 import pandas as pd
 import pytest
@@ -204,6 +204,7 @@ def test_basic_pandas_datasource_v013_self_check(basic_pandas_datasource_v013):
             "discard_subset_failing_expectations": False,
             "boto3_options": {},
             "azure_options": {},
+            "gcs_options": {},
         },
         "data_connectors": {
             "count": 2,
@@ -265,6 +266,7 @@ def test_basic_spark_datasource_self_check(basic_spark_datasource):
         },
         "execution_engine": {
             "caching": True,
+            "azure_options": {},
             "class_name": "SparkDFExecutionEngine",
             "module_name": "great_expectations.execution_engine.sparkdf_execution_engine",
             "persist": True,
@@ -491,8 +493,9 @@ def test_get_batch_with_pipeline_style_batch_request_missing_data_connector_quer
         },
         "batch_identifiers": None,
     }
-    batch_request: BatchRequest = RuntimeBatchRequest(**batch_request)
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(TypeError):
+        batch_request: BatchRequest = RuntimeBatchRequest(**batch_request)
+
         # noinspection PyUnusedLocal
         batch_list: List[
             Batch
