@@ -8,7 +8,6 @@ from unittest import mock
 import boto3
 import pandas as pd
 import pytest
-from botocore.errorfactory import ClientError
 from moto import mock_s3
 
 try:
@@ -21,17 +20,21 @@ import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.batch import BatchDefinition
 from great_expectations.core.batch_spec import (
     AzureBatchSpec,
+    GCSBatchSpec,
     PathBatchSpec,
     RuntimeDataBatchSpec,
     S3BatchSpec,
 )
 from great_expectations.core.id_dict import IDDict
 from great_expectations.datasource.data_connector import ConfiguredAssetS3DataConnector
-from great_expectations.execution_engine.execution_engine import MetricDomainTypes
+from great_expectations.execution_engine.execution_engine import (
+    ExecutionEngine,
+    MetricDomainTypes,
+)
 from great_expectations.execution_engine.pandas_execution_engine import (
     PandasExecutionEngine,
 )
-from great_expectations.validator.validation_graph import MetricConfiguration
+from great_expectations.validator.metric_configuration import MetricConfiguration
 from tests.expectations.test_util import get_table_columns_metric
 
 
@@ -166,6 +169,28 @@ def azure_batch_spec() -> AzureBatchSpec:
     return batch_spec
 
 
+@pytest.fixture
+def gcs_batch_spec() -> GCSBatchSpec:
+    bucket = "test_bucket"
+    keys: List[str] = [
+        "path/A-100.csv",
+        "path/A-101.csv",
+        "directory/B-1.csv",
+        "directory/B-2.csv",
+        "alpha-1.csv",
+        "alpha-2.csv",
+    ]
+    path = keys[0]
+    full_path = os.path.join("gs://", bucket, path)
+
+    batch_spec = GCSBatchSpec(
+        path=full_path,
+        reader_method="read_csv",
+        splitter_method="_split_on_whole_table",
+    )
+    return batch_spec
+
+
 def test_constructor_with_boto3_options():
     # default instantiation
     PandasExecutionEngine()
@@ -238,9 +263,13 @@ def test_get_domain_records_with_column_pair_domain():
     )
 
     expected_column_pair_df = pd.DataFrame(
-        {"a": [2, 3, 4, 6], "b": [3.0, 4.0, 5.0, 6.0], "c": [2.0, 3.0, 4.0, None]}
+        {
+            "a": [2, 3, 4, 6],
+            "b": [3.0, 4.0, 5.0, 6.0],
+            "c": [2.0, 3.0, 4.0, None],
+        },
+        index=[1, 2, 3, 5],
     )
-
     assert data.equals(
         expected_column_pair_df
     ), "Data does not match after getting full access compute domain"
@@ -257,7 +286,7 @@ def test_get_domain_records_with_column_pair_domain():
     data = data.astype(int)
 
     expected_column_pair_df = pd.DataFrame(
-        {"a": [2, 3, 4], "b": [3, 4, 5], "c": [2, 3, 4]}
+        {"a": [2, 3, 4], "b": [3, 4, 5], "c": [2, 3, 4]}, index=[1, 2, 3]
     )
 
     assert data.equals(
@@ -310,7 +339,7 @@ def test_get_domain_records_with_multicolumn_domain():
     data = data.astype(int)
 
     expected_multicolumn_df = pd.DataFrame(
-        {"a": [2, 3, 4, 5], "b": [3, 4, 5, 7], "c": [2, 3, 4, 6]}, index=[0, 1, 2, 4]
+        {"a": [2, 3, 4, 5], "b": [3, 4, 5, 7], "c": [2, 3, 4, 6]}, index=[1, 2, 3, 5]
     )
 
     assert data.equals(
@@ -442,7 +471,7 @@ def test_get_compute_domain_with_column_domain():
 def test_get_compute_domain_with_row_condition():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
-    expected_df = df[df["b"] > 2].reset_index()
+    expected_df = df[df["b"] > 2]
 
     # Loading batch data
     engine.load_batch_data(batch_data=df, batch_id="1234")
@@ -467,7 +496,7 @@ def test_get_compute_domain_with_row_condition():
 def test_get_compute_domain_with_unmeetable_row_condition():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
-    expected_df = df[df["b"] > 24].reset_index()
+    expected_df = df[df["b"] > 24]
 
     # Loading batch data
     engine.load_batch_data(batch_data=df, batch_id="1234")
@@ -586,7 +615,7 @@ def test_get_batch_data(test_df):
         PandasExecutionEngine().get_batch_data(RuntimeDataBatchSpec())
 
 
-def test_get_batch_with_split_on_whole_table(test_df):
+def test_get_batch_with_split_on_whole_table_runtime(test_df):
     split_df = PandasExecutionEngine().get_batch_data(
         RuntimeDataBatchSpec(
             batch_data=test_df, splitter_method="_split_on_whole_table"
@@ -617,32 +646,25 @@ def test_get_batch_with_split_on_whole_table_s3(
     assert df.dataframe.shape == test_df_small.shape
 
 
-def test_get_batch_with_no_s3_configured(batch_with_split_on_whole_table_s3):
-    # if S3 was not configured
-    execution_engine_no_s3 = PandasExecutionEngine()
-    execution_engine_no_s3._s3 = None
-    with pytest.raises(ge_exceptions.ExecutionEngineError):
-        execution_engine_no_s3.get_batch_data(
-            batch_spec=batch_with_split_on_whole_table_s3
-        )
-
-
 def test_get_batch_with_split_on_whole_table_s3_with_configured_asset_s3_data_connector(
     test_s3_files, test_df_small
 ):
     bucket, _keys = test_s3_files
     expected_df = test_df_small
 
+    execution_engine: ExecutionEngine = PandasExecutionEngine()
+
     my_data_connector = ConfiguredAssetS3DataConnector(
         name="my_data_connector",
         datasource_name="FAKE_DATASOURCE_NAME",
+        bucket=bucket,
+        execution_engine=execution_engine,
+        prefix="",
+        assets={"alpha": {}},
         default_regex={
             "pattern": "alpha-(.*)\\.csv",
             "group_names": ["index"],
         },
-        bucket=bucket,
-        prefix="",
-        assets={"alpha": {}},
     )
     batch_def = BatchDefinition(
         datasource_name="FAKE_DATASOURCE_NAME",
@@ -654,7 +676,7 @@ def test_get_batch_with_split_on_whole_table_s3_with_configured_asset_s3_data_co
             "splitter_method": "_split_on_whole_table",
         },
     )
-    test_df = PandasExecutionEngine().get_batch_data(
+    test_df = execution_engine.get_batch_data(
         batch_spec=my_data_connector.build_batch_spec(batch_definition=batch_def)
     )
     assert test_df.dataframe.shape == expected_df.shape
@@ -670,8 +692,8 @@ def test_get_batch_with_split_on_whole_table_s3_with_configured_asset_s3_data_co
             "splitter_method": "_split_on_whole_table",
         },
     )
-    with pytest.raises(ClientError):
-        PandasExecutionEngine().get_batch_data(
+    with pytest.raises(ge_exceptions.ExecutionEngineError):
+        execution_engine.get_batch_data(
             batch_spec=my_data_connector.build_batch_spec(
                 batch_definition=batch_def_no_key
             )
@@ -698,6 +720,19 @@ def test_get_batch_s3_parquet(test_s3_files_parquet, test_df_small):
     assert df.dataframe.shape == test_df_small.shape
 
 
+def test_get_batch_with_no_s3_configured():
+    batch_spec = S3BatchSpec(
+        path="s3a://i_dont_exist",
+        reader_method="read_csv",
+        splitter_method="_split_on_whole_table",
+    )
+    # if S3 was not configured
+    execution_engine_no_s3 = PandasExecutionEngine()
+
+    with pytest.raises(ge_exceptions.ExecutionEngineError):
+        execution_engine_no_s3.get_batch_data(batch_spec=batch_spec)
+
+
 def test_get_batch_with_split_on_column_value(test_df):
     split_df = PandasExecutionEngine().get_batch_data(
         RuntimeDataBatchSpec(
@@ -939,7 +974,7 @@ def test_get_batch_with_split_on_divided_integer_and_sample_on_list(test_df):
 
 
 @mock.patch(
-    "great_expectations.datasource.data_connector.configured_asset_azure_data_connector.BlobServiceClient"
+    "great_expectations.execution_engine.pandas_execution_engine.BlobServiceClient",
 )
 def test_constructor_with_azure_options(mock_azure_conn):
     # default instantiation
@@ -986,3 +1021,65 @@ def test_get_batch_with_no_azure_configured(azure_batch_spec):
     # Raises error due the connection object not being set
     with pytest.raises(ge_exceptions.ExecutionEngineError):
         execution_engine_no_azure.get_batch_data(batch_spec=azure_batch_spec)
+
+
+@mock.patch(
+    "great_expectations.execution_engine.pandas_execution_engine.service_account",
+)
+@mock.patch(
+    "great_expectations.execution_engine.pandas_execution_engine.storage.Client",
+)
+def test_constructor_with_gcs_options(mock_gcs_conn, mock_auth_method):
+    # default instantiation
+    PandasExecutionEngine()
+
+    # instantiation with custom parameters
+    engine = PandasExecutionEngine(discard_subset_failing_expectations=True)
+    assert "discard_subset_failing_expectations" in engine.config
+    assert engine.config.get("discard_subset_failing_expectations") is True
+    custom_gcs_options = {"filename": "a/b/c/my_gcs_credentials.json"}
+    engine = PandasExecutionEngine(gcs_options=custom_gcs_options)
+    assert "gcs_options" in engine.config
+    assert "filename" in engine.config.get("gcs_options")
+
+
+@mock.patch(
+    "great_expectations.execution_engine.pandas_execution_engine.storage.Client",
+)
+def test_get_batch_data_with_gcs_batch_spec(
+    mock_gcs_conn,
+    gcs_batch_spec,
+):
+    mock_gcs_bucket = mock_gcs_conn().get_bucket()
+    mock_gcs_blob = mock_gcs_bucket.blob()
+    mock_gcs_blob.download_as_bytes.return_value = (
+        b"colA,colB,colC\n1,2,3\n4,5,6\n7,8,9"  # (3,3) CSV for testing
+    )
+
+    # Necessary to pass kwargs to bypass "os.getenv | gcs_options == {}" check
+    kwargs = {"gcs_options": {"my_option": "my_value"}}
+    df = PandasExecutionEngine(**kwargs).get_batch_data(batch_spec=gcs_batch_spec)
+
+    mock_gcs_conn().get_bucket.assert_called_with("test_bucket")
+    mock_gcs_bucket.blob.assert_called_with("path/A-100.csv")
+    mock_gcs_blob.download_as_bytes.assert_called_once()
+
+    assert df.dataframe.shape == (3, 3)
+
+
+def test_get_batch_data_with_gcs_batch_spec_no_credentials(gcs_batch_spec, monkeypatch):
+    # If PandasExecutionEngine contains no credentials for GCS, we will still instantiate _gcs engine,
+    # but will raise Exception when trying get_batch_data(). The only situation where it would work is if we are running in a Google Cloud container.
+    # TODO : Determine how we can test the scenario where we are running PandasExecutionEngine from within Google Cloud env.
+
+    monkeypatch.delenv("GOOGLE_APPLICATION_CREDENTIALS", raising=False)
+    with pytest.raises(Exception):
+        PandasExecutionEngine().get_batch_data(batch_spec=gcs_batch_spec)
+
+
+def test_get_batch_with_gcs_misconfigured(gcs_batch_spec):
+    # gcs_batchspec point to data that the ExecutionEngine does not have access to
+    execution_engine_no_gcs = PandasExecutionEngine()
+    # Raises error if batch_spec causes ExecutionEngine error
+    with pytest.raises(ge_exceptions.ExecutionEngineError):
+        execution_engine_no_gcs.get_batch_data(batch_spec=gcs_batch_spec)
