@@ -10,7 +10,7 @@ from util import load_data_into_database
 
 load_data_into_database(
     table_name="taxi_data",
-    csv_path="./data/yellow_trip_data_sample_2019-01.csv",
+    csv_path="./data/yellow_tripdata_sample_2019-01.csv",
     connection_string=CONNECTION_STRING,
 )
 
@@ -49,7 +49,7 @@ batch_request = RuntimeBatchRequest(
     data_connector_name="default_runtime_data_connector_name",
     data_asset_name="default_name",  # this can be anything that identifies this data
     runtime_parameters={"query": "SELECT * from taxi_data LIMIT 10"},
-    batch_identifiers={"default_identifier_name": "something_something"},
+    batch_identifiers={"default_identifier_name": "default_identifier"},
 )
 context.create_expectation_suite(
     expectation_suite_name="test_suite", overwrite_existing=True
