@@ -4,6 +4,8 @@ from collections import OrderedDict
 import pytest
 
 import great_expectations as ge
+from great_expectations import DataContext
+from great_expectations.core import ExpectationSuite
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.profile.basic_dataset_profiler import BasicDatasetProfiler
 from great_expectations.render.renderer import (
@@ -45,28 +47,34 @@ def titanic_profiler_evrs_with_exception():
 
 
 @pytest.fixture(scope="module")
-def titanic_dataset_profiler_expectations():
+def titanic_dataset_profiler_expectations(empty_data_context_module_scoped):
+    context: DataContext = empty_data_context_module_scoped
     with open(
         file_relative_path(
             __file__, "./fixtures/BasicDatasetProfiler_expectations.json"
         ),
     ) as infile:
-        return expectationSuiteSchema.load(
+        expectations_dict: dict = expectationSuiteSchema.load(
             json.load(fp=infile, object_pairs_hook=OrderedDict)
         )
+        return ExpectationSuite(**expectations_dict, data_context=context)
 
 
 @pytest.fixture(scope="module")
-def titanic_dataset_profiler_expectations_with_distribution():
+def titanic_dataset_profiler_expectations_with_distribution(
+    empty_data_context_module_scoped,
+):
+    context: DataContext = empty_data_context_module_scoped
     with open(
         file_relative_path(
             __file__,
             "./fixtures/BasicDatasetProfiler_expectations_with_distribution.json",
         ),
     ) as infile:
-        return expectationSuiteSchema.load(
+        expectations_dict: dict = expectationSuiteSchema.load(
             json.load(fp=infile, object_pairs_hook=OrderedDict)
         )
+        return ExpectationSuite(**expectations_dict, data_context=context)
 
 
 @pytest.mark.smoketest
