@@ -76,7 +76,9 @@ def test_instantiate_class_from_config_with_config_defaults():
             "module_name": "tests.test_plugins.fake_configs",
         },
         runtime_environment=my_runtime_environment,
-        config_defaults={"a": "value_from_the_defaults",},
+        config_defaults={
+            "a": "value_from_the_defaults",
+        },
     )
     assert fake_configurable_object.a == "value_from_the_defaults"
 
@@ -88,7 +90,9 @@ def test_instantiate_class_from_config_with_config_defaults():
             "a": "value_from_the_config",
         },
         runtime_environment=my_runtime_environment,
-        config_defaults={"a": "value_from_the_defaults",},
+        config_defaults={
+            "a": "value_from_the_defaults",
+        },
     )
     assert fake_configurable_object.a == "value_from_the_config"
 
@@ -105,9 +109,14 @@ def test_instantiate_class_from_config_with_config_defaults():
 
     # Module name specified in default, but not config.
     fake_configurable_object = instantiate_class_from_config(
-        config={"class_name": "FakeConfigurableClass", "a": "value_from_the_config",},
+        config={
+            "class_name": "FakeConfigurableClass",
+            "a": "value_from_the_config",
+        },
         runtime_environment=my_runtime_environment,
-        config_defaults={"module_name": "tests.test_plugins.fake_configs",},
+        config_defaults={
+            "module_name": "tests.test_plugins.fake_configs",
+        },
     )
 
     # Both
@@ -118,7 +127,9 @@ def test_instantiate_class_from_config_with_config_defaults():
             "a": "value_from_the_config",
         },
         runtime_environment=my_runtime_environment,
-        config_defaults={"module_name": "tests.test_plugins.fake_configs",},
+        config_defaults={
+            "module_name": "tests.test_plugins.fake_configs",
+        },
     )
 
     # Neither
@@ -134,7 +145,9 @@ def test_instantiate_class_from_config_with_config_defaults():
 
     # Pushing the limits of what we can do with this API...
     fake_configurable_object = instantiate_class_from_config(
-        config={"class_name": "FakeConfigurableClass",},
+        config={
+            "class_name": "FakeConfigurableClass",
+        },
         runtime_environment=my_runtime_environment,
         config_defaults={
             "module_name": "tests.test_plugins.fake_configs",
@@ -144,7 +157,9 @@ def test_instantiate_class_from_config_with_config_defaults():
 
     # This seems like too much magic, but maybe we'll find a place where it's needed.
     fake_configurable_object = instantiate_class_from_config(
-        config={"a": "value_from_the_config",},
+        config={
+            "a": "value_from_the_config",
+        },
         runtime_environment=my_runtime_environment,
         config_defaults={
             "module_name": "tests.test_plugins.fake_configs",
